@@ -379,21 +379,9 @@ ARDOUR_UI::parameter_changed (std::string p)
 	} else if (p == "show-track-meters") {
 		if (editor) editor->toggle_meter_updating();
 	} else if (p == "primary-clock-delta-mode") {
-		if (UIConfiguration::instance().get_primary_clock_delta_mode() != NoDelta) {
-			primary_clock->set_editable (false);
-			primary_clock->set_widget_name ("transport delta");
-		} else {
-			primary_clock->set_editable (true);
-			primary_clock->set_widget_name ("transport");
-		}
+		primary_clock->set_display_delta_mode(UIConfiguration::instance().get_primary_clock_delta_mode());
 	} else if (p == "secondary-clock-delta-mode") {
-		if (UIConfiguration::instance().get_secondary_clock_delta_mode() != NoDelta) {
-			secondary_clock->set_editable (false);
-			secondary_clock->set_widget_name ("secondary delta");
-		} else {
-			secondary_clock->set_editable (true);
-			secondary_clock->set_widget_name ("secondary");
-		}
+		secondary_clock->set_display_delta_mode(UIConfiguration::instance().get_secondary_clock_delta_mode());
 	} else if (p == "super-rapid-clock-update") {
 		if (_session) {
 			stop_clocking ();
