@@ -87,7 +87,6 @@ AutomationRegionView::init (bool /*wfd*/)
 
 	set_height (trackview.current_height());
 
-	fill_color_name = "midi frame base";
 	set_colors ();
 }
 
@@ -110,12 +109,11 @@ uint32_t
 AutomationRegionView::get_fill_color() const
 {
 	const std::string mod_name = (_dragging ? "dragging region" :
-	                              trackview.editor().internal_editing() ? "editable region" :
-	                              "midi frame base");
+	                              trackview.editor().internal_editing() ? "editable region" : fill_color_name);
 	if (_selected) {
 		return UIConfiguration::instance().color_mod ("selected region base", mod_name);
 	} else if (high_enough_for_name || !UIConfiguration::instance().get_color_regions_using_track_color()) {
-		return UIConfiguration::instance().color_mod ("midi frame base", mod_name);
+		return UIConfiguration::instance().color_mod (fill_color_name, mod_name);
 	}
 	return UIConfiguration::instance().color_mod (fill_color, mod_name);
 }
@@ -160,16 +158,14 @@ AutomationRegionView::canvas_group_event (GdkEvent* ev)
 		 * adding the point.
 		 */
 
-		const timepos_t pos = timepos_t (e.pixel_to_sample (x) - _region->position_sample() + _region->start_sample());
-
-		add_automation_event (ev, pos, y, with_guard_points);
+		add_automation_event (ev, timepos_t (e.pixel_to_sample (x)), y, with_guard_points);
 		return true;
 	}
 
 	return RegionView::canvas_group_event (ev);
 }
 
-/** @param when Position in samples, where 0 is the start of the region.
+/** @param when Position is global time position
  *  @param y y position, relative to our TimeAxisView.
  */
 void
@@ -192,7 +188,7 @@ AutomationRegionView::add_automation_event (GdkEvent *, timepos_t const & w, dou
 
 	/* snap time */
 
-	when = snap_region_time_to_region_time (when.earlier (_region->start()), false) + _region->start ();
+	when = snap_region_time_to_region_time (_region->source_position().distance (when), false);
 
 	/* map using line */
 
@@ -253,13 +249,19 @@ AutomationRegionView::paste (timepos_t const &                               pos
 	/* add multi-paste offset if applicable */
 	p += view->editor ().get_paste_offset (pos, paste_count > 0 ? 1 : 0, len);
 
-	/* convert sample-position to model's unit and position */
-	timepos_t model_pos = timepos_t (source_relative_distance (timecnt_t (p, timepos_t()), slist->time_domain()));
+	timepos_t model_pos = pos;
+
+	/* potentially snap */
+
+	view->editor().snap_to (model_pos, Temporal::RoundNearest);
+
+	/* convert timeline position to model's (source-relative) position */
+
+	model_pos = timepos_t (_region->source_position().distance (model_pos));
 
 	XMLNode& before = my_list->get_state();
 	my_list->paste (*slist, model_pos);
-	view->session()->add_command(
-		new MementoCommand<ARDOUR::AutomationList>(_line->memento_command_binder(), &before, &my_list->get_state()));
+	view->session()->add_command(new MementoCommand<ARDOUR::AutomationList>(_line->memento_command_binder(), &before, &my_list->get_state()));
 
 	return true;
 }
@@ -291,11 +293,10 @@ AutomationRegionView::reset_width_dependent_items (double pixel_width)
 	RegionView::reset_width_dependent_items(pixel_width);
 
 	if (_line) {
-		_line->reset();
+		_line->reset ();
 	}
 }
 
-
 void
 AutomationRegionView::region_resized (const PBD::PropertyChange& what_changed)
 {
@@ -314,6 +315,16 @@ AutomationRegionView::region_resized (const PBD::PropertyChange& what_changed)
 	}
 }
 
+void
+AutomationRegionView::tempo_map_changed ()
+{
+	if (_line) {
+		_line->tempo_map_changed ();
+	}
+
+	set_position (_region->position(), 0, 0);
+	set_duration (_region->length(), 0);
+}
 
 void
 AutomationRegionView::entered ()
