@@ -1036,7 +1036,6 @@ private:
 	BBTRulerScale bbt_ruler_scale;
 
 	uint32_t bbt_bars;
-	gint bbt_nmarks;
 	uint32_t bbt_bar_helper_on;
 	void compute_bbt_ruler_scale (samplepos_t lower, samplepos_t upper);
 
@@ -1394,7 +1393,7 @@ private:
 	void set_tempo_from_region ();
 	void use_range_as_bar ();
 
-	void define_one_bar (Temporal::timepos_t const & start, Temporal::timepos_t const & end);
+	void define_one_bar (Temporal::timepos_t const & start, Temporal::timepos_t const & end, std::string const & from);
 
 	void audition_region_from_region_list ();
 
@@ -2314,6 +2313,7 @@ private:
 	void set_gain_envelope_visibility ();
 	void set_region_gain_visibility (RegionView*);
 	void toggle_gain_envelope_active ();
+	void toggle_region_polarity ();
 	void reset_region_gain_envelopes ();
 
 	void session_state_saved (std::string);
