@@ -160,7 +160,7 @@ public:
 	}
 
 	Temporal::TimeDomain time_domain() const { return _time_domain; }
-
+	void set_time_domain (Temporal::TimeDomain);
 
 	void swap_grab (ArdourCanvas::Item *, Gdk::Cursor *, uint32_t);
 	bool motion_handler (GdkEvent*, bool);
@@ -1151,6 +1151,8 @@ private:
 	bool     _pushing;
         uint32_t _final_index;
 	static double _zero_gain_fraction;
+
+	Temporal::timecnt_t total_dt (GdkEvent*) const;
 };
 
 /** Gain or automation line drag */
