@@ -838,8 +838,7 @@ Editor::button_press_handler_1 (ArdourCanvas::Item* item, GdkEvent* event, ItemT
 		if (!Keyboard::modifier_state_equals (event->button.state, Keyboard::PrimaryModifier)
 		    && !ArdourKeyboard::indicates_constraint (event->button.state)) {
 			_drags->set (new CursorDrag (this, *_playhead_cursor, false), event);
-		} else if (ArdourKeyboard::indicates_constraint (event->button.state)
-		           && Keyboard::modifier_state_contains (event->button.state, Keyboard::PrimaryModifier)) {
+		} else if (Keyboard::modifier_state_equals (event->button.state, Keyboard::PrimaryModifier|Keyboard::TertiaryModifier)) {
 			_drags->set (new TempoTwistDrag (this, item), event);
 		} else if (Keyboard::modifier_state_contains (event->button.state, Keyboard::PrimaryModifier)) {
 			_drags->set (new BBTRulerDrag (this, item), event);
@@ -1108,6 +1107,10 @@ Editor::button_press_handler_1 (ArdourCanvas::Item* item, GdkEvent* event, ItemT
 
 				/* click on a normal region view */
 
+				if (_drags->active ()) {
+					return true;
+				}
+
 				if (Keyboard::modifier_state_equals (event->button.state, ArdourKeyboard::slip_contents_modifier ())) {
 					if (!clicked_regionview->region()->locked() && (Config->get_edit_mode() != Lock)) {
 						_drags->add (new RegionSlipContentsDrag (this, item, clicked_regionview, selection->regions.by_layer(), drag_time_domain (clicked_regionview->region())));
@@ -1378,6 +1381,9 @@ Editor::button_press_handler_2 (ArdourCanvas::Item* item, GdkEvent* event, ItemT
 	Editing::MouseMode const eff = effective_mouse_mode ();
 	switch (eff) {
 	case MouseObject:
+		if (_drags->active ()) {
+			return true;
+		}
 		switch (item_type) {
 		case RegionItem:
 			if (ArdourKeyboard::indicates_copy (event->button.state)) {
@@ -2656,6 +2662,8 @@ Editor::add_region_drag (ArdourCanvas::Item* item, GdkEvent*, RegionView* region
 		return;
 	}
 
+	assert (!_drags->active ());
+
 	_drags->add (new RegionMoveDrag (this, item, region_view, selection->regions.by_layer(), copy, drag_time_domain (region_view->region())));
 }
 
@@ -2668,6 +2676,8 @@ Editor::add_region_brush_drag (ArdourCanvas::Item* item, GdkEvent*, RegionView*
 		return;
 	}
 
+	assert (!_drags->active ());
+
 	if (should_ripple()) {
 		return;
 	}
