@@ -2,7 +2,7 @@
  * Copyright (C) 2007-2012 Carl Hetherington <carl@carlh.net>
  * Copyright (C) 2007-2016 Paul Davis <paul@linuxaudiosystems.com>
  * Copyright (C) 2008-2009 David Robillard <d@drobilla.net>
- * Copyright (C) 2014-2019 Robin Gareus <robin@gareus.org>
+ * Copyright (C) 2014-2022 Robin Gareus <robin@gareus.org>
  * Copyright (C) 2015-2016 Tim Mayberry <mojofunk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,20 +24,22 @@
 #define __gtk2_ardour_engine_dialog_h__
 
 #include <map>
-#include <vector>
 #include <string>
+#include <vector>
 
 #include <gtkmm/box.h>
 #include <gtkmm/button.h>
 #include <gtkmm/buttonbox.h>
-#include <gtkmm/comboboxtext.h>
 #include <gtkmm/checkbutton.h>
+#include <gtkmm/comboboxtext.h>
 #include <gtkmm/expander.h>
+#include <gtkmm/liststore.h>
 #include <gtkmm/notebook.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/table.h>
 
 #include "pbd/signals.h"
+#include "pbd/xml++.h"
 
 #include "widgets/ardour_button.h"
 
@@ -51,8 +53,8 @@ public:
 
 	static bool need_setup ();
 
-	XMLNode& get_state ();
-	bool set_state (const XMLNode&);
+	XMLNode& get_state () const;
+	bool     set_state (const XMLNode&);
 
 	void set_desired_sample_rate (uint32_t);
 
@@ -63,9 +65,13 @@ private:
 
 	/* core fields used by all backends */
 
-	Gtk::Table basic_packer;
-	Gtk::HBox basic_hbox;
-	Gtk::VBox basic_vbox;
+	Gtk::VBox main_vbox;
+	Gtk::HBox main_hbox;
+
+	Gtk::Table    settings_table;
+	Gtk::Table    latency_table;
+	Gtk::Expander latency_expander;
+	Gtk::Expander monitor_expander;
 
 	Gtk::ComboBoxText backend_combo;
 	Gtk::ComboBoxText driver_combo;
@@ -75,20 +81,31 @@ private:
 	Gtk::ComboBoxText sample_rate_combo;
 	Gtk::ComboBoxText midi_option_combo;
 	Gtk::ComboBoxText buffer_size_combo;
-	Gtk::Label        buffer_size_duration_label;
 	Gtk::ComboBoxText nperiods_combo;
-	Gtk::Adjustment input_latency_adjustment;
-	Gtk::SpinButton input_latency;
-	Gtk::Adjustment output_latency_adjustment;
-	Gtk::SpinButton output_latency;
-	Gtk::Adjustment input_channels_adjustment;
-	Gtk::SpinButton input_channels;
-	Gtk::Adjustment output_channels_adjustment;
-	Gtk::SpinButton output_channels;
-	Gtk::Adjustment ports_adjustment;
-	Gtk::SpinButton ports_spinner;
+	Gtk::Adjustment   input_latency_adjustment;
+	Gtk::SpinButton   input_latency;
+	Gtk::Adjustment   output_latency_adjustment;
+	Gtk::SpinButton   output_latency;
+	Gtk::ComboBoxText monitor_model_combo;
+
+	Gtk::Label lbl_audio_system;
+	Gtk::Label lbl_midi_system;
+	Gtk::Label lbl_driver;
+	Gtk::Label lbl_device;
+	Gtk::Label lbl_input_device;
+	Gtk::Label lbl_output_device;
+	Gtk::Label lbl_sample_rate;
+	Gtk::Label lbl_buffer_size;
+	Gtk::Label lbl_nperiods;
+	Gtk::Label lbl_input_latency;
+	Gtk::Label lbl_output_latency;
+	Gtk::Label lbl_monitor_model;
+	Gtk::Label lbl_jack_msg;
+
+	Gtk::Label unit_samples_txt1;
+	Gtk::Label unit_samples_txt2;
+	Gtk::Label buffer_size_duration_label;
 
-	Gtk::Label                  have_control_text;
 	ArdourWidgets::ArdourButton control_app_button;
 	ArdourWidgets::ArdourButton midi_devices_button;
 	ArdourWidgets::ArdourButton start_stop_button;
@@ -96,19 +113,20 @@ private:
 	ArdourWidgets::ArdourButton use_buffered_io_button;
 	ArdourWidgets::ArdourButton try_autostart_button;
 
-	Gtk::Button     connect_disconnect_button;
+	Gtk::Button connect_disconnect_button;
 
 	/* latency measurement */
 
 	class ChannelNameCols : public Gtk::TreeModelColumnRecord
 	{
-		public:
-			ChannelNameCols () {
-				add (pretty_name);
-				add (port_name);
-			}
-			Gtk::TreeModelColumn<std::string> pretty_name;
-			Gtk::TreeModelColumn<std::string> port_name;
+	public:
+		ChannelNameCols ()
+		{
+			add (pretty_name);
+			add (port_name);
+		}
+		Gtk::TreeModelColumn<std::string> pretty_name;
+		Gtk::TreeModelColumn<std::string> port_name;
 	};
 
 	ChannelNameCols              lm_output_channel_cols;
@@ -135,15 +153,15 @@ private:
 
 	/* MIDI Tab */
 
-	Gtk::VBox midi_vbox;
+	Gtk::VBox   midi_vbox;
 	Gtk::Button midi_back_button;
-	Gtk::Table midi_device_table;
+	Gtk::Table  midi_device_table;
 
 	/* MIDI ... JACK */
 
 	Gtk::CheckButton aj_button;
 
-	uint32_t ignore_changes; // state save/load
+	uint32_t ignore_changes;        // state save/load
 	uint32_t ignore_device_changes; // AudioEngine::DeviceListChanged
 	uint32_t _desired_sample_rate;
 	bool     started_at_least_once;
@@ -154,12 +172,10 @@ private:
 	void sample_rate_changed ();
 	void buffer_size_changed ();
 	void nperiods_changed ();
-	void channels_changed ();
 	void latency_changed ();
 	void midi_option_changed ();
+	void monitor_model_changed ();
 
-	void setup_midi_tab_for_backend ();
-	void setup_midi_tab_for_jack ();
 	void refresh_midi_display (std::string focus = "");
 
 	void update_midi_options ();
@@ -167,26 +183,24 @@ private:
 	std::string bufsize_as_string (uint32_t);
 	std::string nperiods_as_string (uint32_t);
 
-	std::vector<float> get_default_sample_rates ();
+	std::vector<float>    get_default_sample_rates ();
 	std::vector<uint32_t> get_default_buffer_sizes ();
 
-	std::vector<float> get_sample_rates_for_all_devices ();
+	std::vector<float>    get_sample_rates_for_all_devices ();
 	std::vector<uint32_t> get_buffer_sizes_for_all_devices ();
 
-	float get_rate() const;
-	uint32_t get_buffer_size() const;
-	uint32_t get_nperiods() const;
-	uint32_t get_input_channels() const;
-	uint32_t get_output_channels() const;
-	uint32_t get_input_latency() const;
-	uint32_t get_output_latency() const;
-	std::string get_device_name() const;
-	std::string get_input_device_name() const;
-	std::string get_output_device_name() const;
-	std::string get_driver() const;
-	std::string get_backend() const;
+	float       get_rate () const;
+	uint32_t    get_buffer_size () const;
+	uint32_t    get_nperiods () const;
+	uint32_t    get_input_latency () const;
+	uint32_t    get_output_latency () const;
+	std::string get_device_name () const;
+	std::string get_input_device_name () const;
+	std::string get_output_device_name () const;
+	std::string get_driver () const;
+	std::string get_backend () const;
 	std::string get_midi_option () const;
-	bool get_use_buffered_io () const;
+	bool        get_use_buffered_io () const;
 
 	std::string get_default_device (const std::string&,
 	                                const std::vector<std::string>&);
@@ -208,68 +222,67 @@ private:
 
 	struct MidiDeviceSetting {
 		std::string name;
-		bool enabled;
-		uint32_t input_latency;
-		uint32_t output_latency;
+		bool        enabled;
+		uint32_t    input_latency;
+		uint32_t    output_latency;
 
 		MidiDeviceSetting (std::string n, bool en = true, uint32_t inl = 0, uint32_t oul = 0)
-			: name (n)
-			, enabled (en)
-			, input_latency (inl)
-			, output_latency (oul)
-		{}
+		    : name (n)
+		    , enabled (en)
+		    , input_latency (inl)
+		    , output_latency (oul)
+		{
+		}
 	};
 
 	typedef boost::shared_ptr<MidiDeviceSetting> MidiDeviceSettings;
-	bool _can_set_midi_latencies;
-	std::vector<MidiDeviceSettings> _midi_devices;
+	bool                                         _can_set_midi_latencies;
+	std::vector<MidiDeviceSettings>              _midi_devices;
 
-	MidiDeviceSettings find_midi_device(std::string devicename) const {
-		for (std::vector<MidiDeviceSettings>::const_iterator p = _midi_devices.begin(); p != _midi_devices.end(); ++p) {
+	MidiDeviceSettings find_midi_device (std::string devicename) const
+	{
+		for (std::vector<MidiDeviceSettings>::const_iterator p = _midi_devices.begin (); p != _midi_devices.end (); ++p) {
 			if ((*p)->name == devicename) {
 				return *p;
 			}
 		}
-		return MidiDeviceSettings();
+		return MidiDeviceSettings ();
 	}
 
 	struct StateStruct {
-		std::string backend;
-		std::string driver;
-		std::string device;
-		std::string input_device;
-		std::string output_device;
-		float sample_rate;
-		uint32_t buffer_size;
-		uint32_t n_periods;
-		uint32_t input_latency;
-		uint32_t output_latency;
-		uint32_t input_channels;
-		uint32_t output_channels;
-		bool active;
-		bool use_buffered_io;
-		std::string midi_option;
+		std::string                     backend;
+		std::string                     driver;
+		std::string                     device;
+		std::string                     input_device;
+		std::string                     output_device;
+		float                           sample_rate;
+		uint32_t                        buffer_size;
+		uint32_t                        n_periods;
+		uint32_t                        input_latency;
+		uint32_t                        output_latency;
+		bool                            active;
+		bool                            use_buffered_io;
+		std::string                     midi_option;
 		std::vector<MidiDeviceSettings> midi_devices;
-		std::string lm_input;
-		std::string lm_output;
-		time_t lru;
+		std::string                     lm_input;
+		std::string                     lm_output;
+		time_t                          lru;
 
-		StateStruct()
-			: sample_rate (48000)
-			, buffer_size (1024)
-			, input_latency (0)
-			, output_latency (0)
-			, input_channels (0)
-			, output_channels (0)
-			, active (false)
-			, use_buffered_io (false)
-			, lru (0)
-		{}
+		StateStruct ()
+		    : sample_rate (48000)
+		    , buffer_size (1024)
+		    , input_latency (0)
+		    , output_latency (0)
+		    , active (false)
+		    , use_buffered_io (false)
+		    , lru (0)
+		{
+		}
 	};
 
 	typedef boost::shared_ptr<StateStruct> State;
-	typedef std::list<State> StateList;
-	static bool state_sort_cmp (const State &a, const State &b);
+	typedef std::list<State>               StateList;
+	static bool                            state_sort_cmp (const State& a, const State& b);
 
 	StateList states;
 
@@ -282,22 +295,22 @@ private:
 	                          const std::string& driver,
 	                          const std::string& input_device,
 	                          const std::string& output_device);
+
 	State get_saved_state_for_currently_displayed_backend_and_device ();
-	void maybe_display_saved_state ();
+	void  maybe_display_saved_state ();
 	State save_state ();
-	void store_state (State);
-	bool equivalent_states (const State&, const State&);
+	void  store_state (State);
+	bool  equivalent_states (const State&, const State&);
 
 	bool set_current_state (const State& state);
 	void set_default_state ();
 
-	bool  _have_control;
-
-	static bool print_channel_count (Gtk::SpinButton*);
+	bool _have_control;
 
 	void build_notebook ();
 	void build_full_control_notebook ();
 	void build_no_control_notebook ();
+	void populate_action_area (int);
 
 	void connect_changed_signals ();
 	void block_changed_signals ();
@@ -307,12 +320,11 @@ private:
 	{
 	public:
 		SignalBlocker (EngineControl& engine_control, const std::string& reason);
-
 		~SignalBlocker ();
 
 	private:
 		EngineControl& ec;
-		std::string m_reason;
+		std::string    m_reason;
 	};
 
 	uint32_t block_signals;
@@ -328,11 +340,14 @@ private:
 	sigc::connection midi_option_combo_connection;
 	sigc::connection input_latency_connection;
 	sigc::connection output_latency_connection;
-	sigc::connection input_channels_connection;
-	sigc::connection output_channels_connection;
+	sigc::connection monitor_model_connection;
+	sigc::connection latency_timeout;
+	sigc::connection lm_back_button_signal;
 
 	void on_show ();
 	void on_map ();
+	void on_monitor_expand ();
+	void on_latency_expand ();
 	void config_parameter_changed (std::string const&);
 	void control_app_button_clicked ();
 	void start_stop_button_clicked ();
@@ -341,7 +356,7 @@ private:
 	void try_autostart_button_clicked ();
 	void use_latency_button_clicked ();
 	void manage_control_app_sensitivity ();
-	int push_state_to_backend (bool start);
+	int  push_state_to_backend (bool start);
 	void post_push ();
 	void update_sensitivity ();
 	bool start_engine ();
@@ -352,32 +367,32 @@ private:
 	void latency_back_button_clicked ();
 	bool check_audio_latency_measurement ();
 	bool check_midi_latency_measurement ();
-	sigc::connection latency_timeout;
 	void enable_latency_tab ();
 	void disable_latency_tab ();
 	void start_latency_detection ();
 	void end_latency_detection ();
 
+	MidiDeviceSettings _measure_midi;
+
+	void midi_latency_adjustment_changed (Gtk::Adjustment*, MidiDeviceSettings, bool);
+	void midi_device_enabled_toggled (ArdourWidgets::ArdourButton*, MidiDeviceSettings);
+
+	/* main dialog events */
 	void on_switch_page (GtkNotebookPage*, guint page_num);
 	bool on_delete_event (GdkEventAny*);
 	void on_response (int);
 
-	void engine_running ();
-	void engine_stopped ();
-	void device_list_changed ();
-
-	PBD::ScopedConnection running_connection;
-	PBD::ScopedConnectionList stopped_connection;
-	PBD::ScopedConnection devicelist_connection;
-
 	void connect_disconnect_click ();
 	void calibrate_audio_latency ();
 	void calibrate_midi_latency (MidiDeviceSettings);
 
-	MidiDeviceSettings _measure_midi;
-	void midi_latency_adjustment_changed(Gtk::Adjustment *, MidiDeviceSettings, bool);
-	void midi_device_enabled_toggled(ArdourWidgets::ArdourButton *, MidiDeviceSettings);
-	sigc::connection lm_back_button_signal;
+	void engine_running ();
+	void engine_stopped ();
+	void device_list_changed ();
+
+	PBD::ScopedConnection     running_connection;
+	PBD::ScopedConnectionList stopped_connection;
+	PBD::ScopedConnection     devicelist_connection;
 };
 
 #endif /* __gtk2_ardour_engine_dialog_h__ */
