@@ -82,9 +82,9 @@ FoldbackSend::FoldbackSend (boost::shared_ptr<Send> snd, boost::shared_ptr<ARDOU
 	_button.set_led_left (true);
 	_button.signal_led_clicked.connect (sigc::mem_fun (*this, &FoldbackSend::led_clicked));
 	if (_send_proc->get_pre_fader ()) {
-		_button.set_name ("processor prefader");
+		_button.set_name ("foldback prefader");
 	} else {
-		_button.set_name ("processor postfader");
+		_button.set_name ("foldback postfader");
 	}
 	_button.set_layout_ellipsize_width (PX_SCALE (_width) * PANGO_SCALE);
 	_button.set_text_ellipsize (Pango::ELLIPSIZE_END);
@@ -95,16 +95,14 @@ FoldbackSend::FoldbackSend (boost::shared_ptr<Send> snd, boost::shared_ptr<ARDOU
 
 	if (_foldback_route->input ()->n_ports ().n_audio () == 2) {
 		_button.set_layout_ellipsize_width (PX_SCALE (_width - 19) * PANGO_SCALE);
-		boost::shared_ptr<Pannable>          pannable = _send_del->panner ()->pannable ();
-		boost::shared_ptr<AutomationControl> ac;
-		ac = pannable->pan_azimuth_control;
+		boost::shared_ptr<Pannable> pannable = _send->panner ()->pannable ();
 		_pan_control.set_size_request (PX_SCALE (19), PX_SCALE (19));
 		_pan_control.set_tooltip_prefix (_("Pan: "));
-		_pan_control.set_name ("trim knob");
 		_pan_control.set_no_show_all (true);
 		snd_but_pan->pack_start (_pan_control, false, false);
 		_pan_control.show ();
-		_pan_control.set_controllable (ac);
+		_pan_control.set_controllable (pannable->pan_azimuth_control);
+		_pan_control.set_name (_send->panner_linked_to_route () ? "trim knob" : "pan knob");
 	}
 	boost::shared_ptr<AutomationControl> lc;
 	lc = _send->gain_control ();
@@ -123,7 +121,9 @@ FoldbackSend::FoldbackSend (boost::shared_ptr<Send> snd, boost::shared_ptr<ARDOU
 	_send_proc->ActiveChanged.connect (_connections, invalidator (*this), boost::bind (&FoldbackSend::send_state_changed, this), gui_context ());
 	_button.signal_button_press_event ().connect (sigc::mem_fun (*this, &FoldbackSend::button_press));
 	_button.signal_button_release_event ().connect (sigc::mem_fun (*this, &FoldbackSend::button_release));
+	_pan_control.signal_button_press_event().connect (sigc::mem_fun (*this, &FoldbackSend::pan_knob_press));
 	_send_route->PropertyChanged.connect (_connections, invalidator (*this), boost::bind (&FoldbackSend::route_property_changed, this, _1), gui_context ());
+	_send->panner_shell()->PannableChanged.connect (_connections, invalidator (*this), boost::bind (&FoldbackSend::send_pan_changed, this), gui_context ());
 
 	show ();
 }
@@ -169,6 +169,17 @@ FoldbackSend::led_clicked (GdkEventButton* ev)
 	}
 }
 
+bool
+FoldbackSend::pan_knob_press (GdkEventButton* ev)
+{
+	if (Keyboard::is_context_menu_event (ev)) {
+		_send->set_panner_linked_to_route (!_send->panner_linked_to_route ());
+		_pan_control.set_name (_send->panner_linked_to_route () ? "trim knob" : "pan knob");
+		return true;
+	}
+	return false;
+}
+
 bool
 FoldbackSend::button_press (GdkEventButton* ev)
 {
@@ -207,6 +218,13 @@ FoldbackSend::send_state_changed ()
 	_button.set_active (_send_proc->enabled ());
 }
 
+void
+FoldbackSend::send_pan_changed ()
+{
+	boost::shared_ptr<Pannable>  pannable = _send->panner ()->pannable ();
+	_pan_control.set_controllable (pannable->pan_azimuth_control);
+}
+
 void
 FoldbackSend::level_adjusted ()
 {
@@ -253,6 +271,7 @@ FoldbackSend::set_tooltip ()
 	std::string tt = ARDOUR::value_as_string (lc->desc (), lc->get_value ());
 	string      sm = Gtkmm2ext::markup_escape_text (tt);
 	_slider_persistant_tooltip.set_tip (sm);
+	_slider.set_text (sm);
 }
 
 Menu*
@@ -405,7 +424,7 @@ FoldbackStrip::init ()
 	_name_button.set_text_ellipsize (Pango::ELLIPSIZE_END);
 	_name_button.set_layout_ellipsize_width (PX_SCALE (_width) * PANGO_SCALE);
 
-	_send_display.set_flags (CAN_FOCUS);
+	_send_display.set_can_focus ();
 	_send_display.set_spacing (4);
 
 	_send_scroller.set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
@@ -523,7 +542,7 @@ FoldbackStrip::init ()
 	            Gdk::KEY_PRESS_MASK |
 	            Gdk::KEY_RELEASE_MASK);
 
-	set_flags (get_flags () | Gtk::CAN_FOCUS);
+	set_can_focus ();
 
 	signal_enter_notify_event ().connect (sigc::mem_fun (*this, &FoldbackStrip::fb_strip_enter_event));
 
@@ -656,13 +675,8 @@ FoldbackStrip::update_send_box ()
 	StripableList stripables;
 	stripables.clear ();
 
-	Route::FedBy fed_by = _route->fed_by ();
-	for (Route::FedBy::iterator i = fed_by.begin (); i != fed_by.end (); ++i) {
-		if (i->sends_only) {
-			boost::shared_ptr<Route>     rt (i->r.lock ());
-			boost::shared_ptr<Stripable> s = boost::dynamic_pointer_cast<Stripable> (rt);
-			stripables.push_back (s);
-		}
+	for (auto const& s : _route->signal_sources (true)) {
+		stripables.push_back (s);
 	}
 	stripables.sort (StripableByPresentationOrder ());
 	for (StripableList::iterator it = stripables.begin (); it != stripables.end (); ++it) {
@@ -992,7 +1006,7 @@ FoldbackStrip::reset_strip_style ()
 		set_name ("AudioBusStripBaseInactive");
 	}
 
-	set_invert_sensitive (active);
+	update_phase_invert_sensitivty ();
 	update_sensitivity ();
 
 	_comment_button.set_sensitive (active);
@@ -1076,19 +1090,15 @@ FoldbackStrip::duplicate_current_fb ()
 		double oldgain = old_fb->gain_control ()->get_value ();
 		new_fb->gain_control ()->set_value (oldgain * 0.25, PBD::Controllable::NoGroup);
 
-		Route::FedBy fed_by = old_fb->fed_by ();
-		for (Route::FedBy::iterator i = fed_by.begin (); i != fed_by.end (); ++i) {
-			if (i->sends_only) {
-				boost::shared_ptr<Route>     rt (i->r.lock ());
-				boost::shared_ptr<Send>      old_snd  = rt->internal_send_for (old_fb);
+		for (auto const& rt : old_fb->signal_sources (true)) {
+			boost::shared_ptr<Send> old_snd  = rt->internal_send_for (old_fb);
+			if (old_snd) {
 				boost::shared_ptr<Processor> old_proc = old_snd;
 				bool                         old_pre  = old_proc->get_pre_fader ();
 				rt->add_foldback_send (new_fb, !old_pre);
-				if (old_snd) {
-					float                   old_gain = old_snd->gain_control ()->get_value ();
-					boost::shared_ptr<Send> new_snd  = rt->internal_send_for (new_fb);
-					new_snd->gain_control ()->set_value (old_gain, PBD::Controllable::NoGroup);
-				}
+				float                   old_gain = old_snd->gain_control ()->get_value ();
+				boost::shared_ptr<Send> new_snd  = rt->internal_send_for (new_fb);
+				new_snd->gain_control ()->set_value (old_gain, PBD::Controllable::NoGroup);
 			}
 		}
 		set_route (new_fb);
