@@ -58,7 +58,9 @@
 #include "gtkmm2ext/utils.h"
 #include "gtkmm2ext/doi.h"
 
+#include "widgets/frame.h"
 #include "widgets/ardour_knob.h"
+#include "widgets/ardour_spacer.h"
 #include "widgets/fastmeter.h"
 #include "widgets/slider_controller.h"
 #include "widgets/tooltips.h"
@@ -82,8 +84,8 @@ using namespace ArdourWidgets;
 using namespace Gtk;
 using namespace ARDOUR_UI_UTILS;
 
-GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrollable)
-	: PlugUIBase (pi)
+GenericPluginUI::GenericPluginUI (boost::shared_ptr<PlugInsertBase> pib, bool scrollable)
+	: PlugUIBase (pib)
 	, automation_menu (0)
 	, is_scrollable(scrollable)
 	, _plugin_pianokeyboard_expander (_("MIDI Keyboard (audition only)"))
@@ -100,7 +102,13 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 	HBox* smaller_hbox = manage (new HBox);
 	smaller_hbox->set_spacing (6);
 	smaller_hbox->set_border_width (0);
-	add_common_widgets (smaller_hbox, false);
+
+	if (_pib->ui_elements () == PlugInsertBase::NoGUIToolbar) {
+		Gtk::Label* spacer = manage (new Gtk::Label());
+		smaller_hbox->pack_start(*spacer);
+	} else {
+		add_common_widgets (smaller_hbox, false);
+	}
 
 	automation_manual_all_button.set_text (GainMeterBase::astate_string (ARDOUR::Off));
 	automation_manual_all_button.set_name (X_("generic button"));
@@ -113,9 +121,9 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 	automation_latch_all_button.set_text (GainMeterBase::astate_string (ARDOUR::Latch));
 	automation_latch_all_button.set_name (X_("generic button"));
 
-	if (pi->is_instrument ()) {
+	if (_pib->ui_elements () & PlugInsertBase::MIDIKeyboard) {
 		_piano = new APianoKeyboard ();
-		_piano->set_flags(Gtk::CAN_FOCUS);
+		_piano->set_can_focus ();
 
 		_piano->NoteOn.connect (sigc::mem_fun (*this, &GenericPluginUI::note_on_event_handler));
 		_piano->NoteOff.connect (sigc::mem_fun (*this, &GenericPluginUI::note_off_event_handler));
@@ -137,11 +145,11 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 		_plugin_pianokeyboard_expander.property_expanded().signal_changed().connect( sigc::mem_fun(*this, &GenericPluginUI::toggle_pianokeyboard));
 
 		pack_end (_plugin_pianokeyboard_expander, false, false);
-	} else {
+	} else if (_pi && _pi->ui_elements () != PlugInsertBase::NoGUIToolbar) {
 		pack_end (plugin_analysis_expander, false, false);
 	}
 
-	if (insert->provides_stats ()) {
+	if (_pib->provides_stats ()) {
 		pack_end (cpuload_expander, false, false);
 	}
 
@@ -154,7 +162,31 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 	settings_box.set_border_width (0);
 	settings_box.pack_start (*smaller_hbox, false, false);
 
-	if (pi->controls().size() > 0) {
+	bool has_automatables = false;
+
+	for (size_t i = 0; i < plugin->parameter_count(); ++i) {
+		if (!plugin->parameter_is_control (i)) {
+			continue;
+		}
+		if (!plugin->parameter_is_input (i)) {
+			continue;
+		}
+		const Evoral::Parameter param(PluginAutomation, 0, i);
+		boost::shared_ptr<ARDOUR::AutomationControl> c (boost::dynamic_pointer_cast<ARDOUR::AutomationControl>(_pib->control (param)));
+		if (!c) {
+			continue;
+		}
+		if (c->flags () & Controllable::HiddenControl) {
+			continue;
+		}
+		if (c->flags () & Controllable::NotAutomatable) {
+			continue;
+		}
+		has_automatables = true;
+		break;
+	}
+
+	if (_pi && has_automatables) {
 		HBox* automation_hbox = manage (new HBox);
 		automation_hbox->set_spacing (6);
 		Label* l = manage (new Label (_("All Automation")));
@@ -169,8 +201,12 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 
 	main_contents.pack_start (settings_box, false, false);
 
-	pi->ActiveChanged.connect (active_connection, invalidator (*this), boost::bind (&GenericPluginUI::processor_active_changed, this, boost::weak_ptr<Processor>(pi)), gui_context());
-	_bypass_button.set_active (!pi->enabled());
+	if (_pi) {
+		_pi->ActiveChanged.connect (active_connection, invalidator (*this), boost::bind (&GenericPluginUI::processor_active_changed, this, boost::weak_ptr<Processor>(_pi)), gui_context());
+		_bypass_button.set_active (!_pi->enabled());
+	} else {
+		_bypass_button.set_sensitive (false);
+	}
 
 	/* ScrolledWindow will wrap hpacker in a Viewport */
 	scroller.add (hpacker);
@@ -182,7 +218,7 @@ GenericPluginUI::GenericPluginUI (boost::shared_ptr<PluginInsert> pi, bool scrol
 	prefheight = -1;
 	build ();
 
-	if (insert->plugin()->has_midnam() && insert->plugin()->knows_bank_patch()) {
+	if (_pib->plugin()->has_midnam() && _pib->plugin()->knows_bank_patch()) {
 		build_midi_table ();
 	}
 
@@ -320,9 +356,7 @@ GenericPluginUI::build ()
 
 			ControlUI* cui;
 
-			boost::shared_ptr<ARDOUR::AutomationControl> c
-				= boost::dynamic_pointer_cast<ARDOUR::AutomationControl>(
-					insert->control(param));
+			boost::shared_ptr<ARDOUR::AutomationControl> c (boost::dynamic_pointer_cast<ARDOUR::AutomationControl>(_pib->control (param)));
 
 			if (c && c->flags () & Controllable::HiddenControl) {
 				continue;
@@ -350,9 +384,7 @@ GenericPluginUI::build ()
 		const ParameterDescriptor& desc = d->second;
 		const Evoral::Parameter    param(PluginPropertyAutomation, 0, desc.key);
 
-		boost::shared_ptr<ARDOUR::AutomationControl> c
-			= boost::dynamic_pointer_cast<ARDOUR::AutomationControl>(
-				insert->control(param));
+		boost::shared_ptr<ARDOUR::AutomationControl> c (boost::dynamic_pointer_cast<ARDOUR::AutomationControl>(_pib->control (param)));
 
 		if (!c) {
 			error << string_compose(_("Plugin Editor: no control for property %1"), desc.key) << endmsg;
@@ -380,9 +412,9 @@ GenericPluginUI::build ()
 		plugin->announce_property_values();
 	}
 
-	if (control_uis.empty ()) {
+	if (control_uis.empty () && _pi) {
 		if (has_descriptive_presets ()) {
-			preset_gui = new PluginPresetsUI (insert);
+			preset_gui = new PluginPresetsUI (_pi); // XXX
 			hpacker.pack_start (*preset_gui, true, true);
 		}
 	} else {
@@ -415,8 +447,8 @@ GenericPluginUI::automatic_layout (const std::vector<ControlUI*>& control_uis)
 	Gtk::Table* button_table = manage (new Gtk::Table (initial_button_rows, initial_button_cols));
 	Gtk::Table* output_table = manage (new Gtk::Table (initial_output_rows, initial_output_cols));
 
-	Frame* frame;
-	Frame* bt_frame;
+	Gtk::Frame* frame;
+	Gtk::Frame* bt_frame;
 	VBox* box;
 	int output_row, output_col;
 	int button_row, button_col;
@@ -446,7 +478,7 @@ GenericPluginUI::automatic_layout (const std::vector<ControlUI*>& control_uis)
 	output_table->set_border_width (5);
 
 
-	bt_frame = manage (new Frame);
+	bt_frame = manage (new Gtk::Frame);
 	bt_frame->set_name ("BaseFrame");
 	bt_frame->set_label (_("Switches"));
 	bt_frame->add (*button_table);
@@ -456,7 +488,7 @@ GenericPluginUI::automatic_layout (const std::vector<ControlUI*>& control_uis)
 	box->set_border_width (5);
 	box->set_spacing (1);
 
-	frame = manage (new Frame);
+	frame = manage (new Gtk::Frame);
 	frame->set_name ("BaseFrame");
 	frame->set_label (_("Controls"));
 	frame->add (*box);
@@ -562,7 +594,7 @@ GenericPluginUI::automatic_layout (const std::vector<ControlUI*>& control_uis)
 
 		if (x > max_controls_per_column || similarity_scores[i] <= similarity_threshold) {
 			if (x > min_controls_per_column) {
-				frame = manage (new Frame);
+				frame = manage (new Gtk::Frame);
 				frame->set_name ("BaseFrame");
 				frame->set_label (_("Controls"));
 				box = manage (new VBox);
@@ -597,7 +629,7 @@ GenericPluginUI::automatic_layout (const std::vector<ControlUI*>& control_uis)
 	}
 
 	if (!output_table->children().empty()) {
-		frame = manage (new Frame);
+		frame = manage (new Gtk::Frame);
 		frame->set_name ("BaseFrame");
 		frame->set_label(_("Meters"));
 		frame->add (*output_table);
@@ -626,9 +658,9 @@ GenericPluginUI::build_midi_table ()
 	pgm_table->set_border_width (5);
 	pgm_table->set_col_spacing (2, 10);
 
-	Frame* frame = manage (new Frame);
+	ArdourWidgets::Frame* frame = manage (new ArdourWidgets::Frame);
 	frame->set_name ("BaseFrame");
-	if (dynamic_cast<MidiTrack*> (insert->owner())) {
+	if (_pi && dynamic_cast<MidiTrack*> (_pi->owner())) {
 		frame->set_label (_("MIDI Programs (sent to track)"));
 	} else {
 		frame->set_label (_("MIDI Programs (volatile)"));
@@ -644,20 +676,20 @@ GenericPluginUI::build_midi_table ()
 		cui->set_text_ellipsize (Pango::ELLIPSIZE_END);
 		cui->set_layout_ellipsize_width (PANGO_SCALE * 112 * UIConfiguration::instance ().get_ui_scale ());
 		midi_pgmsel.push_back (cui);
-		pgm_table->attach (*manage (new Label (string_compose ("C%1:", (int)(chn + 1)), ALIGN_RIGHT)), col, col + 1, row, row+1, FILL, SHRINK);
+		pgm_table->attach (*manage (new Label (string_compose ("C%1:", (int)(chn + 1)), ALIGN_END)), col, col + 1, row, row+1, FILL, SHRINK);
 		pgm_table->attach (*cui, col + 1, col + 2, row, row+1, SHRINK, SHRINK);
 	}
 
-	insert->plugin ()->read_midnam();
+	_pib->plugin ()->read_midnam();
 
 	midi_refill_patches ();
 
-	insert->plugin()->BankPatchChange.connect (
+	_pib->plugin()->BankPatchChange.connect (
 			midi_connections, invalidator (*this),
 			boost::bind (&GenericPluginUI::midi_bank_patch_change, this, _1),
 			gui_context());
 
-	insert->plugin()->UpdatedMidnam.connect (
+	_pib->plugin()->UpdatedMidnam.connect (
 			midi_connections, invalidator (*this),
 			boost::bind (&GenericPluginUI::midi_refill_patches, this),
 			gui_context());
@@ -670,7 +702,7 @@ GenericPluginUI::midi_refill_patches ()
 
 	pgm_names.clear ();
 
-	const std::string model = insert->plugin ()->midnam_model ();
+	const std::string model = _pib->plugin ()->midnam_model ();
 	std::string mode;
 	const std::list<std::string> device_modes = MIDI::Name::MidiPatchManager::instance().custom_device_mode_names_by_model (model);
 	if (device_modes.size() > 0) {
@@ -706,7 +738,7 @@ void
 GenericPluginUI::midi_bank_patch_change (uint8_t chn)
 {
 	assert (chn < 16 && midi_pgmsel.size() == 16);
-	uint32_t bankpgm = insert->plugin()->bank_patch (chn);
+	uint32_t bankpgm = _pib->plugin()->bank_patch (chn);
 	if (bankpgm == UINT32_MAX) {
 		midi_pgmsel[chn]->set_text (_("--Unset--"));
 	} else {
@@ -726,7 +758,7 @@ GenericPluginUI::midi_bank_patch_select (uint8_t chn, uint32_t bankpgm)
 {
 	int bank = bankpgm >> 7;
 	int pgm = bankpgm & 127;
-	MidiTrack* mt = dynamic_cast<MidiTrack*> (insert->owner());
+	MidiTrack* mt = _pi ? dynamic_cast<MidiTrack*> (_pi->owner()) : NULL;
 	if (mt) {
 		/* send to track */
 		boost::shared_ptr<AutomationControl> bank_msb = mt->automation_control(Evoral::Parameter (MidiCCAutomation, chn, MIDI_CTL_MSB_BANK), true);
@@ -741,15 +773,15 @@ GenericPluginUI::midi_bank_patch_select (uint8_t chn, uint32_t bankpgm)
 		event[0] = (MIDI_CMD_CONTROL | chn);
 		event[1] = 0x00;
 		event[2] = bank >> 7;
-		insert->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
+		_pib->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 
 		event[1] = 0x20;
 		event[2] = bank & 127;
-		insert->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
+		_pib->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 
 		event[0] = (MIDI_CMD_PGM_CHANGE | chn);
 		event[1] = pgm;
-		insert->write_immediate_event (Evoral::MIDI_EVENT, 2, event);
+		_pib->write_immediate_event (Evoral::MIDI_EVENT, 2, event);
 	}
 }
 
@@ -801,13 +833,18 @@ GenericPluginUI::set_short_autostate (ControlUI* cui, bool value)
 void
 GenericPluginUI::automation_state_changed (ControlUI* cui)
 {
+	AutoState state;
+	if (_pi) {
+		/* don't lock to avoid deadlock because we're triggered by
+		 * AutomationControl::Changed() while the automation lock is taken
+		 */
+		state = _pi->get_parameter_automation_state (cui->parameter());
+	} else {
+		state = ARDOUR::Off;
+	}
+
 	/* update button label */
 
-	// don't lock to avoid deadlock because we're triggered by
-	// AutomationControl::Changed() while the automation lock is taken
-
-	AutoState state = insert->get_parameter_automation_state (cui->parameter());
-
 	cui->automate_button.set_active((state != ARDOUR::Off));
 
 	if (cui->short_autostate) {
@@ -998,7 +1035,7 @@ GenericPluginUI::build_control_ui (const Evoral::Parameter&             param,
 		}
 
 
-		if (mcontrol->flags () & Controllable::NotAutomatable) {
+		if (!_pi || mcontrol->flags () & Controllable::NotAutomatable) {
 			control_ui->automate_button.set_sensitive (false);
 			set_tooltip(control_ui->automate_button, _("This control cannot be automated"));
 		} else {
@@ -1114,6 +1151,7 @@ GenericPluginUI::knob_size_request(Gtk::Requisition* req, ControlUI* cui) {
 bool
 GenericPluginUI::astate_button_event (GdkEventButton* ev, ControlUI* cui)
 {
+	assert (_pi);
 	if (ev->button != 1) {
 		return true;
 	}
@@ -1141,7 +1179,7 @@ GenericPluginUI::astate_button_event (GdkEventButton* ev, ControlUI* cui)
 				   sigc::bind (sigc::mem_fun(*this, &GenericPluginUI::set_automation_state), (AutoState) Latch, cui)));
 
 	anchored_menu_popup (automation_menu, &cui->automate_button,
-	                     GainMeterBase::astate_string (insert->get_parameter_automation_state (cui->parameter())),
+	                     GainMeterBase::astate_string (_pi->get_parameter_automation_state (cui->parameter())),
 	                     1, ev->time);
 
 	return true;
@@ -1158,7 +1196,9 @@ GenericPluginUI::set_all_automation (AutoState as)
 void
 GenericPluginUI::set_automation_state (AutoState state, ControlUI* cui)
 {
-	insert->set_parameter_automation_state (cui->parameter(), state);
+	if (_pi) {
+		_pi->set_parameter_automation_state (cui->parameter(), state);
+	}
 }
 
 void
@@ -1223,7 +1263,7 @@ void
 GenericPluginUI::control_combo_changed (ControlUI* cui, float value)
 {
 	if (!cui->ignore_change) {
-		insert->automation_control (cui->parameter())->set_value (value, Controllable::NoGroup);
+		cui->combo->get_controllable ()->set_value (value, Controllable::NoGroup);
 	}
 }
 
@@ -1252,7 +1292,7 @@ GenericPluginUI::output_update ()
 	for (vector<ControlUI*>::iterator i = output_controls.begin(); i != output_controls.end(); ++i) {
 		float val = plugin->get_parameter ((*i)->parameter().id());
 		char buf[32];
-		boost::shared_ptr<ReadOnlyControl> c = insert->control_output ((*i)->parameter().id());
+		boost::shared_ptr<ReadOnlyControl> c = _pib->control_output ((*i)->parameter().id());
 		const std::string& str = ARDOUR::value_as_string(c->desc(), Variant(val));
 		size_t len = str.copy(buf, 31);
 		buf[len] = '\0';
@@ -1306,7 +1346,7 @@ GenericPluginUI::toggle_pianokeyboard ()
 void
 GenericPluginUI::note_on_event_handler (int note, int)
 {
-	MidiTrack* mt = dynamic_cast<MidiTrack*> (insert->owner());
+	MidiTrack* mt = _pi ? dynamic_cast<MidiTrack*> (_pi->owner()) : NULL;
 	_piano->grab_focus ();
 	uint8_t channel = _piano_channel.get_value_as_int () - 1;
 	uint8_t event[3];
@@ -1316,14 +1356,14 @@ GenericPluginUI::note_on_event_handler (int note, int)
 	if (mt) {
 		mt->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 	} else {
-		insert->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
+		_pib->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 	}
 }
 
 void
 GenericPluginUI::note_off_event_handler (int note)
 {
-	MidiTrack* mt = dynamic_cast<MidiTrack*> (insert->owner());
+	MidiTrack* mt = _pi ? dynamic_cast<MidiTrack*> (_pi->owner()) : NULL;
 	uint8_t channel = _piano_channel.get_value_as_int () - 1;
 	uint8_t event[3];
 	event[0] = (MIDI_CMD_NOTE_OFF | channel);
@@ -1332,6 +1372,6 @@ GenericPluginUI::note_off_event_handler (int note)
 	if (mt) {
 		mt->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 	} else {
-		insert->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
+		_pib->write_immediate_event (Evoral::MIDI_EVENT, 3, event);
 	}
 }
