@@ -36,7 +36,7 @@
 #include "loudness_settings.h"
 
 namespace ARDOUR {
-	class AudioRange;
+	class TimelineRange;
 	class ExportAnalysis;
 	class ExportStatus;
 	class PluginInsert;
@@ -47,7 +47,7 @@ namespace ARDOUR {
 class LoudnessDialog : public ArdourDialog
 {
 public:
-	LoudnessDialog (ARDOUR::Session*, ARDOUR::AudioRange const&, bool);
+	LoudnessDialog (ARDOUR::Session*, ARDOUR::TimelineRange const&, bool);
 	int run ();
 
 	float gain_db () const;
@@ -86,7 +86,7 @@ private:
 	static CLoudnessPreset _last_preset;
 
 	ARDOUR::Session*                        _session;
-	ARDOUR::AudioRange const&               _range;
+	ARDOUR::TimelineRange const&               _range;
 	boost::shared_ptr<ARDOUR::ExportStatus> _status;
 	bool                                    _autostart;
 
