@@ -323,6 +323,19 @@ int main (int argc, char *argv[])
 	}
 #endif
 
+	/* This is horrible, but ... we don't want to init GTK until it is
+	 * really time (during a Gtkmm2ext::UI constructor. However, this will
+	 * try to load GTK modules too, so do this only if it appears that need
+	 * to do this.
+	 */
+
+	for (int n = 1; n < argc; ++n) {
+		if (!strncmp (argv[n], "--gtk", 5) || !strncmp (argv[n], "--gdk", 5)) {
+			gtk_parse_args (&argc, &argv);
+			break;
+		}
+	}
+
 	if (parse_opts (argc, argv)) {
 		command_line_parse_error (&argc, &argv);
 		exit (EXIT_FAILURE);
@@ -354,7 +367,7 @@ int main (int argc, char *argv[])
 	}
 
 	if (no_splash) {
-		cout << _("Copyright (C) 1999-2022 Paul Davis") << endl
+		cout << _("Copyright (C) 1999-2023 Paul Davis") << endl
 		     << _("Some portions Copyright (C) Steve Harris, Ari Johnson, Brett Viren, Joel Baker, Robin Gareus") << endl
 		     << endl
 		     << string_compose (_("%1 comes with ABSOLUTELY NO WARRANTY"), PROGRAM_NAME) << endl
