@@ -22,8 +22,7 @@
 using namespace ARDOUR;
 
 MidiCutBuffer::MidiCutBuffer (Session* s)
-	: AutomatableSequence<Temporal::Beats> (*s)
-	, _origin (0)
+	: AutomatableSequence<Temporal::Beats> (*s, Temporal::BeatTime)
 {
 
 }
