@@ -125,7 +125,6 @@ public:
 	GhostRegion* add_ghost (TimeAxisView&);
 
 	NoteBase* add_note(const boost::shared_ptr<NoteType> note, bool visible);
-	void resolve_note(uint8_t note_num, Temporal::Beats end_time);
 
 	void cut_copy_clear (Editing::CutCopyOp);
 	bool paste (Temporal::timepos_t const & pos, const ::Selection& selection, PasteContext& ctx);
@@ -279,9 +278,9 @@ public:
 	 * @param x a pixel coordinate relative to region start
 	 * @param ensure_snap ignore SnapOff and magnetic snap.
 	 * Required for inverting snap logic with modifier keys and snap delta calculation.
-	 * @return the snapped timepos_t coordinate relative to region start
+	 * @return the snapped timecnt_t coordinate relative to region start
 	 */
-	Temporal::timepos_t snap_pixel_to_time (double x, bool ensure_snap = false);
+	Temporal::timecnt_t snap_pixel_to_time (double x, bool ensure_snap = false);
 
 	void goto_previous_note (bool add_to_selection);
 	void goto_next_note (bool add_to_selection);
