@@ -49,8 +49,12 @@
 #include "pbd/tokenizer.h"
 
 #include "ardour/utils.h"
+#include "ardour/rc_configuration.h"
 
+#include "ardour_message.h"
+#include "plugin_scan_dialog.h"
 #include "plugin_selector.h"
+#include "ardour_ui.h"
 #include "plugin_utils.h"
 #include "gui_thread.h"
 #include "ui_config.h"
@@ -67,7 +71,7 @@ using namespace ARDOUR_PLUGIN_UTILS;
 static const uint32_t MAX_CREATOR_LEN = 24;
 
 PluginSelector::PluginSelector (PluginManager& mgr)
-	: ArdourDialog (_("Plugin Manager"), true, false)
+	: ArdourDialog (_("Plugin Selector"), true, false)
 	, search_clear_button (Stock::CLEAR)
 	, manager (mgr)
 	, _need_tag_save (false)
@@ -90,12 +94,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 
 	plugin_model = Gtk::ListStore::create (plugin_columns);
 	plugin_display.set_model (plugin_model);
-	/* XXX translators: try to convert "Fav" into a short term
-	 * related to "favorite" and "Hid" into a short term
-	 * related to "hidden"
-	 */
-	plugin_display.append_column (_("Fav"), plugin_columns.favorite);
-	plugin_display.append_column (_("Hide"), plugin_columns.hidden);
+	plugin_display.append_column (S_("Favorite|Fav"), plugin_columns.favorite);
 	plugin_display.append_column (_("Name"), plugin_columns.name);
 	plugin_display.append_column (_("Tags"), plugin_columns.tags);
 	plugin_display.append_column (_("Creator"), plugin_columns.creator);
@@ -106,7 +105,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	plugin_display.set_headers_clickable (true);
 	plugin_display.set_reorderable (false);
 	plugin_display.set_rules_hint (true);
-	plugin_display.add_object_drag (plugin_columns.plugin.index(), "PluginInfoPtr");
+	plugin_display.add_object_drag (plugin_columns.plugin.index(), "x-ardour/plugin.info");
 	plugin_display.set_drag_column (plugin_columns.name.index());
 
 	// setting a sort-column prevents re-ordering via Drag/Drop
@@ -118,14 +117,8 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 
 	CellRendererToggle* fav_cell = dynamic_cast<CellRendererToggle*>(plugin_display.get_column_cell_renderer (0));
 	fav_cell->property_activatable() = true;
-	fav_cell->property_radio() = true;
 	fav_cell->signal_toggled().connect (sigc::mem_fun (*this, &PluginSelector::favorite_changed));
 
-	CellRendererToggle* hidden_cell = dynamic_cast<CellRendererToggle*>(plugin_display.get_column_cell_renderer (1));
-	hidden_cell->property_activatable() = true;
-	hidden_cell->property_radio() = true;
-	hidden_cell->signal_toggled().connect (sigc::mem_fun (*this, &PluginSelector::hidden_changed));
-
 	scroller.set_border_width(10);
 	scroller.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 	scroller.add(plugin_display);
@@ -136,7 +129,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	added_list.set_headers_visible (true);
 	added_list.set_reorderable (false);
 
-	for (int i = 2; i <= 7; ++i) {
+	for (int i = 1; i < 7; ++i) {
 		Gtk::TreeView::Column* column = plugin_display.get_column(i);
 		if (column) {
 			column->set_sort_column(i);
@@ -176,10 +169,10 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	_search_ignore_checkbox->set_name ("pluginlist filter button");
 
 	Gtk::Label* search_help_label1 = manage (new Label(
-		_("All search terms must be matched."), Gtk::ALIGN_LEFT));
+		_("All search terms must be matched."), Gtk::ALIGN_START));
 
 	Gtk::Label* search_help_label2 = manage (new Label(
-		_("Ex: \"ess dyn\" will find \"dynamic de-esser\" but not \"de-esser\"."), Gtk::ALIGN_LEFT));
+		_("Ex: \"ess dyn\" will find \"dynamic de-esser\" but not \"de-esser\"."), Gtk::ALIGN_START));
 
 	search_table->attach (search_entry,            0, 3, 0, 1, FILL|EXPAND, FILL);
 	search_table->attach (search_clear_button,     3, 4, 0, 1, FILL, FILL);
@@ -193,7 +186,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	search_table->set_col_spacings (4);
 	search_table->set_row_spacings (4);
 
-	Frame* search_frame = manage (new Frame);
+	Gtk::Frame* search_frame = manage (new Gtk::Frame);
 	search_frame->set_name ("BaseFrame");
 	search_frame->set_label (_("Search"));
 	search_frame->add (*search_table);
@@ -216,13 +209,17 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 
 	//_fil_type_combo = manage (new ComboBoxText);
 	_fil_type_combo.append_text_item (_("Show All Formats"));
+
+#if (defined WINDOWS_VST_SUPPORT || defined LXVST_SUPPORT || defined MACVST_SUPPORT)
 	_fil_type_combo.append_text_item (X_("VST"));
+#endif
+#ifdef VST3_SUPPORT
+	_fil_type_combo.append_text_item (X_("VST3"));
+#endif
 #ifdef AUDIOUNIT_SUPPORT
 	_fil_type_combo.append_text_item (X_("AudioUnit"));
 #endif
-#ifdef LV2_SUPPORT
 	_fil_type_combo.append_text_item (X_("LV2"));
-#endif
 	_fil_type_combo.append_text_item (X_("Lua"));
 	_fil_type_combo.append_text_item (X_("LADSPA"));
 	_fil_type_combo.set_text (_("Show All Formats"));
@@ -244,7 +241,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	filter_vbox->set_border_width (4);
 	filter_vbox->set_spacing (4);
 
-	Frame* filter_frame = manage (new Frame);
+	Gtk::Frame* filter_frame = manage (new Gtk::Frame);
 	filter_frame->set_name ("BaseFrame");
 	filter_frame->set_label (_("Filter"));
 	filter_frame->add (*filter_vbox);
@@ -273,13 +270,13 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	tag_reset_button->signal_clicked().connect (sigc::mem_fun (*this, &PluginSelector::tag_reset_button_clicked));
 
 	Gtk::Label* tagging_help_label1 = manage (new Label(
-		_("Enter space-separated, one-word Tags for the selected plugin."), Gtk::ALIGN_LEFT));
+		_("Enter space-separated, one-word Tags for the selected plugin."), Gtk::ALIGN_START));
 
 	Gtk::Label* tagging_help_label2 = manage (new Label(
-		_("You can include dashes, colons or underscores in a Tag."), Gtk::ALIGN_LEFT));
+		_("You can include dashes, colons or underscores in a Tag."), Gtk::ALIGN_START));
 
 	Gtk::Label* tagging_help_label3 = manage (new Label(
-		_("Ex: \"dynamic de-esser vocal\" applies 3 Tags."), Gtk::ALIGN_LEFT));
+		_("Ex: \"dynamic de-esser vocal\" applies 3 Tags."), Gtk::ALIGN_START));
 
 	int p = 0;
 	tagging_table->attach (*tag_entry,           0, 1, p, p+1, FILL|EXPAND, FILL);
@@ -288,7 +285,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 	tagging_table->attach (*tagging_help_label2, 0, 2, p, p+1, FILL, FILL); p++;
 	tagging_table->attach (*tagging_help_label3, 0, 2, p, p+1, FILL, FILL); p++;
 
-	Frame* tag_frame = manage (new Frame);
+	Gtk::Frame* tag_frame = manage (new Gtk::Frame);
 	tag_frame->set_name ("BaseFrame");
 	tag_frame->set_label (_("Tags for Selected Plugin"));
 	tag_frame->add (*tagging_table);
@@ -434,11 +431,13 @@ PluginSelector::show_this_plugin (const PluginInfoPtr& info, const std::string&
 		return false;
 	}
 
-#ifdef LV2_SUPPORT
+	if (_fil_type_combo.get_text() == X_("VST3") && info->type != VST3) {
+		return false;
+	}
+
 	if (_fil_type_combo.get_text() == X_("LV2") && info->type != LV2) {
 		return false;
 	}
-#endif
 
 	if (_fil_type_combo.get_text() == X_("Lua") && info->type != Lua) {
 		return false;
@@ -520,6 +519,7 @@ PluginSelector::refill ()
 	mac_vst_refiller (searchstr);
 	au_refiller (searchstr);
 	lua_refiller (searchstr);
+	vst3_refiller (searchstr);
 
 	in_row_change = false;
 
@@ -542,7 +542,6 @@ PluginSelector::refiller (const PluginInfoList& plugs, const::std::string& searc
 
 			PluginManager::PluginStatusType status = manager.get_status (*i);
 			newrow[plugin_columns.favorite] = status == PluginManager::Favorite;
-			newrow[plugin_columns.hidden] = status == PluginManager::Hidden;
 
 			string name = (*i)->name;
 			if (name.length() > 48) {
@@ -618,17 +617,11 @@ PluginSelector::lua_refiller (const std::string& searchstr)
 void
 PluginSelector::lv2_refiller (const std::string& searchstr)
 {
-#ifdef LV2_SUPPORT
 	refiller (manager.lv2_plugin_info(), searchstr, "LV2");
-#endif
 }
 
 void
-#ifdef WINDOWS_VST_SUPPORT
 PluginSelector::vst_refiller (const std::string& searchstr)
-#else
-PluginSelector::vst_refiller (const std::string&)
-#endif
 {
 #ifdef WINDOWS_VST_SUPPORT
 	refiller (manager.windows_vst_plugin_info(), searchstr, "VST");
@@ -636,11 +629,7 @@ PluginSelector::vst_refiller (const std::string&)
 }
 
 void
-#ifdef LXVST_SUPPORT
 PluginSelector::lxvst_refiller (const std::string& searchstr)
-#else
-PluginSelector::lxvst_refiller (const std::string&)
-#endif
 {
 #ifdef LXVST_SUPPORT
 	refiller (manager.lxvst_plugin_info(), searchstr, "LXVST");
@@ -648,11 +637,7 @@ PluginSelector::lxvst_refiller (const std::string&)
 }
 
 void
-#ifdef MACVST_SUPPORT
 PluginSelector::mac_vst_refiller (const std::string& searchstr)
-#else
-PluginSelector::mac_vst_refiller (const std::string&)
-#endif
 {
 #ifdef MACVST_SUPPORT
 	refiller (manager.mac_vst_plugin_info(), searchstr, "MacVST");
@@ -660,11 +645,15 @@ PluginSelector::mac_vst_refiller (const std::string&)
 }
 
 void
-#ifdef AUDIOUNIT_SUPPORT
-PluginSelector::au_refiller (const std::string& searchstr)
-#else
-PluginSelector::au_refiller (const std::string&)
+PluginSelector::vst3_refiller (const std::string& searchstr)
+{
+#ifdef VST3_SUPPORT
+	refiller (manager.vst3_plugin_info(), searchstr, "VST3");
 #endif
+}
+
+void
+PluginSelector::au_refiller (const std::string& searchstr)
 {
 #ifdef AUDIOUNIT_SUPPORT
 	refiller (manager.au_plugin_info(), searchstr, "AU");
@@ -868,7 +857,6 @@ PluginSelector::plugin_status_changed (PluginType t, std::string uid, PluginMana
 		PluginInfoPtr pp = (*i)[plugin_columns.plugin];
 		if ((pp->type == t) && (pp->unique_id == uid)) {
 			(*i)[plugin_columns.favorite] = (stat == PluginManager::Favorite) ? true : false;
-			(*i)[plugin_columns.hidden] = (stat == PluginManager::Hidden) ? true : false;
 
 			/* if plug was hidden, remove it from the view */
 			if (stat == PluginManager::Hidden || stat == PluginManager::Concealed) {
@@ -928,7 +916,7 @@ PluginSelector::plugin_menu()
 void
 PluginSelector::build_plugin_menu ()
 {
-	if (is_visible ()) {
+	if (get_visible ()) {
 		_need_menu_rebuild = true;
 		return;
 	}
@@ -937,6 +925,7 @@ PluginSelector::build_plugin_menu ()
 
 	all_plugs.insert (all_plugs.end(), manager.ladspa_plugin_info().begin(), manager.ladspa_plugin_info().end());
 	all_plugs.insert (all_plugs.end(), manager.lua_plugin_info().begin(), manager.lua_plugin_info().end());
+	all_plugs.insert (all_plugs.end(), manager.lv2_plugin_info().begin(), manager.lv2_plugin_info().end());
 #ifdef WINDOWS_VST_SUPPORT
 	all_plugs.insert (all_plugs.end(), manager.windows_vst_plugin_info().begin(), manager.windows_vst_plugin_info().end());
 #endif
@@ -946,12 +935,12 @@ PluginSelector::build_plugin_menu ()
 #ifdef MACVST_SUPPORT
 	all_plugs.insert (all_plugs.end(), manager.mac_vst_plugin_info().begin(), manager.mac_vst_plugin_info().end());
 #endif
+#ifdef VST3_SUPPORT
+	all_plugs.insert (all_plugs.end(), manager.vst3_plugin_info().begin(), manager.vst3_plugin_info().end());
+#endif
 #ifdef AUDIOUNIT_SUPPORT
 	all_plugs.insert (all_plugs.end(), manager.au_plugin_info().begin(), manager.au_plugin_info().end());
 #endif
-#ifdef LV2_SUPPORT
-	all_plugs.insert (all_plugs.end(), manager.lv2_plugin_info().begin(), manager.lv2_plugin_info().end());
-#endif
 
 	using namespace Menu_Helpers;
 
@@ -966,7 +955,7 @@ PluginSelector::build_plugin_menu ()
 	Gtk::Menu* favs = create_favs_menu(all_plugs);
 	items.push_back (MenuElem (_("Favorites"), *manage (favs)));
 
-	items.push_back (MenuElem (_("Plugin Manager..."), sigc::mem_fun (*this, &PluginSelector::show_manager)));
+	items.push_back (MenuElem (_("Plugin Selector..."), sigc::mem_fun (*this, &PluginSelector::show_manager)));
 	items.push_back (SeparatorElem ());
 
 	Menu* charts = create_charts_menu(all_plugs);
@@ -982,29 +971,7 @@ PluginSelector::build_plugin_menu ()
 string
 GetPluginTypeStr(PluginInfoPtr info)
 {
-	string type;
-
-	switch (info->type) {
-	case LADSPA:
-		type = X_(" (LADSPA)");
-		break;
-	case AudioUnit:
-		type = X_(" (AU)");
-		break;
-	case LV2:
-		type = X_(" (LV2)");
-		break;
-	case Windows_VST:
-	case LXVST:
-	case MacVST:
-		type = X_(" (VST)");
-		break;
-	case Lua:
-		type = X_(" (Lua)");
-		break;
-	}
-
-	return type;
+	return string_compose (" (%1)", PluginManager::plugin_type_name (info->type, false));
 }
 
 Gtk::Menu*
@@ -1212,41 +1179,46 @@ PluginSelector::favorite_changed (const std::string& path)
 	in_row_change = false;
 }
 
-void
-PluginSelector::hidden_changed (const std::string& path)
-{
-	PluginInfoPtr pi;
-
-	if (in_row_change) {
-		return;
-	}
-
-	in_row_change = true;
-
-	TreeModel::iterator iter = plugin_model->get_iter (path);
-
-	if (iter) {
-
-		bool hidden = !(*iter)[plugin_columns.hidden];
-
-		/* change state */
-
-		PluginManager::PluginStatusType status = (hidden ? PluginManager::Hidden : PluginManager::Normal);
-
-		/* save new statuses list */
-
-		pi = (*iter)[plugin_columns.plugin];
-
-		manager.set_status (pi->type, pi->unique_id, status);
-
-		_need_status_save = true;
-	}
-	in_row_change = false;
-}
-
 void
 PluginSelector::show_manager ()
 {
+	bool scan_now = false;
+	if (!manager.cache_valid ()) {
+		ArdourMessageDialog q (
+#ifdef __APPLE__
+				_("Scan VST2/3 and AudioUnit plugins now?")
+#else
+				_("Scan VST2/3 Plugins now?")
+#endif
+				, false, MESSAGE_QUESTION, BUTTONS_YES_NO);
+
+		q.set_title (string_compose (_("Discover %1 Plugins?"),
+#ifdef __APPLE__
+					_("VST/AU")
+#else
+					_("VST")
+#endif
+					));
+
+		q.set_secondary_text (string_compose (_("Third party plugins have not yet been indexed. %1 plugins have to be scanned before they can be used. This can also be done manually from Window > Plugin Manager. Depending on the number of installed plugins the process can take several minutes."),
+#ifdef __APPLE__
+					_("AudioUnit and VST")
+#else
+					_("VST")
+#endif
+					));
+
+		if (q.run () == RESPONSE_YES) {
+			scan_now = true;
+		}
+	}
+
+	if (scan_now) {
+		PluginScanDialog psd (false, true);
+		psd.start ();
+		ARDOUR_UI::instance()->show_plugin_manager ();
+	}
+
 	show_all();
 	run ();
 }
