@@ -34,6 +34,7 @@
 #include "ardour/auditioner.h"
 #include "ardour/bundle.h"
 #include "ardour/control_protocol_manager.h"
+#include "ardour/io_plug.h"
 #include "ardour/io_processor.h"
 #include "ardour/midi_port.h"
 #include "ardour/midiport_manager.h"
@@ -346,12 +347,14 @@ PortGroupList::gather (ARDOUR::Session* session, ARDOUR::DataType type, bool inp
 		return;
 	}
 
-	boost::shared_ptr<PortGroup> bus (new PortGroup (string_compose (_("%1 Busses"), PROGRAM_NAME)));
-	boost::shared_ptr<PortGroup> track (new PortGroup (string_compose (_("%1 Tracks"), PROGRAM_NAME)));
-	boost::shared_ptr<PortGroup> sidechain (new PortGroup (string_compose (_("%1 Sidechains"), PROGRAM_NAME)));
+	boost::shared_ptr<PortGroup> bus (new PortGroup (_("Busses")));
+	boost::shared_ptr<PortGroup> track (new PortGroup (("Tracks")));
+	boost::shared_ptr<PortGroup> sidechain (new PortGroup (_("Sidechains")));
+	boost::shared_ptr<PortGroup> iop_pre  (new PortGroup (_("I/O Pre") ));
+	boost::shared_ptr<PortGroup> iop_post (new PortGroup (_("I/O Post") ));
 	boost::shared_ptr<PortGroup> system (new PortGroup (_("Hardware")));
 	boost::shared_ptr<PortGroup> program (new PortGroup (string_compose (_("%1 Misc"), PROGRAM_NAME)));
-	boost::shared_ptr<PortGroup> other (new PortGroup (_("Other")));
+	boost::shared_ptr<PortGroup> other (new PortGroup (_("External")));
 
 	/* Find the IOs which have bundles for routes and their processors.  We store
 	   these IOs in a RouteIOs class so that we can then sort the results by route
@@ -562,6 +565,20 @@ PortGroupList::gather (ARDOUR::Session* session, ARDOUR::DataType type, bool inp
 		program->add_bundle (sync);
 	}
 
+	for (auto const& iop : *session->io_plugs ()) {
+		boost::shared_ptr<IO> io = inputs ? iop->input() : iop->output();
+		if (io->n_ports().n_total () == 0) {
+			continue;
+		}
+		if (type == DataType::NIL || io->n_ports().get (type) > 0) {
+			if (iop->is_pre ()) {
+				iop_pre->add_bundle (io->bundle(), io);
+			} else {
+				iop_post->add_bundle (io->bundle(), io);
+			}
+		}
+	}
+
 	/* Now find all other ports that we haven't thought of yet */
 
 	std::vector<std::string> extra_system[DataType::num_types];
@@ -603,6 +620,8 @@ PortGroupList::gather (ARDOUR::Session* session, ARDOUR::DataType type, bool inp
 			        !system->has_port(p)
 			     && !bus->has_port(p)
 			     && !track->has_port(p)
+			     && !iop_pre->has_port(p)
+			     && !iop_post->has_port(p)
 			     && !sidechain->has_port(p)
 			     && !program->has_port(p)
 			     && !other->has_port(p)
@@ -678,8 +697,7 @@ PortGroupList::gather (ARDOUR::Session* session, ARDOUR::DataType type, bool inp
 
 	for (DataType::iterator i = DataType::begin(); i != DataType::end(); ++i) {
 		if (!extra_system[*i].empty()) {
-			boost::shared_ptr<Bundle> b = make_bundle_from_ports (extra_system[*i], *i, inputs);
-			system->add_bundle (b, allow_dups);
+			add_bundles_for_ports (extra_system[*i], *i, inputs, allow_dups, system);
 		}
 	}
 
@@ -693,39 +711,58 @@ PortGroupList::gather (ARDOUR::Session* session, ARDOUR::DataType type, bool inp
 
 	for (DataType::iterator i = DataType::begin(); i != DataType::end(); ++i) {
 		if (extra_other[*i].empty()) continue;
-		std::string cp;
-		std::vector<std::string> nb;
-		for (uint32_t j = 0; j < extra_other[*i].size(); ++j) {
-			std::string nn = extra_other[*i][j];
-			std::string pf = nn.substr (0, nn.find_first_of (":") + 1);
-			if (pf != cp && !nb.empty()) {
-				boost::shared_ptr<Bundle> b = make_bundle_from_ports (nb, *i, inputs);
-				other->add_bundle (b);
-				nb.clear();
-			}
-			cp = pf;
-			nb.push_back(extra_other[*i][j]);
-		}
-		if (!nb.empty()) {
-			boost::shared_ptr<Bundle> b = make_bundle_from_ports (nb, *i, inputs);
-			other->add_bundle (b);
-		}
+		add_bundles_for_ports (extra_other[*i], *i, inputs, allow_dups, other);
 	}
 
 	if (!allow_dups) {
 		system->remove_duplicates ();
 	}
 
-	add_group_if_not_empty (other);
 	add_group_if_not_empty (bus);
 	add_group_if_not_empty (track);
 	add_group_if_not_empty (sidechain);
+	add_group_if_not_empty (iop_pre);
+	add_group_if_not_empty (iop_post);
 	add_group_if_not_empty (program);
+	add_group_if_not_empty (other);
 	add_group_if_not_empty (system);
 
 	emit_changed ();
 }
 
+void
+PortGroupList::add_bundles_for_ports (std::vector<std::string> const & p, ARDOUR::DataType type, bool inputs, bool allow_dups, boost::shared_ptr<PortGroup> group) const
+{
+	bool has_colon = true, has_slash = true;
+	for (const auto& s : p) {
+		if (s.find('/') == std::string::npos) has_slash = false;
+		if (s.find(':') == std::string::npos) has_colon = false;
+	}
+	std::string sep = has_slash ? "/" : has_colon ? ":" : "";
+	if (sep.empty()) {
+		boost::shared_ptr<Bundle> b = make_bundle_from_ports (p, type, inputs);
+		group->add_bundle (b, allow_dups);
+		return;
+	}
+
+	std::vector<std::string> nb;
+	std::string cp;
+	for (const auto& s : p) {
+		std::string pf = s.substr (0, s.find_first_of (sep) + 1);
+		if (pf != cp && !nb.empty()) {
+				boost::shared_ptr<Bundle> b = make_bundle_from_ports (nb, type, inputs);
+				group->add_bundle (b, allow_dups);
+				nb.clear();			
+		}
+		cp = pf;
+		nb.push_back(s);
+	}
+	if (!nb.empty()) {
+		boost::shared_ptr<Bundle> b = make_bundle_from_ports (nb, type, inputs);
+		group->add_bundle (b, allow_dups);
+	}
+}
+
 boost::shared_ptr<Bundle>
 PortGroupList::make_bundle_from_ports (std::vector<std::string> const & p, ARDOUR::DataType type, bool inputs, std::string const& bundle_name) const
 {
