@@ -70,7 +70,6 @@ class RegionSelection;
 class Selectable;
 class AutomationTimeAxisView;
 class AutomationLine;
-class ProcessorAutomationLine;
 class TimeSelection;
 class RouteGroupMenu;
 class ItemCounts;
@@ -94,24 +93,26 @@ public:
 	void set_button_names ();
 
 	void set_samples_per_pixel (double);
-	void set_height (uint32_t h, TrackHeightMode m = OnlySelf);
-	void show_timestretch (samplepos_t start, samplepos_t end, int layers, int layer);
+	void set_height (uint32_t h, TrackHeightMode m = OnlySelf, bool from_idle = false);
+	void show_timestretch (Temporal::timepos_t const & start, Temporal::timepos_t const & end, int layers, int layer);
 	void hide_timestretch ();
 	void selection_click (GdkEventButton*);
 	void set_selected_points (PointSelection&);
 	void set_selected_regionviews (RegionSelection&);
-	void get_selectables (ARDOUR::samplepos_t start, ARDOUR::samplepos_t end, double top, double bot, std::list<Selectable *>&, bool within = false);
+	void get_selectables (Temporal::timepos_t const &, Temporal::timepos_t const &, double top, double bot, std::list<Selectable *>&, bool within = false);
 	void get_inverted_selectables (Selection&, std::list<Selectable*>&);
-	void set_layer_display (LayerDisplay d);
+	void get_regionviews_at_or_after (Temporal::timepos_t const &, RegionSelection&);
+
+	virtual void set_layer_display (LayerDisplay d);
 	void toggle_layer_display ();
 	LayerDisplay layer_display () const;
 
-	boost::shared_ptr<ARDOUR::Region> find_next_region (samplepos_t pos, ARDOUR::RegionPoint, int32_t dir);
-	samplepos_t find_next_region_boundary (samplepos_t pos, int32_t dir);
+	boost::shared_ptr<ARDOUR::Region> find_next_region (ARDOUR::timepos_t const & pos, ARDOUR::RegionPoint, int32_t dir);
+	ARDOUR::timepos_t find_next_region_boundary (ARDOUR::timepos_t const & pos, int32_t dir);
 
 	/* Editing operations */
 	void cut_copy_clear (Selection&, Editing::CutCopyOp);
-	bool paste (ARDOUR::samplepos_t, const Selection&, PasteContext& ctx, const int32_t sub_num);
+	bool paste (Temporal::timepos_t const &, const Selection&, PasteContext& ctx);
 	RegionView* combine_regions ();
 	void uncombine_regions ();
 	void uncombine_region (RegionView*);
