@@ -119,6 +119,7 @@ public:
 	boost::shared_ptr<ARDOUR::MidiTrack>  midi_track () const;
 
 	Gdk::Color route_color () const;
+	Gdk::Color route_color_tint () const;
 
 	// protected: XXX sigh this should be here
 	// callbacks used by dervice classes via &RouteUI::*
@@ -217,7 +218,10 @@ protected:
 
 	static void delete_ioselector (IOSelectorMap&, boost::shared_ptr<ARDOUR::Route>);
 
+	static void help_count_plugins (boost::weak_ptr<ARDOUR::Processor> p, uint32_t*);
+
 	PBD::ScopedConnectionList route_connections;
+	PBD::ScopedConnectionList send_connections;
 	bool                      self_destruct;
 
 	void init ();
@@ -235,7 +239,8 @@ protected:
 	virtual void bus_send_display_changed (boost::shared_ptr<ARDOUR::Route>);
 
 	bool mark_hidden (bool yn);
-	void set_invert_sensitive (bool);
+	void setup_invert_buttons ();
+	void update_phase_invert_sensitivty ();
 	bool verify_new_route_name (const std::string& name);
 	void check_rec_enable_sensitivity ();
 	void route_gui_changed (PBD::PropertyChange const&);
@@ -259,7 +264,6 @@ protected:
 	ARDOUR::SoloMuteRelease* _mute_release;
 
 private:
-	void setup_invert_buttons ();
 	void invert_menu_toggled (uint32_t);
 	bool invert_press (GdkEventButton*);
 	bool invert_release (GdkEventButton*, uint32_t i);
@@ -271,6 +275,7 @@ private:
 	void update_solo_display ();
 	void update_mute_display ();
 	void update_polarity_display ();
+	void update_polarity_tooltips ();
 	void update_solo_button ();
 	void solo_changed_so_update_mute ();
 	void session_rec_enable_changed ();
