@@ -28,13 +28,12 @@
 
 #include <gtkmm.h>
 
+#include <gtkmm2ext/colors.h>
 #include <gtkmm2ext/gtk_ui.h>
 #include <gtkmm2ext/utils.h>
 
-#include "ardour/playlist.h"
 #include "ardour/region.h"
 #include "ardour/track.h"
-#include "ardour/session.h"
 
 #include "pbd/compose.h"
 
@@ -48,16 +47,13 @@
 #include "selection.h"
 #include "public_editor.h"
 #include "timers.h"
-#include "rgb_macros.h"
 #include "gui_thread.h"
 #include "ui_config.h"
-#include "utils.h"
 
 #include "pbd/i18n.h"
 
 using namespace std;
 using namespace ARDOUR;
-using namespace ARDOUR_UI_UTILS;
 using namespace PBD;
 using namespace Editing;
 
@@ -122,7 +118,7 @@ StreamView::set_height (double h)
 {
 	/* limit the values to something sane-ish */
 
-	if (h < 10.0 || h > 1000.0) {
+	if (h < 10.0 || h > 2500.0) {
 		return -1;
 	}
 
@@ -247,8 +243,6 @@ StreamView::layer_regions()
 			region_views.erase (i);
 			i = tmp;
 			continue;
-		} else {
-			(*i)->enable_display(true);
 		}
 
 		if (copy.size() == 0) {
@@ -323,7 +317,7 @@ StreamView::playlist_switched (boost::weak_ptr<Track> wtr)
 	/* disconnect from old playlist */
 
 	playlist_connections.drop_connections ();
-	//undisplay_track ();
+	undisplay_track ();
 
 	/* draw it */
 	tr->playlist()->freeze();
@@ -342,11 +336,10 @@ StreamView::playlist_switched (boost::weak_ptr<Track> wtr)
 	tr->playlist()->ContentsChanged.connect (playlist_connections, invalidator (*this), boost::bind (&StreamView::update_coverage_frame, this), gui_context());
 }
 
-
 void
 StreamView::apply_color (Gdk::Color const& c, ColorTarget target)
 {
-	return apply_color (gdk_color_to_rgba (c), target);
+	return apply_color (Gtkmm2ext::gdk_color_to_rgba (c), target);
 }
 
 void
@@ -541,7 +534,7 @@ StreamView::set_selected_regionviews (RegionSelection& regions)
  *  @param result Filled in with selectable things.
  */
 void
-StreamView::get_selectables (samplepos_t start, samplepos_t end, double top, double bottom, list<Selectable*>& results, bool within)
+StreamView::get_selectables (timepos_t const & start, timepos_t const & end, double top, double bottom, list<Selectable*>& results, bool within)
 {
 	if (_trackview.editor().internal_editing()) {
 		return;  // Don't select regions with an internal tool
@@ -579,11 +572,11 @@ StreamView::get_selectables (samplepos_t start, samplepos_t end, double top, dou
 		}
 
 		if (within) {
-			if ((*i)->region()->coverage (start, end) == Evoral::OverlapExternal && layer_ok) {
+			if ((*i)->region()->coverage (start, end) == Temporal::OverlapExternal && layer_ok) {
 				results.push_back (*i);
 			}
 		} else {
-			if ((*i)->region()->coverage (start, end) != Evoral::OverlapNone && layer_ok) {
+			if ((*i)->region()->coverage (start, end) != Temporal::OverlapNone && layer_ok) {
 				results.push_back (*i);
 			}
 		}
@@ -601,6 +594,16 @@ StreamView::get_inverted_selectables (Selection& sel, list<Selectable*>& results
 	}
 }
 
+void
+StreamView::get_regionviews_at_or_after (timepos_t const & pos, RegionSelection& regions)
+{
+	for (list<RegionView*>::iterator i = region_views.begin(); i != region_views.end(); ++i) {
+		if ((*i)->region()->position() >= pos) {
+			regions.push_back (*i);
+		}
+	}
+}
+
 /** @return height of a child region view, depending on stacked / overlaid mode */
 double
 StreamView::child_height () const
@@ -709,7 +712,7 @@ StreamView::setup_new_rec_layer_time (boost::shared_ptr<Region> region)
 	   top-layered region after the start of the region we are recording and make a note of it.
 	*/
 	if (_layer_display == Stacked) {
-		_new_rec_layer_time = _trackview.track()->playlist()->find_next_top_layer_position (region->position());
+		_new_rec_layer_time = _trackview.track()->playlist()->find_next_top_layer_position (region->position()).samples();
 	} else {
 		_new_rec_layer_time = max_samplepos;
 	}
