@@ -75,6 +75,7 @@ unsigned char* xpm2rgba (const char** xpm, uint32_t& w, uint32_t& h);
 ArdourCanvas::Points* get_canvas_points (std::string who, uint32_t npoints);
 
 Pango::FontDescription sanitized_font (std::string const&);
+Pango::FontDescription ardour_font (std::string const&);
 Pango::FontDescription get_font_for_style (std::string widgetname);
 
 void decorate (Gtk::Window& w, Gdk::WMDecoration d);
@@ -97,6 +98,7 @@ void resize_window_to_proportion_of_monitor (Gtk::Window*, int, int);
 
 std::string escape_underscores (std::string const &);
 
+Gdk::Color unique_palette_color (std::list<Gdk::Color> &);
 Gdk::Color unique_random_color (std::list<Gdk::Color> &);
 
 std::string rate_as_string (float r);
