@@ -24,7 +24,6 @@
 
 #include "pbd/unwind.h"
 
-#include "ardour/plugin_insert.h"
 #include "ardour/vst3_plugin.h"
 
 #include "gtkmm2ext/gui_thread.h"
@@ -37,8 +36,8 @@ using namespace ARDOUR;
 using namespace Steinberg;
 
 
-VST3HWNDPluginUI::VST3HWNDPluginUI (boost::shared_ptr<PluginInsert> pi, boost::shared_ptr<VST3Plugin> vst3)
-	: VST3PluginUI (pi, vst3)
+VST3HWNDPluginUI::VST3HWNDPluginUI (boost::shared_ptr<PlugInsertBase> pib, boost::shared_ptr<VST3Plugin> vst3)
+	: VST3PluginUI (pib, vst3)
 {
 	/* TODO register window class, implement wndproc etc */
 
