@@ -48,7 +48,8 @@ class LIBARDOUR_API AnalysisGraph {
 		void analyze_region (ARDOUR::AudioRegion const*, bool raw = false, ARDOUR::Progress* = 0);
 		void analyze_region (boost::shared_ptr<ARDOUR::AudioRegion>, bool raw = false);
 
-		void analyze_range (boost::shared_ptr<ARDOUR::Route>, boost::shared_ptr<ARDOUR::AudioPlaylist>, const std::list<AudioRange>&);
+		void analyze_range (boost::shared_ptr<ARDOUR::Route>, boost::shared_ptr<ARDOUR::AudioPlaylist>, const std::list<TimelineRange>&);
+
 		const AnalysisResults& results () const { return _results; }
 
 		void cancel () { _canceled = true; }
