@@ -118,7 +118,7 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 	bool           is_realtime() const;
 
 	// for the user which hold state_lock to check if reset operation is pending
-	bool           is_reset_requested() const { return g_atomic_int_get (&_hw_reset_request_count); }
+	bool           is_reset_requested() const { return g_atomic_int_get (const_cast<GATOMIC_QUAL gint*> (&_hw_reset_request_count)); }
 
 	int set_device_name (const std::string&);
 	int set_sample_rate (float);
@@ -135,7 +135,7 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 	bool running() const { return _running; }
 
 	Glib::Threads::Mutex& process_lock() { return _process_lock; }
-	Glib::Threads::RecMutex& state_lock() { return _state_lock; }
+	Glib::Threads::Mutex& latency_lock() { return _latency_lock; }
 
 	int request_buffer_size (pframes_t samples) {
 		return set_buffer_size (samples);
@@ -198,6 +198,7 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 
 	static AudioEngine* instance() { return _instance; }
 	static void destroy();
+
 	void died ();
 
 	/* The backend will cause these at the appropriate time(s) */
@@ -264,6 +265,7 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 	static AudioEngine*       _instance;
 
 	Glib::Threads::Mutex       _process_lock;
+	Glib::Threads::Mutex       _latency_lock;
 	Glib::Threads::RecMutex    _state_lock;
 	Glib::Threads::Cond        session_removed;
 	bool                       session_remove_pending;
@@ -278,7 +280,6 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 	samplecnt_t                last_monitor_check;
 	/// the number of samples processed since start() was called
 	samplecnt_t               _processed_samples;
-	Glib::Threads::Thread*     m_meter_thread;
 	ProcessThread*            _main_thread;
 	MTDM*                     _mtdm;
 	MIDIDM*                   _mididm;
@@ -295,12 +296,12 @@ class LIBARDOUR_API AudioEngine : public PortManager, public SessionHandlePtr
 
 	std::string               _last_backend_error_string;
 
-	Glib::Threads::Thread*    _hw_reset_event_thread;
+	PBD::Thread*              _hw_reset_event_thread;
 	GATOMIC_QUAL gint         _hw_reset_request_count;
 	Glib::Threads::Cond       _hw_reset_condition;
 	Glib::Threads::Mutex      _reset_request_lock;
 	GATOMIC_QUAL gint         _stop_hw_reset_processing;
-	Glib::Threads::Thread*    _hw_devicelist_update_thread;
+	PBD::Thread*              _hw_devicelist_update_thread;
 	GATOMIC_QUAL gint         _hw_devicelist_update_count;
 	Glib::Threads::Cond       _hw_devicelist_update_condition;
 	Glib::Threads::Mutex      _devicelist_update_lock;
