@@ -27,14 +27,14 @@ namespace ARDOUR {
 
 class Session;
 
-class LIBARDOUR_API AudioRom : public Readable
+class LIBARDOUR_API AudioRom : public AudioReadable
 {
 public:
 	static boost::shared_ptr<AudioRom> new_rom (Sample*, size_t);
 	~AudioRom();
 
 	samplecnt_t read (Sample*, samplepos_t pos, samplecnt_t cnt, int channel) const;
-	samplecnt_t readable_length() const { return _size; }
+	samplecnt_t readable_length_samples() const { return _size; }
 	uint32_t  n_channels () const { return 1; }
 
 private:
