@@ -39,7 +39,7 @@ public:
 	bool add_impdata (
 	    uint32_t                    c_in,
 	    uint32_t                    c_out,
-	    boost::shared_ptr<Readable> r,
+	    boost::shared_ptr<AudioReadable> r,
 	    float                       gain      = 1.0,
 	    uint32_t                    pre_delay = 0,
 	    sampleoffset_t              offset    = 0,
@@ -51,9 +51,13 @@ public:
 	uint32_t n_inputs () const  { return _n_inputs; }
 	uint32_t n_outputs () const { return _n_outputs; }
 
+	void clear_impdata ();
 	void restart ();
 	void run (BufferSet&, ChanMapping const&, ChanMapping const&, pframes_t, samplecnt_t);
 
+	void run_mono_buffered (float*, uint32_t);
+	void run_mono_no_latency (float*, uint32_t);
+
 protected:
 	ArdourZita::Convproc _convproc;
 
@@ -64,10 +68,10 @@ protected:
 	bool     _threaded;
 
 private:
-	class ImpData : public Readable
+	class ImpData : public AudioReadable
 	{
 	public:
-		ImpData (uint32_t ci, uint32_t co, boost::shared_ptr<Readable> r, float g, float d, sampleoffset_t s = 0, samplecnt_t l = 0, uint32_t c = 0)
+		ImpData (uint32_t ci, uint32_t co, boost::shared_ptr<AudioReadable> r, float g, float d, sampleoffset_t s = 0, samplecnt_t l = 0, uint32_t c = 0)
 		    : c_in (ci)
 		    , c_out (co)
 		    , gain (g)
@@ -87,8 +91,8 @@ private:
 			return _readable->read (s, pos + _offset, cnt, _channel);
 		}
 
-		samplecnt_t readable_length () const {
-			samplecnt_t rl = _readable->readable_length ();
+		samplecnt_t readable_length_samples () const {
+			samplecnt_t rl = _readable->readable_length_samples ();
 			if (rl < _offset) {
 				return 0;
 			} else if (_length > 0) {
@@ -103,7 +107,7 @@ private:
 		}
 
 	private:
-		boost::shared_ptr<Readable> _readable;
+		boost::shared_ptr<AudioReadable> _readable;
 
 		sampleoffset_t _offset;
 		samplecnt_t    _length;
@@ -172,7 +176,7 @@ public:
 	void run_stereo_no_latency (float* L, float* R, uint32_t);
 
 private:
-	std::vector<boost::shared_ptr<Readable> > _readables;
+	std::vector<boost::shared_ptr<AudioReadable> > _readables;
 
 	IRChannelConfig _irc;
 	IRSettings      _ir_settings;
