@@ -29,39 +29,6 @@ namespace PBD {
 
 DEFINE_ENUM_CONVERT(Evoral::ControlList::InterpolationStyle)
 
-template <>
-inline bool to_string (Temporal::Beats beats, std::string& str)
-{
-	return double_to_string (beats.to_double (), str);
-}
-
-template <>
-inline bool string_to (const std::string& str, Temporal::Beats& beats)
-{
-	double tmp;
-	if (!string_to_double (str, tmp)) {
-		return false;
-	}
-	beats = Temporal::Beats(tmp);
-	return true;
-}
-
-template <>
-inline std::string to_string (Temporal::Beats beats)
-{
-	std::string tmp;
-	double_to_string (beats.to_double (), tmp);
-	return tmp;
-}
-
-template <>
-inline Temporal::Beats string_to (const std::string& str)
-{
-	double tmp;
-	string_to_double (str, tmp);
-	return Temporal::Beats (tmp);
-}
-
 } // namespace PBD
 
 #endif // ARDOUR_EVORAL_TYPES_CONVERT_H
