@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2010-2011 David Robillard <d@drobilla.net>
  * Copyright (C) 2011 Carl Hetherington <carl@carlh.net>
- * Copyright (C) 2015-2019 Robin Gareus <robin@gareus.org>
+ * Copyright (C) 2015-2022 Robin Gareus <robin@gareus.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,56 +22,82 @@
 #define __ardour_graphnode_h__
 
 #include <list>
+#include <map>
 #include <set>
-#include <vector>
 
 #include <boost/shared_ptr.hpp>
 
 #include "pbd/g_atomic_compat.h"
+#include "pbd/rcu.h"
+
+#include "ardour/libardour_visibility.h"
 
 namespace ARDOUR
 {
 class Graph;
 class GraphNode;
+struct GraphChain;
 
 typedef boost::shared_ptr<GraphNode> node_ptr_t;
 typedef std::set<node_ptr_t>         node_set_t;
 typedef std::list<node_ptr_t>        node_list_t;
 
+class LIBARDOUR_API ProcessNode
+{
+public:
+	virtual ~ProcessNode() {}
+	virtual void prep (GraphChain const*) = 0;
+	virtual void run (GraphChain const*) = 0;
+};
+
 class LIBARDOUR_API GraphActivision
 {
+public:
+	GraphActivision ();
+	virtual ~GraphActivision () {}
+
+	typedef std::map<GraphChain const*, node_set_t> ActivationMap;
+	typedef std::map<GraphChain const*, int>        RefCntMap;
+
+	node_set_t const& activation_set (GraphChain const* const g) const;
+	int               init_refcount (GraphChain const* const g) const;
+
 protected:
-	friend class Graph;
+	friend struct GraphChain;
+
 	/** Nodes that we directly feed */
-	node_set_t _activation_set[2];
+	SerializedRCUManager<ActivationMap> _activation_set;
 	/** The number of nodes that we directly feed us (one count for each chain) */
-	gint _init_refcount[2];
+	SerializedRCUManager<RefCntMap> _init_refcount;
 };
 
 /** A node on our processing graph, ie a Route */
-class LIBARDOUR_API GraphNode : public GraphActivision
+class LIBARDOUR_API GraphNode : public ProcessNode, public GraphActivision
 {
 public:
 	GraphNode (boost::shared_ptr<Graph> Graph);
-	virtual ~GraphNode ();
 
-	void prep (int chain);
+	/* API used by Graph */
+	void prep (GraphChain const*);
+	void run (GraphChain const*);
+
+	/* API used to sort Nodes and create GraphChain */
+	virtual std::string graph_node_name () const = 0;
+
+	virtual bool direct_feeds_according_to_reality (boost::shared_ptr<GraphNode>, bool* via_send_only = 0) = 0;
+
+protected:
 	void trigger ();
-
-	void
-	run (int chain)
-	{
-		process ();
-		finish (chain);
-	}
-
-private:
-	void finish (int chain);
-	void process ();
+	virtual void process () = 0;
 
 	boost::shared_ptr<Graph> _graph;
-	GATOMIC_QUAL gint        _refcount;
+
+private:
+	void finish (GraphChain const*);
+
+	GATOMIC_QUAL gint _refcount;
 };
-}
+
+} // namespace ARDOUR
 
 #endif
