@@ -33,9 +33,10 @@
 
 #include "pbd/command.h"
 
+#include "ardour/libardour_visibility.h"
+#include "ardour/automation_list.h"
 #include "ardour/automatable_sequence.h"
-#include "ardour/libardour_visibility.h"
-#include "ardour/libardour_visibility.h"
+#include "ardour/source.h"
 #include "ardour/types.h"
 #include "ardour/types.h"
 #include "ardour/variant.h"
@@ -59,10 +60,7 @@ class LIBARDOUR_API MidiModel : public AutomatableSequence<Temporal::Beats> {
 public:
 	typedef Temporal::Beats TimeType;
 
-	MidiModel (boost::shared_ptr<MidiSource>);
-
-	NoteMode note_mode() const { return (percussive() ? Percussive : Sustained); }
-	void set_note_mode(NoteMode mode) { set_percussive(mode == Percussive); };
+	MidiModel (MidiSource&);
 
 	class LIBARDOUR_API DiffCommand : public Command {
 	public:
@@ -75,7 +73,7 @@ public:
 		virtual void undo () = 0;
 
 		virtual int set_state (const XMLNode&, int version) = 0;
-		virtual XMLNode & get_state () = 0;
+		virtual XMLNode & get_state () const = 0;
 
 		boost::shared_ptr<MidiModel> model() const { return _model; }
 
@@ -103,7 +101,7 @@ public:
 		void undo ();
 
 		int set_state (const XMLNode&, int version);
-		XMLNode & get_state ();
+		XMLNode & get_state () const;
 
 		void add (const NotePtr note);
 		void remove (const NotePtr note);
@@ -151,10 +149,10 @@ public:
 
 		std::set<NotePtr> side_effect_removals;
 
-		XMLNode &marshal_change(const NoteChange&);
+		XMLNode &marshal_change(const NoteChange&) const;
 		NoteChange unmarshal_change(XMLNode *xml_note);
 
-		XMLNode &marshal_note(const NotePtr note);
+		XMLNode &marshal_note(const NotePtr note) const;
 		NotePtr unmarshal_note(XMLNode *xml_note);
 	};
 
@@ -168,7 +166,7 @@ public:
 		};
 
 		int set_state (const XMLNode&, int version);
-		XMLNode & get_state ();
+		XMLNode & get_state () const;
 
 		void remove (SysExPtr sysex);
 		void operator() ();
@@ -191,7 +189,7 @@ public:
 
 		std::list<SysExPtr> _removed;
 
-		XMLNode & marshal_change (const Change &);
+		XMLNode & marshal_change (const Change &) const;
 		Change unmarshal_change (XMLNode *);
 	};
 
@@ -201,7 +199,7 @@ public:
 		PatchChangeDiffCommand (boost::shared_ptr<MidiModel>, const XMLNode &);
 
 		int set_state (const XMLNode &, int version);
-		XMLNode & get_state ();
+		XMLNode & get_state () const;
 
 		void operator() ();
 		void undo ();
@@ -247,10 +245,10 @@ public:
 		std::list<PatchChangePtr> _added;
 		std::list<PatchChangePtr> _removed;
 
-		XMLNode & marshal_change (const Change &);
+		XMLNode & marshal_change (const Change &) const;
 		Change unmarshal_change (XMLNode *);
 
-		XMLNode & marshal_patch_change (constPatchChangePtr);
+		XMLNode & marshal_patch_change (constPatchChangePtr) const;
 		PatchChangePtr unmarshal_patch_change (XMLNode *);
 	};
 
@@ -258,7 +256,7 @@ public:
 	 *
 	 * This has no side-effects on the model or Session, the returned command
 	 * can be held on to for as long as the caller wishes, or discarded without
-	 * formality, until apply_command is called and ownership is taken.
+	 * formality, until apply_diff_command_* is called and ownership is taken.
 	 */
 	MidiModel::NoteDiffCommand* new_note_diff_command (const std::string& name = "midi edit");
 	/** Start a new SysExDiff command */
@@ -270,40 +268,44 @@ public:
 	/** Apply a command.
 	 *
 	 * Ownership of cmd is taken, it must not be deleted by the caller.
+	 * This STARTS and COMMITS an undo command.
 	 * The command will constitute one item on the undo stack.
 	 */
-	void apply_command (Session& session, Command* cmd);
+	void apply_diff_command_as_commit (Session& session, Command* cmd);
 
-	void apply_command (Session* session, Command* cmd) { if (session) { apply_command (*session, cmd); } }
+	void apply_diff_command_as_commit (Session* session, Command* cmd) { if (session) { apply_diff_command_as_commit (*session, cmd); } }
 
-	/** Apply a command as part of a larger reversible transaction
+	/** Add a command as part of a larger reversible transaction
 	 *
 	 * Ownership of cmd is taken, it must not be deleted by the caller.
-	 * The command will constitute one item on the undo stack.
+	 * The command will be incorporated into the current command.
 	 */
-	void apply_command_as_subcommand (Session& session, Command* cmd);
+	void apply_diff_command_as_subcommand (Session& session, Command* cmd);
 
-	bool sync_to_source (const Glib::Threads::Mutex::Lock& source_lock);
+	/** Apply the midi diff, but without any effect on undo
+	 *
+	 * Ownership of cmd is not changed.
+	 */
+	void apply_diff_command_only (Session& session, Command* cmd);
+
+	bool sync_to_source (const Source::WriterLock& source_lock);
 
 	bool write_to(boost::shared_ptr<MidiSource>     source,
-	              const Glib::Threads::Mutex::Lock& source_lock);
+	              const Source::WriterLock& source_lock);
 
 	bool write_section_to(boost::shared_ptr<MidiSource>     source,
-	                      const Glib::Threads::Mutex::Lock& source_lock,
+	                      const Source::WriterLock& source_lock,
 	                      Temporal::Beats                   begin = Temporal::Beats(),
 	                      Temporal::Beats                   end   = std::numeric_limits<Temporal::Beats>::max(),
 	                      bool                              offset_events = false);
 
 	// MidiModel doesn't use the normal AutomationList serialisation code
 	// since controller data is stored in the .mid
-	XMLNode& get_state();
+	XMLNode& get_state() const;
 	int set_state(const XMLNode&) { return 0; }
 
 	PBD::Signal0<void> ContentsChanged;
-	PBD::Signal1<void, double> ContentsShifted;
-
-	boost::shared_ptr<const MidiSource> midi_source ();
-	void set_midi_source (boost::shared_ptr<MidiSource>);
+	PBD::Signal1<void, Temporal::timecnt_t> ContentsShifted;
 
 	boost::shared_ptr<Evoral::Note<TimeType> > find_note (NotePtr);
 	PatchChangePtr find_patch_change (Evoral::event_id_t);
@@ -318,19 +320,26 @@ public:
 	void insert_silence_at_start (TimeType);
 	void transpose (NoteDiffCommand *, const NotePtr, int);
 
-protected:
+  protected:
 	int resolve_overlaps_unlocked (const NotePtr, void* arg = 0);
 
-private:
+  protected:
+	friend class NoteDiffCommand;
+	friend class SysExDiffCommand;
+	friend class PatchChangeDiffCommand;
+
+	MidiSource& midi_source() const { return _midi_source; }
+
+  private:
 	struct WriteLockImpl : public AutomatableSequence<TimeType>::WriteLockImpl {
-		WriteLockImpl(Glib::Threads::Mutex::Lock* slock, Glib::Threads::RWLock& s, Glib::Threads::Mutex& c)
+		WriteLockImpl(Source::WriterLock* slock, Glib::Threads::RWLock& s, Glib::Threads::Mutex& c)
 			: AutomatableSequence<TimeType>::WriteLockImpl(s, c)
 			, source_lock (slock)
 		{}
 		~WriteLockImpl() {
 			delete source_lock;
 		}
-		Glib::Threads::Mutex::Lock* source_lock;
+		Source::WriterLock* source_lock;
 	};
 
 public:
@@ -339,17 +348,16 @@ public:
 private:
 	friend class DeltaCommand;
 
-	void source_interpolation_changed (Evoral::Parameter, Evoral::ControlList::InterpolationStyle);
-	void source_automation_state_changed (Evoral::Parameter, AutoState);
-	void control_list_interpolation_changed (Evoral::Parameter, Evoral::ControlList::InterpolationStyle);
-	void automation_list_automation_state_changed (Evoral::Parameter, AutoState);
+	void source_interpolation_changed (Evoral::Parameter const&, AutomationList::InterpolationStyle);
+	void source_automation_state_changed (Evoral::Parameter const&, AutoState);
+	void control_list_interpolation_changed (Evoral::Parameter const&, AutomationList::InterpolationStyle);
+	void automation_list_automation_state_changed (Evoral::Parameter const&, AutoState);
 
 	void control_list_marked_dirty ();
 
 	PBD::ScopedConnectionList _midi_source_connections;
 
-	// We cannot use a boost::shared_ptr here to avoid a retain cycle
-	boost::weak_ptr<MidiSource> _midi_source;
+	MidiSource& _midi_source;
 	InsertMergePolicy _insert_merge_policy;
 };
 
