@@ -67,7 +67,7 @@ public:
 	void start_touch (timepos_t const & when);
 	void stop_touch (timepos_t const & when);
 
-	bool touching() const { return g_atomic_int_get (&_touching); }
+	bool touching() const { return g_atomic_int_get (const_cast<GATOMIC_QUAL gint*> (&_touching)); }
 
 	bool writing() const { return _auto_state == Write; }
 	bool touch_enabled() const { return _auto_state & (Touch | Latch); }
