@@ -51,7 +51,7 @@ class Pannable;
 class LIBARDOUR_API PannerShell : public SessionObject
 {
 public:
-	PannerShell (std::string name, Session&, boost::shared_ptr<Pannable>, bool is_send = false);
+	PannerShell (std::string name, Session&, boost::shared_ptr<Pannable>, Temporal::TimeDomain, bool is_send = false);
 	virtual ~PannerShell ();
 
 	std::string describe_parameter (Evoral::Parameter param);
@@ -62,7 +62,7 @@ public:
 	/// The fundamental Panner function
 	void run (BufferSet& src, BufferSet& dest, samplepos_t start_sample, samplepos_t end_samples, pframes_t nframes);
 
-	XMLNode& get_state ();
+	XMLNode& get_state () const;
 	int      set_state (const XMLNode&, int version);
 
 	PBD::Signal0<void> PannableChanged; /* Pannable changed -- l*/
