@@ -121,6 +121,16 @@ private:
 
 }; // class BackendPort
 
+class LIBARDOUR_API BackendMIDIEvent
+{
+public:
+	virtual ~BackendMIDIEvent () {}
+	virtual size_t size () const = 0;
+	virtual pframes_t timestamp () const = 0;
+	virtual const uint8_t* data () const = 0;
+	bool operator< (const BackendMIDIEvent &other) const;
+};
+
 class LIBARDOUR_API PortEngineSharedImpl
 {
 public:
@@ -209,14 +219,17 @@ protected:
 		}
 	};
 
-	typedef std::map<std::string, BackendPortPtr>    PortMap;   // fast lookup in _ports
-	typedef std::set<BackendPortPtr, SortByPortName> PortIndex; // fast lookup in _ports
-	SerializedRCUManager<PortMap>                  _portmap;
-	SerializedRCUManager<PortIndex>                _ports;
+	typedef std::map<std::string, BackendPortPtr>    PortMap;       // fast-lookup by name
+	typedef std::set<BackendPortPtr, SortByPortName> PortIndex;     // name-based
+	typedef std::set<BackendPortPtr>                 PortRegistry;  // std::less<>, safe during rename
+
+	SerializedRCUManager<PortMap>      _portmap;
+	SerializedRCUManager<PortIndex>    _ports;
+	SerializedRCUManager<PortRegistry> _portregistry;
 
 	bool valid_port (BackendPortHandle port) const {
-		boost::shared_ptr<PortIndex> p = _ports.reader ();
-		return std::find (p->begin (), p->end (), port) != p->end ();
+		boost::shared_ptr<PortRegistry> p = _portregistry.reader ();
+		return p->find (port) != p->end ();
 	}
 
 	BackendPortPtr find_port (const std::string& port_name) const {
