@@ -35,7 +35,7 @@ class Session;
 class LIBARDOUR_API RecordSafeControl : public SlavableAutomationControl
 {
   public:
-	RecordSafeControl (Session& session, std::string const & name, Recordable& m);
+	RecordSafeControl (Session& session, std::string const & name, Recordable& m, Temporal::TimeDomain td);
 	~RecordSafeControl() {}
 
   protected:
