@@ -67,6 +67,7 @@ public:
 		StartRoll,
 		EndRoll,
 		TransportStateChange,
+		SyncCues,
 
 		/* only one of each of these events can be queued at any one time */
 
@@ -90,6 +91,7 @@ public:
 		bool             yes_or_no;
 		samplepos_t      target2_sample;
 		OverwriteReason  overwrite;
+		int32_t          scene;
 	};
 
 	boost::weak_ptr<Track> track;
@@ -114,8 +116,8 @@ public:
 	RTeventCallback              rt_return;  /* called after rt_slot, with this event as an argument */
 	PBD::EventLoop*              event_loop;
 
-	std::list<AudioRange> audio_range;
-	std::list<MusicRange> music_range;
+	std::list<TimelineRange> audio_range;
+	std::list<TimelineRange> music_range;
 
 	boost::shared_ptr<Region> region;
 	boost::shared_ptr<TransportMaster> transport_master;
@@ -146,12 +148,13 @@ public:
 	static bool has_per_thread_pool ();
 	static void create_per_thread_pool (const std::string& n, uint32_t nitems);
 	static void init_event_pool ();
+	static guint pool_available ();
 
-	CrossThreadPool* event_pool() const { return own_pool; }
+	PBD::CrossThreadPool* event_pool() const { return own_pool; }
 
 private:
-	static PerThreadPool* pool;
-	CrossThreadPool* own_pool;
+	static PBD::PerThreadPool* pool;
+	PBD::CrossThreadPool*      own_pool;
 
 	friend class Butler;
 };
@@ -197,4 +200,6 @@ protected:
 
 } /* namespace */
 
+LIBARDOUR_API std::ostream& operator<<(std::ostream&, const ARDOUR::SessionEvent&);
+
 #endif /* __ardour_session_event_h__ */
