@@ -638,6 +638,7 @@ typedef std::list<boost::shared_ptr<Stripable> > StripableList;
 typedef std::list<boost::weak_ptr  <Route> > WeakRouteList;
 typedef std::list<boost::weak_ptr  <Stripable> > WeakStripableList;
 typedef std::list<boost::shared_ptr<AutomationControl> > ControlList;
+typedef std::list<boost::weak_ptr  <AutomationControl> > WeakControlList;
 typedef std::list<boost::shared_ptr<SlavableAutomationControl> > SlavableControlList;
 typedef std::set <AutomationType> AutomationTypeSet;
 
@@ -684,6 +685,12 @@ enum PluginGUIBehavior {
 	PluginGUIDestroyVST,
 };
 
+enum AppleNSGLViewMode {
+	NSGLHiRes,
+	NSGLLoRes,
+	NSGLDisable,
+};
+
 /** A struct used to describe changes to processors in a route.
  *  This is useful because objects that respond to a change in processors
  *  can optimise what work they do based on details of what has changed.
@@ -696,7 +703,8 @@ struct RouteProcessorChange {
 	enum Type {
 		MeterPointChange = 0x1,
 		RealTimeChange   = 0x2,
-		GeneralChange    = 0x4
+		GeneralChange    = 0x4,
+		SendReturnChange = 0x8
 	};
 
 	RouteProcessorChange () : type (GeneralChange), meter_visibly_changed (true)
