@@ -59,7 +59,7 @@ class LIBARDOUR_API VCA : public Stripable,
 	std::string full_name() const;
 
 	int init ();
-	XMLNode& get_state();
+	XMLNode& get_state() const;
 	int set_state (XMLNode const&, int version);
 
 	PBD::Signal0<void> Drop; /* signal to slaves to drop control by this VCA */
@@ -79,7 +79,7 @@ class LIBARDOUR_API VCA : public Stripable,
 	void push_solo_upstream (int32_t) {}
 	void push_solo_isolate_upstream (int32_t) {}
 	bool can_solo() const { return true; }
-	bool can_monitor() const { return false; }
+	bool can_monitor() const { return true; }
 	bool is_safe () const { return false; }
 
 	/* Muteable API */
