@@ -70,8 +70,8 @@ using namespace std;
 using namespace ARDOUR;
 using namespace PBD;
 
-#define S2SC(s) Temporal::samples_to_superclock (s, AudioEngine::instance()->sample_rate())
-#define SC2S(s) Temporal::superclock_to_samples (s, AudioEngine::instance()->sample_rate())
+#define S2SC(s) Temporal::samples_to_superclock (s, TEMPORAL_SAMPLE_RATE)
+#define SC2S(s) Temporal::superclock_to_samples (s, TEMPORAL_SAMPLE_RATE)
 
 namespace ARDOUR {
 	namespace Properties {
@@ -447,7 +447,13 @@ AudioRegion::read_peaks (PeakData *buf, samplecnt_t npeaks, samplecnt_t offset,
 		return 0;
 	}
 
-	if (_scale_amplitude != 1.0f) {
+	if (_scale_amplitude < 0.f) {
+		for (samplecnt_t n = 0; n < npeaks; ++n) {
+			const float tmp = buf[n].max;
+			buf[n].max = _scale_amplitude * buf[n].min;
+			buf[n].min = _scale_amplitude * tmp;
+		}
+	} else if (_scale_amplitude != 1.0f) {
 		for (samplecnt_t n = 0; n < npeaks; ++n) {
 			buf[n].max *= _scale_amplitude;
 			buf[n].min *= _scale_amplitude;
@@ -1438,6 +1444,9 @@ AudioRegion::maximum_amplitude (Progress* p) const
 			/* read it in */
 
 			if (read_raw_internal (buf, fpos, to_read, n) != to_read) {
+#ifndef NDEBUG
+				cerr << "AudioRegion::maximum_amplitude read failed for '" << _name << "'\n";
+#endif
 				return 0;
 			}
 
