@@ -193,6 +193,8 @@ Automatable::describe_parameter (Evoral::Parameter param)
 		return _("Fader");
 	} else if (param.type() == BusSendLevel) {
 		return _("Send");
+	} else if (param.type() == InsertReturnLevel) {
+		return _("Return");
 	} else if (param.type() == TrimAutomation) {
 		return _("Trim");
 	} else if (param.type() == MainOutVolume) {
@@ -561,6 +563,8 @@ Automatable::control_factory(const Evoral::Parameter& param)
 		control = new GainControl(_a_session, param);
 	} else if (param.type() == TrimAutomation) {
 		control = new GainControl(_a_session, param);
+	} else if (param.type() == InsertReturnLevel) {
+		control = new GainControl(_a_session, param);
 	} else if (param.type() == MainOutVolume) {
 		control = new GainControl(_a_session, param);
 	} else if (param.type() == BusSendLevel) {
@@ -606,6 +610,17 @@ Automatable::control_factory(const Evoral::Parameter& param)
 	return boost::shared_ptr<Evoral::Control>(control);
 }
 
+void
+Automatable::automatables (ControllableSet& s) const
+{
+	for (auto const& i : _controls) {
+		boost::shared_ptr<AutomationControl> ac = boost::dynamic_pointer_cast<AutomationControl> (i.second);
+		if (ac) {
+			s.insert (ac);
+		}
+	}
+}
+
 boost::shared_ptr<AutomationControl>
 Automatable::automation_control (PBD::ID const & id) const
 {
