@@ -95,12 +95,14 @@ AutomationControl::writable() const
 	return true;
 }
 
-/** Get the current effective `user' value based on automation state */
 double
 AutomationControl::get_value() const
 {
-	bool from_list = alist() && alist()->automation_playback();
-	return Control::get_double (from_list, _session.transport_sample());
+	/* automation_run() will have updated the value
+	 * (possibly ahead of time, according to latency compensation),
+	 * and actually_set_value() will have set the user-value accordingly.
+	 */
+	return Control::get_double();
 }
 
 double
@@ -128,7 +130,7 @@ AutomationControl::set_value (double val, PBD::Controllable::GroupControlDisposi
 	}
 
 	if (_list && !touching () && alist()->automation_state() == Latch && _session.transport_rolling ()) {
-		start_touch (_session.transport_sample ());
+		start_touch (timepos_t (_session.transport_sample ()));
 	}
 
 	/* enforce strict double/boolean value mapping */
@@ -170,7 +172,7 @@ AutomationControl::automation_run (samplepos_t start, pframes_t nframes)
 
 	assert (_list);
 	bool valid = false;
-	double val = _list->rt_safe_eval (start, valid);
+	double val = _list->rt_safe_eval (timepos_t (start), valid);
 	if (!valid) {
 		return;
 	}
@@ -208,7 +210,7 @@ AutomationControl::actually_set_value (double value, PBD::Controllable::GroupCon
 	   anything has changed) is the one derived from the automation event
 	   list.
 	*/
-	float old_value = Control::user_double();
+	float old_value = Control::get_double();
 
 	if (al && al->automation_write ()) {
 		to_list = true;
@@ -216,7 +218,7 @@ AutomationControl::actually_set_value (double value, PBD::Controllable::GroupCon
 		to_list = false;
 	}
 
-	Control::set_double (value, pos, to_list);
+	Control::set_double (value, timepos_t (pos), to_list);
 
 	if (old_value != (float)value) {
 #if 0
@@ -255,8 +257,13 @@ AutomationControl::set_automation_state (AutoState as)
 			AutomationWatch::instance().add_automation_watch (boost::dynamic_pointer_cast<AutomationControl>(shared_from_this()));
 		} else if (as & (Touch | Latch)) {
 			if (alist()->empty()) {
-				Control::set_double (val, _session.current_start_sample (), true);
-				Control::set_double (val, _session.current_end_sample (), true);
+				if (alist()->time_domain() == Temporal::AudioTime) {
+					Control::set_double (val, timepos_t (_session.current_start ().samples()), true);
+					Control::set_double (val, timepos_t (_session.current_end ().samples()), true);
+				} else {
+					Control::set_double (val, timepos_t (_session.current_start ().beats()), true);
+					Control::set_double (val, timepos_t (_session.current_end ().beats()), true);
+				}
 				Changed (true, Controllable::NoGroup);
 			}
 			if (!touching()) {
@@ -277,7 +284,7 @@ AutomationControl::set_automation_state (AutoState as)
 }
 
 void
-AutomationControl::start_touch (double when)
+AutomationControl::start_touch (timepos_t const & when)
 {
 	if (!_list || touching ()) {
 		return;
@@ -300,7 +307,7 @@ AutomationControl::start_touch (double when)
 }
 
 void
-AutomationControl::stop_touch (double when)
+AutomationControl::stop_touch (timepos_t const & when)
 {
 	if (!_list || !touching ()) {
 		return;
