@@ -56,17 +56,17 @@ bool
 Convolution::add_impdata (
     uint32_t                    c_in,
     uint32_t                    c_out,
-    boost::shared_ptr<Readable> readable,
+    boost::shared_ptr<AudioReadable> readable,
     float                       gain,
     uint32_t                    pre_delay,
     sampleoffset_t              offset,
     samplecnt_t                 length,
     uint32_t                    channel)
 {
-	if (_configured || c_in >= _n_inputs || c_out >= _n_outputs) {
+	if (c_in >= _n_inputs || c_out >= _n_outputs) {
 		return false;
 	}
-	if (!readable || readable->readable_length () <= offset || readable->n_channels () <= channel) {
+	if (!readable || readable->readable_length_samples () <= offset || readable->n_channels () <= channel) {
 		return false;
 	}
 
@@ -74,6 +74,12 @@ Convolution::add_impdata (
 	return true;
 }
 
+void
+Convolution::clear_impdata ()
+{
+	_impdata.clear ();
+}
+
 bool
 Convolution::ready () const
 {
@@ -87,6 +93,11 @@ Convolution::restart ()
 	_convproc.cleanup ();
 	_convproc.set_options (0);
 
+	if (_impdata.empty ()) {
+		_configured = false;
+		return;
+	}
+
 	uint32_t n_part;
 
 	if (_threaded) {
@@ -104,7 +115,7 @@ Convolution::restart ()
 	_max_size  = 0;
 
 	for (std::vector<ImpData>::const_iterator i = _impdata.begin (); i != _impdata.end (); ++i) {
-		_max_size = std::max (_max_size, (uint32_t)i->readable_length ());
+		_max_size = std::max (_max_size, (uint32_t)i->readable_length_samples ());
 	}
 
 	int rv = _convproc.configure (
@@ -121,7 +132,7 @@ Convolution::restart ()
 
 		const float    ir_gain  = i->gain;
 		const uint32_t ir_delay = i->delay;
-		const uint32_t ir_len   = i->readable_length ();
+		const uint32_t ir_len   = i->readable_length_samples ();
 
 		while (true) {
 			float ir[8192];
@@ -235,14 +246,14 @@ Convolver::Convolver (
 {
 	_threaded = true;
 
-	std::vector<boost::shared_ptr<Readable> > readables = Readable::load (_session, path);
+	std::vector<boost::shared_ptr<AudioReadable> > readables = AudioReadable::load (_session, path);
 
 	if (readables.empty ()) {
 		PBD::error << string_compose (_("Convolver: IR \"%1\" no usable audio-channels sound."), path) << endmsg;
 		throw failed_constructor ();
 	}
 
-	if (readables[0]->readable_length () > 0x1000000 /*2^24*/) {
+	if (readables[0]->readable_length_samples () > 0x1000000 /*2^24*/) {
 		PBD::error << string_compose (_("Convolver: IR \"%1\" file too long."), path) << endmsg;
 		throw failed_constructor ();
 	}
@@ -297,7 +308,7 @@ Convolver::Convolver (
 			io_i = (c / n_outputs ()) % n_inputs ();
 		}
 
-		boost::shared_ptr<Readable> r = readables[ir_c];
+		boost::shared_ptr<AudioReadable> r = readables[ir_c];
 		assert (r->n_channels () == 1);
 
 		const float    chan_gain  = _ir_settings.gain * _ir_settings.channel_gain[c];
@@ -316,8 +327,14 @@ Convolver::Convolver (
 void
 Convolver::run_mono_buffered (float* buf, uint32_t n_samples)
 {
-	assert (_convproc.state () == Convproc::ST_PROC);
 	assert (_irc == Mono);
+	Convolution::run_mono_buffered (buf, n_samples);
+}
+
+void
+Convolution::run_mono_buffered (float* buf, uint32_t n_samples)
+{
+	assert (_convproc.state () == Convproc::ST_PROC);
 
 	uint32_t done   = 0;
 	uint32_t remain = n_samples;
@@ -375,8 +392,14 @@ Convolver::run_stereo_buffered (float* left, float* right, uint32_t n_samples)
 void
 Convolver::run_mono_no_latency (float* buf, uint32_t n_samples)
 {
-	assert (_convproc.state () == Convproc::ST_PROC);
 	assert (_irc == Mono);
+	Convolution::run_mono_no_latency (buf, n_samples);
+}
+
+void
+Convolution::run_mono_no_latency (float* buf, uint32_t n_samples)
+{
+	assert (_convproc.state () == Convproc::ST_PROC);
 
 	uint32_t done   = 0;
 	uint32_t remain = n_samples;
