@@ -321,10 +321,6 @@ Graph::run_one ()
 		DEBUG_TRACE (DEBUG::ProcessThreads, string_compose ("%1 goes to sleep\n", pthread_name ()));
 		_execution_sem.wait ();
 
-		/* update the thread-local tempo map ptr */
-
-		Temporal::TempoMap::fetch ();
-
 		if (g_atomic_int_get (&_terminate)) {
 			return;
 		}
@@ -337,6 +333,14 @@ Graph::run_one ()
 		_trigger_queue.pop_front (to_run);
 	}
 
+	/* Update the thread-local tempo map ptr.
+	 *
+	 * Doing this here is problematic, since it can result in each thread,
+	 * using a different tempo-map in a given cycle. And even different maps
+	 * in the same cycle for different routes.
+	 */
+	Temporal::TempoMap::fetch ();
+
 	/* Process the graph-node */
 	g_atomic_int_dec_and_test (&_trigger_queue_size);
 	to_run->run (_graph_chain);
@@ -366,9 +370,6 @@ Graph::helper_thread ()
 
 	pt->get_buffers ();
 
-	/* just in case we need the thread local tempo map ptr before anything else */
-	Temporal::TempoMap::fetch ();
-
 	while (!g_atomic_int_get (&_terminate)) {
 		run_one ();
 	}
@@ -402,7 +403,6 @@ Graph::main_thread ()
 	/* Wait for initial process callback */
 again:
 	_callback_start_sem.wait ();
-	Temporal::TempoMap::fetch ();
 
 	DEBUG_TRACE (DEBUG::ProcessThreads, "main thread is awake\n");
 
@@ -473,9 +473,10 @@ Graph::routes_no_roll (boost::shared_ptr<GraphChain> chain, pframes_t nframes, s
 	_process_start_sample   = start_sample;
 	_process_end_sample     = end_sample;
 
-	_process_mode        = NoRoll;
-	_process_retval      = 0;
-	_process_need_butler = false;
+	_process_mode           = NoRoll;
+	_process_retval         = 0;
+	_process_need_butler    = false;
+	_process_non_rt_pending = non_rt_pending;
 
 	DEBUG_TRACE (DEBUG::ProcessThreads, "wake graph for no-roll process\n");
 	_callback_start_sem.signal ();
