@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2010-2011 David Robillard <d@drobilla.net>
  * Copyright (C) 2011 Carl Hetherington <carl@carlh.net>
- * Copyright (C) 2017-2019 Robin Gareus <robin@gareus.org>
+ * Copyright (C) 2017-2022 Robin Gareus <robin@gareus.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,27 +18,52 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "ardour/graph.h"
 #include "ardour/graphnode.h"
+#include "ardour/graph.h"
 #include "ardour/route.h"
 
 using namespace ARDOUR;
 
+GraphActivision::GraphActivision ()
+	: _activation_set (new ActivationMap)
+	, _init_refcount (new RefCntMap)
+{
+}
+
+node_set_t const&
+GraphActivision::activation_set (GraphChain const* const g) const
+{
+	boost::shared_ptr<ActivationMap> m (_activation_set.reader ());
+	return m->at (g);
+}
+
+int
+GraphActivision::init_refcount (GraphChain const* const g) const
+{
+	boost::shared_ptr<RefCntMap> m (_init_refcount.reader ());
+	return m->at (g);
+}
+
+/* ****************************************************************************/
+
 GraphNode::GraphNode (boost::shared_ptr<Graph> graph)
 	: _graph (graph)
 {
 	g_atomic_int_set (&_refcount, 0);
 }
 
-GraphNode::~GraphNode ()
+void
+GraphNode::prep (GraphChain const* chain)
 {
+	/* This is the number of nodes that directly feed us */
+	g_atomic_int_set (&_refcount, init_refcount (chain));
 }
 
 void
-GraphNode::prep (int chain)
+GraphNode::run (GraphChain const* chain)
 {
-	/* This is the number of nodes that directly feed us */
-	g_atomic_int_set (&_refcount, _init_refcount[chain]);
+	process ();
+	finish (chain);
 }
 
 /** Called by an upstream node, when it has completed processing */
@@ -57,14 +82,14 @@ GraphNode::trigger ()
 }
 
 void
-GraphNode::finish (int chain)
+GraphNode::finish (GraphChain const* chain)
 {
 	node_set_t::iterator i;
 	bool                 feeds = false;
 
 	/* Notify downstream nodes that depend on this node */
-	for (i = _activation_set[chain].begin (); i != _activation_set[chain].end (); ++i) {
-		(*i)->trigger ();
+	for (auto const& i : activation_set (chain)) {
+		i->trigger ();
 		feeds = true;
 	}
 
@@ -74,9 +99,3 @@ GraphNode::finish (int chain)
 		_graph->reached_terminal_node ();
 	}
 }
-
-void
-GraphNode::process ()
-{
-	_graph->process_one_route (dynamic_cast<Route*> (this));
-}
