@@ -484,6 +484,9 @@ write_midi_data_to_new_files (Evoral::SMF* source, ImportStatus& status,
 
 				smfs->load_model (source_lock, true);
 
+				/* Now that there is a model, we can set interpolation of parameters. */
+				smfs->mark_streaming_write_completed (source_lock);
+
 				if (status.cancel) {
 					break;
 				}
@@ -582,6 +585,7 @@ Session::deinterlace_midi_region (boost::shared_ptr<MidiRegion> mr)
 		/* create a whole-file region for this new source, so it shows up in the Source List...*/
 		PropertyList plist (mr->properties ());
 		plist.add (Properties::whole_file, true);
+		plist.add (Properties::opaque, true);
 		plist.add (Properties::name, (*x)->name());
 		plist.add (Properties::tags, string_compose ("%1%2%3", _("(split-chans)"), mr->tags ().empty() ? "" : " ", mr->tags ()));
 		boost::shared_ptr<Region> whole = RegionFactory::create (*x, plist);
@@ -594,6 +598,29 @@ Session::deinterlace_midi_region (boost::shared_ptr<MidiRegion> mr)
 	}
 }
 
+static vector<string>
+unique_track_names (const vector<string>& n)
+{
+	set<string>    uniq;
+	vector<string> rv;
+
+	for (auto tn : n) {
+		while (uniq.find (tn) != uniq.end()) {
+			if (tn.empty ()) {
+				tn = "MIDI";
+			}
+			/* not not use '-' as separator because that is used by
+			 * new_midi_source_path, new_audio_source_path
+			 * when checking for existing files.
+			 */
+			tn = bump_name_once (tn, '.');
+		}
+		uniq.insert (tn);
+		rv.push_back (tn);
+	}
+	return rv;
+}
+
 // This function is still unable to cleanly update an existing source, even though
 // it is possible to set the ImportStatus flag accordingly. The functionality
 // is disabled at the GUI until the Source implementations are able to provide
@@ -665,11 +692,14 @@ Session::import_files (ImportStatus& status)
 						if (status.split_midi_channels) {
 							vector<string> temp;
 							smf_reader->track_names (temp);
+							temp = unique_track_names (temp);
 							for (uint32_t i = 0; i<num_channels;i++) {
 								smf_names.push_back( string_compose ("%1.ch%2", temp[i/16], 1+i%16 ) );  //trackname.chanX
 							}
 						} else {
-							smf_reader->track_names (smf_names);
+							vector<string> temp;
+							smf_reader->track_names (temp);
+							smf_names = unique_track_names (temp);
 						}
 						break;
 					case SMFInstrumentName:
