@@ -151,6 +151,7 @@ ARDOUR::samplecnt_t
 LTC_TransportMaster::update_interval() const
 {
 	if (timecode.rate) {
+		/* Use engine rate, timecode ports are not resampled */
 		return AudioEngine::instance()->sample_rate() / timecode.rate;
 	}
 
@@ -656,7 +657,7 @@ std::string
 LTC_TransportMaster::delta_string() const
 {
 	if (!_collect || current.timestamp == 0) {
-		return X_("\u2012\u2012\u2012\u2012");
+		return X_(u8"\u2012\u2012\u2012\u2012");
 	} else if ((monotonic_cnt - current.timestamp) > 2 * samples_per_ltc_frame) {
 		return _("flywheel");
 	} else {
