@@ -2764,7 +2764,7 @@ Playlist::uses_source (boost::shared_ptr<const Source> src, bool shallow) const
 		 * incredibly deep and time-consuming recursion, and at worst
 		 * cycles if the user has managed to create cycles of reference
 		 * between compound regions. We generally only this during
-		 * cleanup, and @param shallow is passed as true.
+		 * cleanup, and @p shallow is passed as true.
 		 */
 		if (r->uses_source (src, shallow)) {
 			return true;
@@ -3063,7 +3063,7 @@ Playlist::find_next_top_layer_position (timepos_t const & t) const
 }
 
 boost::shared_ptr<Region>
-Playlist::combine (const RegionList& rl)
+Playlist::combine (const RegionList& rl, boost::shared_ptr<Track>)
 {
 	if (rl.empty()) {
 		return boost::shared_ptr<Region>();
