@@ -81,7 +81,7 @@ BackendPort::connect (BackendPortHandle port, BackendPortHandle self)
 			<< " (" << name () << ") -> (" << port->name () << ")"
 			<< endmsg;
 #endif
-		return -1;
+		return 0;
 	}
 
 	store_connection (port);
@@ -186,14 +186,93 @@ BackendPort::update_connected_latency (bool for_playback)
 	set_latency_range (lr, for_playback);
 }
 
+bool
+BackendMIDIEvent::operator< (const BackendMIDIEvent &other) const {
+	if (timestamp() == other.timestamp ()) {
+		/* concurrent MIDI events, sort
+		 * - CC first (may include bank/patch)
+		 * - Program Change
+		 * - Note Off
+		 * - Note On
+		 * - Note Pressure
+		 * - Channel Pressure
+		 * - Pitch Bend
+		 * - SysEx/RT, etc
+		 *
+		 * see Evoral::Sequence<Time>::const_iterator::choose_next
+		 * and MidiBuffer::second_simultaneous_midi_byte_is_first
+		 */
+		uint8_t ta = 9;
+		uint8_t tb = 9;
+		if (size () > 0 && size () < 4) {
+			switch (data ()[0] & 0xf0) {
+				case 0xB0: /* Control Change */
+					ta = 1;
+					break;
+				case 0xC0: /* Program Change */
+					ta = 2;
+					break;
+				case 0x80: /* Note Off */
+					ta = 3;
+					break;
+				case 0x90: /* Note On */
+					ta = 4;
+					break;
+				case 0xA0: /* Key Pressure */
+					ta = 5;
+					break;
+				case 0xD0: /* Channel Pressure */
+					ta = 6;
+					break;
+				case 0xE0: /* Pitch Bend */
+					ta = 7;
+					break;
+				default:
+					ta = 8;
+					break;
+			}
+		}
 
+		if (other.size () > 0 && other.size () < 4) {
+			switch (other.data ()[0] & 0xf0) {
+				case 0xB0: /* Control Change */
+					tb = 1;
+					break;
+				case 0xC0: /* Program Change */
+					tb = 2;
+					break;
+				case 0x80: /* Note Off */
+					tb = 3;
+					break;
+				case 0x90: /* Note On */
+					tb = 4;
+					break;
+				case 0xA0: /* Key Pressure */
+					tb = 5;
+					break;
+				case 0xD0: /* Channel Pressure */
+					tb = 6;
+					break;
+				case 0xE0: /* Pitch Bend */
+					tb = 7;
+					break;
+				default:
+					tb = 8;
+					break;
+			}
+		}
+		return ta < tb;
+	}
+	return timestamp () < other.timestamp ();
+};
 
 PortEngineSharedImpl::PortEngineSharedImpl (PortManager& mgr, std::string const & str)
 	: _instance_name (str)
-	, _port_change_flag (false)
 	, _portmap (new PortMap)
 	, _ports (new PortIndex)
+	, _portregistry (new PortRegistry)
 {
+	g_atomic_int_set (&_port_change_flag, 0);
 	pthread_mutex_init (&_port_callback_mutex, 0);
 }
 
@@ -337,13 +416,16 @@ PortEngineSharedImpl::add_port (const std::string& name, ARDOUR::DataType type,
 	}
 
 	{
-		RCUWriter<PortIndex> index_writer (_ports);
-		RCUWriter<PortMap> map_writer (_portmap);
+		RCUWriter<PortIndex>    index_writer (_ports);
+		RCUWriter<PortMap>      map_writer (_portmap);
+		RCUWriter<PortRegistry> registry_writer (_portregistry);
 
-		boost::shared_ptr<PortIndex> ps = index_writer.get_copy ();
-		boost::shared_ptr<PortMap> pm = map_writer.get_copy ();
+		boost::shared_ptr<PortIndex> ps    = index_writer.get_copy ();
+		boost::shared_ptr<PortMap> pm      = map_writer.get_copy ();
+		boost::shared_ptr<PortRegistry> pr = registry_writer.get_copy ();
 
 		ps->insert (port);
+		pr->insert (port);
 		pm->insert (make_pair (name, port));
 	}
 
@@ -356,11 +438,13 @@ PortEngineSharedImpl::unregister_port (PortEngine::PortHandle port_handle)
 	BackendPortPtr port = boost::dynamic_pointer_cast<BackendPort>(port_handle);
 
 	{
-		RCUWriter<PortIndex> index_writer (_ports);
-		RCUWriter<PortMap> map_writer (_portmap);
+		RCUWriter<PortIndex>    index_writer (_ports);
+		RCUWriter<PortMap>      map_writer (_portmap);
+		RCUWriter<PortRegistry> registry_writer (_portregistry);
 
-		boost::shared_ptr<PortIndex> ps = index_writer.get_copy ();
-		boost::shared_ptr<PortMap> pm = map_writer.get_copy ();
+		boost::shared_ptr<PortIndex> ps    = index_writer.get_copy ();
+		boost::shared_ptr<PortMap> pm      = map_writer.get_copy ();
+		boost::shared_ptr<PortRegistry> pr = registry_writer.get_copy ();
 
 		PortIndex::iterator i = std::find (ps->begin(), ps->end(), boost::dynamic_pointer_cast<BackendPort> (port_handle));
 
@@ -373,10 +457,12 @@ PortEngineSharedImpl::unregister_port (PortEngine::PortHandle port_handle)
 
 		pm->erase (port->name());
 		ps->erase (i);
+		pr->erase (port);
 	}
 
 	_ports.flush ();
 	_portmap.flush ();
+	_portregistry.flush ();
 }
 
 
@@ -389,12 +475,13 @@ PortEngineSharedImpl::unregister_ports (bool system_only)
 	_system_midi_out.clear();
 
 	{
-		RCUWriter<PortIndex> index_writer (_ports);
-		RCUWriter<PortMap> map_writer (_portmap);
-
-		boost::shared_ptr<PortIndex> ps = index_writer.get_copy ();
-		boost::shared_ptr<PortMap> pm = map_writer.get_copy ();
+		RCUWriter<PortIndex>    index_writer (_ports);
+		RCUWriter<PortMap>      map_writer (_portmap);
+		RCUWriter<PortRegistry> registry_writer (_portregistry);
 
+		boost::shared_ptr<PortIndex> ps    = index_writer.get_copy ();
+		boost::shared_ptr<PortMap> pm      = map_writer.get_copy ();
+		boost::shared_ptr<PortRegistry> pr = registry_writer.get_copy ();
 
 		for (PortIndex::iterator i = ps->begin (); i != ps->end ();) {
 			PortIndex::iterator cur = i++;
@@ -403,25 +490,29 @@ PortEngineSharedImpl::unregister_ports (bool system_only)
 				port->disconnect_all (port);
 				pm->erase (port->name());
 				ps->erase (cur);
+				pr->erase (port);
 			}
 		}
 	}
 
 	_ports.flush ();
 	_portmap.flush ();
+	_portregistry.flush ();
 }
 
 void
 PortEngineSharedImpl::clear_ports ()
 {
 	{
-		RCUWriter<PortIndex> index_writer (_ports);
-		RCUWriter<PortMap> map_writer (_portmap);
+		RCUWriter<PortIndex>    index_writer (_ports);
+		RCUWriter<PortMap>      map_writer (_portmap);
+		RCUWriter<PortRegistry> registry_writer (_portregistry);
 
-		boost::shared_ptr<PortIndex> ps = index_writer.get_copy();
-		boost::shared_ptr<PortMap> pm = map_writer.get_copy ();
+		boost::shared_ptr<PortIndex> ps    = index_writer.get_copy ();
+		boost::shared_ptr<PortMap> pm      = map_writer.get_copy ();
+		boost::shared_ptr<PortRegistry> pr = registry_writer.get_copy ();
 
-		if (ps->size () || pm->size ()) {
+		if (ps->size () || pm->size () || pr->size ()) {
 			PBD::warning << _("PortEngineSharedImpl: recovering from unclean shutdown, port registry is not empty.") << endmsg;
 			_system_inputs.clear();
 			_system_outputs.clear();
@@ -429,14 +520,16 @@ PortEngineSharedImpl::clear_ports ()
 			_system_midi_out.clear();
 			ps->clear();
 			pm->clear();
+			pr->clear();
 		}
 	}
 
 	_ports.flush ();
 	_portmap.flush ();
+	_portregistry.flush ();
 
+	g_atomic_int_set (&_port_change_flag, 0);
 	pthread_mutex_lock (&_port_callback_mutex);
-	_port_change_flag = false;
 	_port_connection_queue.clear();
 	pthread_mutex_unlock (&_port_callback_mutex);
 }
@@ -464,13 +557,22 @@ PortEngineSharedImpl::set_port_name (PortEngine::PortHandle port_handle, const s
 	}
 
 	const std::string old_name = port->name();
-	int ret =  port->set_name (newname);
+
+	/* PortIndex std::set is sorted by name, using the name as key.
+	 * So name-changes need to update the set.
+	 * PortRegistry does not change
+	 */
+	RCUWriter<PortIndex> index_writer (_ports);
+	RCUWriter<PortMap>   map_writer (_portmap);
+
+	boost::shared_ptr<PortIndex> ps = index_writer.get_copy ();
+	boost::shared_ptr<PortMap>   pm = map_writer.get_copy ();
+
+	ps->erase (port);
+	int ret = port->set_name (newname);
+	ps->insert (port);
 
 	if (ret == 0) {
-
-		RCUWriter<PortMap> map_writer (_portmap);
-		boost::shared_ptr<PortMap> pm = map_writer.get_copy ();
-
 		pm->erase (old_name);
 		pm->insert (make_pair (newname, port));
 	}
@@ -514,6 +616,10 @@ PortEngineSharedImpl::get_port_property (PortEngine::PortHandle port, const std:
 		if (!value.empty()) {
 			return 0;
 		}
+		value = boost::static_pointer_cast<BackendPort>(port)->hw_port_name ();
+		if (!value.empty()) {
+			return 0;
+		}
 	}
 	return -1;
 }
@@ -657,12 +763,12 @@ PortEngineSharedImpl::connected (PortEngine::PortHandle port_handle, bool /* pro
 }
 
 bool
-PortEngineSharedImpl::connected_to (PortEngine::PortHandle src, const std::string& dst, bool /*process_callback_safe*/)
+PortEngineSharedImpl::connected_to (PortEngine::PortHandle src, const std::string& dst, bool process_callback_safe)
 {
 	BackendPortPtr src_port = boost::dynamic_pointer_cast<BackendPort> (src);
 	BackendPortPtr dst_port = find_port (dst);
 #ifndef NDEBUG
-	if (!valid_port (src_port) || !dst_port) {
+	if (!process_callback_safe && (!valid_port (src_port) || !dst_port)) {
 		PBD::error << string_compose (_("%1::connected_to: Invalid Port"), _instance_name) << endmsg;
 		return false;
 	}
@@ -720,3 +826,14 @@ PortEngineSharedImpl::update_system_port_latencies ()
 		(*it)->update_connected_latency (false);
 	}
 }
+
+#ifndef NDEBUG
+void
+PortEngineSharedImpl::list_ports () const
+{
+	boost::shared_ptr<PortIndex> p = _ports.reader ();
+	for (PortIndex::const_iterator i = p->begin (); i != p->end (); ++i) {
+		std::cout << (*i)->name () << "\n";
+	}
+}
+#endif
