@@ -23,6 +23,7 @@
 
 #include "pbd/xml++.h"
 
+#include "ardour/amp.h"
 #include "ardour/audio_port.h"
 #include "ardour/audioengine.h"
 #include "ardour/delivery.h"
@@ -48,11 +49,32 @@ PortInsert::name_and_id_new_insert (Session& s, uint32_t& bitslot)
 PortInsert::PortInsert (Session& s, boost::shared_ptr<Pannable> pannable, boost::shared_ptr<MuteMaster> mm)
 	: IOProcessor (s, true, true, name_and_id_new_insert (s, _bitslot), "", DataType::AUDIO, true)
 	, _out (new Delivery (s, _output, pannable, mm, _name, Delivery::Insert))
+	, _metering (false)
+	, _signal_latency (0)
+	, _mtdm (0)
+	, _latency_detect (false)
+	, _latency_flush_samples (0)
+	, _measured_latency (0)
 {
-	_mtdm = 0;
-	_latency_detect = false;
-	_latency_flush_samples = 0;
-	_measured_latency = 0;
+	/* Send */
+	_out->set_gain_control (boost::shared_ptr<GainControl> (new GainControl (_session, Evoral::Parameter(BusSendLevel), boost::shared_ptr<AutomationList> (new AutomationList (Evoral::Parameter (BusSendLevel), time_domain())))));
+
+	_out->set_polarity_control (boost::shared_ptr<AutomationControl> (new AutomationControl (_session, PhaseAutomation, ParameterDescriptor (PhaseAutomation), boost::shared_ptr<AutomationList>(new AutomationList(Evoral::Parameter(PhaseAutomation), time_domain())), "polarity-invert")));
+	_send_meter.reset (new PeakMeter (_session, name()));
+
+	/* Return */
+	_gain_control = boost::shared_ptr<GainControl> (new GainControl (_session, Evoral::Parameter(InsertReturnLevel), boost::shared_ptr<AutomationList> (new AutomationList (Evoral::Parameter (InsertReturnLevel), time_domain()))));
+	_amp.reset (new Amp (_session, _("Return"), _gain_control, true));
+	_return_meter.reset (new PeakMeter (_session, name()));
+
+	add_control (_out->gain_control ());
+	add_control (_out->polarity_control ());
+	add_control (_gain_control);
+
+	_io_latency = _session.engine().samples_per_cycle();
+
+	input ()->changed.connect_same_thread (*this, boost::bind (&PortInsert::io_changed, this, _1, _2));
+	output ()->changed.connect_same_thread (*this, boost::bind (&PortInsert::io_changed, this, _1, _2));
 }
 
 PortInsert::~PortInsert ()
@@ -68,9 +90,20 @@ PortInsert::set_pre_fader (bool p)
 	_out->set_pre_fader (p);
 }
 
+void
+PortInsert::latency_changed ()
+{
+	LatencyChanged (); /* EMIT SIGNAL */
+	assert (owner ());
+	static_cast<Route*>(owner ())->processor_latency_changed (); /* EMIT SIGNAL */
+}
+
 void
 PortInsert::start_latency_detection ()
 {
+	if (_latency_detect) {
+		return;
+	}
 	delete _mtdm;
 	_mtdm = new MTDM (_session.sample_rate());
 	_latency_flush_samples = 0;
@@ -81,6 +114,9 @@ PortInsert::start_latency_detection ()
 void
 PortInsert::stop_latency_detection ()
 {
+	if (!_latency_detect) {
+		return;
+	}
 	_latency_flush_samples = effective_latency() + _session.engine().samples_per_cycle();
 	_latency_detect = false;
 }
@@ -92,31 +128,17 @@ PortInsert::set_measured_latency (samplecnt_t n)
 		return;
 	}
 	_measured_latency = n;
-	LatencyChanged (); /* EMIT SIGNAL */
-	assert (owner ());
-	static_cast<Route*>(owner ())->processor_latency_changed (); /* EMIT SIGNAL */
-}
-
-samplecnt_t
-PortInsert::latency() const
-{
-	/* because we deliver and collect within the same cycle,
-	   all I/O is necessarily delayed by at least samples_per_cycle().
-
-	   if the return port for insert has its own latency, we
-	   need to take that into account too.
-	*/
-
-	if (_measured_latency == 0) {
-		return _session.engine().samples_per_cycle() + _input->latency();
-	} else {
-		return _measured_latency;
-	}
 }
 
 void
 PortInsert::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_sample, double speed, pframes_t nframes, bool)
 {
+	const samplecnt_t l = effective_latency ();
+	if (_signal_latency != l) {
+		_signal_latency = l;
+		latency_changed ();
+	}
+
 	if (_output->n_ports().n_total() == 0) {
 		return;
 	}
@@ -134,6 +156,8 @@ PortInsert::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 			outbuf.set_written (true);
 		}
 
+		_send_meter->reset ();
+		_return_meter->reset ();
 		return;
 
 	} else if (_latency_flush_samples) {
@@ -150,17 +174,34 @@ PortInsert::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 			_latency_flush_samples = 0;
 		}
 
+		_send_meter->reset ();
+		_return_meter->reset ();
 		return;
 	}
 
 	if (!check_active()) {
 		/* deliver silence */
 		silence (nframes, start_sample);
+		_send_meter->reset ();
+		_return_meter->reset ();
 		return;
 	}
 
 	_out->run (bufs, start_sample, end_sample, speed, nframes, true);
+
+	if (_metering) {
+		_send_meter->run (bufs, start_sample, end_sample, speed, nframes, true);
+	}
+
 	_input->collect_input (bufs, nframes, ChanCount::ZERO);
+
+	_amp->set_gain_automation_buffer (_session.send_gain_automation_buffer ());
+	_amp->setup_gain_automation (start_sample, end_sample, nframes);
+	_amp->run (bufs, start_sample, end_sample, speed, nframes, true);
+
+	if (_metering) {
+		_return_meter->run (bufs, start_sample, end_sample, speed, nframes, true);
+	}
 }
 
 XMLNode&
@@ -172,6 +213,14 @@ PortInsert::state () const
 	node.set_property ("latency", _measured_latency);
 	node.set_property ("block-size", _session.get_block_size());
 
+	XMLNode* ret = new XMLNode(X_("Return"));
+	ret->add_child_nocopy (_gain_control->get_state());
+	node.add_child_nocopy (*ret);
+
+	XMLNode* snd = new XMLNode(X_("Send"));
+	snd->add_child_nocopy (_out->gain_control ()->get_state());
+	node.add_child_nocopy (*snd);
+
 	return node;
 }
 
@@ -208,8 +257,10 @@ PortInsert::set_state (const XMLNode& node, int version)
 	uint32_t blocksize = 0;
 	node.get_property ("block-size", blocksize);
 
-	//if the jack period is the same as when the value was saved, we can recall our latency..
-	if ( (_session.get_block_size() == blocksize) ) {
+	/* If the period is the same as when the value was saved,
+	 * we can recall our latency.
+	 */
+	if (_session.engine().samples_per_cycle () == blocksize && blocksize > 0) {
 		node.get_property ("latency", _measured_latency);
 	}
 
@@ -224,6 +275,15 @@ PortInsert::set_state (const XMLNode& node, int version)
 		}
 	}
 
+	XMLNode* child = node.child (X_("Send"));
+	if (child && child->children().size () > 0) {
+		_out->gain_control ()->set_state (**child->children().begin(), version);
+	}
+	child = node.child (X_("Return"));
+	if (child && child->children().size () > 0) {
+		_gain_control->set_state (**child->children().begin(), version);
+	}
+
 	return 0;
 }
 
@@ -237,15 +297,25 @@ PortInsert::signal_latency() const
 	 * need to take that into account too.
 	 */
 
-	if (_measured_latency == 0) {
-		return _session.engine().samples_per_cycle()
-		       + _input->connected_latency (false)
-		       + _output->connected_latency (true);
+	if (_measured_latency == 0 || _latency_detect) {
+		return _io_latency;
 	} else {
 		return _measured_latency;
 	}
 }
 
+void
+PortInsert::io_changed (IOChange change, void*)
+{
+	if (change.type & IOChange::ConnectionsChanged) {
+		if (output ()->connected () && input ()->connected ()) {
+			_io_latency = _input->connected_latency (false) + _output->connected_latency (true);
+		} else {
+			_io_latency = _session.engine().samples_per_cycle ();
+		}
+	}
+}
+
 /** Caller must hold process lock */
 bool
 PortInsert::configure_io (ChanCount in, ChanCount out)
@@ -264,6 +334,17 @@ PortInsert::configure_io (ChanCount in, ChanCount out)
 		return false;
 	}
 
+	if (!_send_meter->configure_io (out, out)) {
+		return false;
+	}
+
+	if (!_return_meter->configure_io (in, in)) {
+		return false;
+	}
+
+	_out->configure_io (in, out); /* send */
+	_amp->configure_io (out, in); /* return */
+
 	return Processor::configure_io (in, out);
 }
 
@@ -291,7 +372,16 @@ PortInsert::activate ()
 {
 	IOProcessor::activate ();
 
+	_send_meter->activate ();
+	_return_meter->activate ();
+	_amp->activate ();
 	_out->activate ();
+
+	const samplecnt_t l = effective_latency ();
+	if (_signal_latency != l) {
+		_signal_latency = l;
+		latency_changed ();
+	}
 }
 
 void
@@ -299,5 +389,18 @@ PortInsert::deactivate ()
 {
 	IOProcessor::deactivate ();
 
+	_send_meter->deactivate ();
+	_send_meter->reset ();
+
+	_return_meter->deactivate ();
+	_return_meter->reset ();
+
+	_amp->deactivate ();
 	_out->deactivate ();
+
+	const samplecnt_t l = effective_latency ();
+	if (_signal_latency != l) {
+		_signal_latency = l;
+		latency_changed ();
+	}
 }
