@@ -28,6 +28,8 @@
 
 #include "ardour/debug.h"
 #include "ardour/session_event.h"
+#include "ardour/track.h"
+#include "ardour/region.h"
 
 #include "pbd/i18n.h"
 
@@ -43,6 +45,15 @@ SessionEvent::init_event_pool ()
 	pool = new PerThreadPool;
 }
 
+guint
+SessionEvent::pool_available ()
+{
+	if (!pool || !pool->per_thread_pool (false)) {
+		return 0;
+	}
+	return pool->per_thread_pool()->available ();
+}
+
 bool
 SessionEvent::has_per_thread_pool ()
 {
@@ -56,7 +67,13 @@ SessionEvent::create_per_thread_pool (const std::string& name, uint32_t nitems)
 	   a CrossThreadPool for use by this thread whenever events are allocated/released
 	   from SessionEvent::pool()
 	*/
-	pool->create_per_thread_pool (name, sizeof (SessionEvent), nitems);
+	pool->create_per_thread_pool (name, sizeof (SessionEvent), nitems,
+#ifndef NDEBUG
+			[](size_t i, void*p) { std::cout << i << " " << *static_cast<SessionEvent*> (p) << "\n"; }
+#else
+			NULL
+#endif
+			);
 }
 
 SessionEvent::SessionEvent (Type t, Action a, samplepos_t when, samplepos_t where, double spd, bool yn, bool yn2, bool yn3)
@@ -162,7 +179,7 @@ SessionEventManager::dump_events () const
 	cerr << "EVENT DUMP" << endl;
 	for (Events::const_iterator i = events.begin(); i != events.end(); ++i) {
 
-		cerr << "\tat " << (*i)->action_sample << ' ' << enum_2_string ((*i)->type) << " target = " << (*i)->target_sample << endl;
+		cerr << "\tat " << (*i)->action_sample << " type " << enum_2_string ((*i)->type) << " target = " << (*i)->target_sample << endl;
 	}
 	cerr << "Next event: ";
 
@@ -254,11 +271,11 @@ SessionEventManager::_replace_event (SessionEvent* ev)
 	Events& e (ev->action_sample == SessionEvent::Immediate ? immediate_events : events);
 
 	for (i = e.begin(); i != e.end(); ++i) {
-		if ((*i)->type == ev->type && ev->type == SessionEvent::Overwrite && (*i)->track.lock() == ev->track.lock() && (*i)->overwrite == ev->overwrite) {
+		if ((*i)->type == ev->type && ev->type == SessionEvent::Overwrite && (*i)->track.lock() == ev->track.lock()) {
 			assert (ev->action_sample == SessionEvent::Immediate);
-			ret = true;
+			(*i)->overwrite = ARDOUR::OverwriteReason ((*i)->overwrite | ev->overwrite);
 			delete ev;
-			break;
+			return true;
 		}
 		else if ((*i)->type == ev->type && ev->type != SessionEvent::Overwrite) {
 			assert (ev->action_sample != SessionEvent::Immediate);
@@ -355,3 +372,45 @@ SessionEventManager::_clear_event_type (SessionEvent::Type type)
 
 	set_next_event ();
 }
+
+std::ostream& operator<<(std::ostream& o, ARDOUR::SessionEvent const& ev) {
+  o << "SessionEvent"
+		<< " type: " << enum_2_string (ev.type)
+		<< " action: " << enum_2_string (ev.action)
+		<< " atime: " << ev.action_sample
+		<< " ttime: " << ev.target_sample;
+
+	switch (ev.type) {
+		case SessionEvent::Locate:
+			o << " disposition: " << ev.locate_transport_disposition;
+			o << " force: " << ev.yes_or_no;
+			break;
+		case SessionEvent::LocateRoll:
+			o << " force: " << ev.yes_or_no;
+			break;
+		case SessionEvent::SetDefaultPlaySpeed:
+			/* fallthrough */
+		case SessionEvent::SetTransportSpeed:
+			o << " speed: " << ev.speed;
+			break;
+		case SessionEvent::EndRoll:
+			o << " abort: " << ev.yes_or_no;
+			o << " clear: " << ev.second_yes_or_no;
+			break;
+		case SessionEvent::OverwriteAll:
+			o << " reason: " << ev.overwrite;
+			break;
+		case SessionEvent::Audition:
+			o << " region: '" << ev.region->name () << "'";
+			break;
+		case SessionEvent::Overwrite:
+			if (boost::shared_ptr<Track> track = ev.track.lock ()) {
+				o << " track: '" << track->name () << "'";
+			}
+			o << " reason: " << ev.overwrite;
+			break;
+		default:
+			break;
+	}
+	return o;
+}
