@@ -686,6 +686,12 @@ Session::scene_input_port () const
 	return _midi_ports->scene_input_port ();
 }
 
+boost::shared_ptr<ARDOUR::Port>
+Session::trigger_input_port () const
+{
+	return _midi_ports->trigger_input_port ();
+}
+
 boost::shared_ptr<AsyncMIDIPort>
 Session::vkbd_output_port () const
 {
