@@ -24,23 +24,23 @@
 #include "libardour-config.h"
 #endif
 
-#include "pbd/error.h"
 #include "pbd/convert.h"
-#include "pbd/pthread_utils.h"
+#include "pbd/error.h"
+
+#include "temporal/tempo.h"
 
-#include "ardour/audioplaylist.h"
 #include "ardour/audio_playlist_source.h"
+#include "ardour/audioplaylist.h"
 #include "ardour/boost_debug.h"
 #include "ardour/ffmpegfilesource.h"
 #include "ardour/midi_playlist.h"
-#include "ardour/midi_playlist_source.h"
 #include "ardour/mp3filesource.h"
-#include "ardour/source.h"
-#include "ardour/source_factory.h"
-#include "ardour/sndfilesource.h"
+#include "ardour/session.h"
 #include "ardour/silentfilesource.h"
 #include "ardour/smf_source.h"
-#include "ardour/session.h"
+#include "ardour/sndfilesource.h"
+#include "ardour/source.h"
+#include "ardour/source_factory.h"
 
 #ifdef HAVE_COREAUDIO
 #include "ardour/coreaudiosource.h"
@@ -52,10 +52,12 @@ using namespace ARDOUR;
 using namespace std;
 using namespace PBD;
 
-PBD::Signal1<void,boost::shared_ptr<Source> > SourceFactory::SourceCreated;
-Glib::Threads::Cond SourceFactory::PeaksToBuild;
-Glib::Threads::Mutex SourceFactory::peak_building_lock;
-std::list<boost::weak_ptr<AudioSource> > SourceFactory::files_with_peaks;
+PBD::Signal1<void, boost::shared_ptr<Source>> SourceFactory::SourceCreated;
+Glib::Threads::Cond                           SourceFactory::PeaksToBuild;
+Glib::Threads::Mutex                          SourceFactory::peak_building_lock;
+std::list<boost::weak_ptr<AudioSource>>       SourceFactory::files_with_peaks;
+std::vector<PBD::Thread*>                     SourceFactory::peak_thread_pool;
+bool                                          SourceFactory::peak_thread_run = false;
 
 static int active_threads = 0;
 
@@ -66,21 +68,28 @@ peak_thread_work ()
 	pthread_set_name ("PeakFileBuilder");
 
 	while (true) {
-
 		SourceFactory::peak_building_lock.lock ();
 
-	  wait:
-		if (SourceFactory::files_with_peaks.empty()) {
+	wait:
+		if (SourceFactory::files_with_peaks.empty () && SourceFactory::peak_thread_run) {
 			SourceFactory::PeaksToBuild.wait (SourceFactory::peak_building_lock);
+			(void) Temporal::TempoMap::fetch();
 		}
 
-		if (SourceFactory::files_with_peaks.empty()) {
+		if (!SourceFactory::peak_thread_run) {
+			SourceFactory::peak_building_lock.unlock ();
+			return;
+		}
+
+		if (SourceFactory::files_with_peaks.empty ()) {
 			goto wait;
 		}
 
-		boost::shared_ptr<AudioSource> as (SourceFactory::files_with_peaks.front().lock());
+		boost::shared_ptr<AudioSource> as (SourceFactory::files_with_peaks.front ().lock ());
 		SourceFactory::files_with_peaks.pop_front ();
-		++active_threads;
+		if (as) {
+			++active_threads;
+		}
 		SourceFactory::peak_building_lock.unlock ();
 
 		if (!as) {
@@ -105,8 +114,25 @@ SourceFactory::peak_work_queue_length ()
 void
 SourceFactory::init ()
 {
+	if (peak_thread_run) {
+		return;
+	}
+	peak_thread_run = true;
 	for (int n = 0; n < 2; ++n) {
-		Glib::Threads::Thread::create (sigc::ptr_fun (::peak_thread_work));
+		peak_thread_pool.push_back (PBD::Thread::create (&peak_thread_work));
+	}
+}
+
+void
+SourceFactory::terminate ()
+{
+	if (!peak_thread_run) {
+		return;
+	}
+	peak_thread_run = false;
+	PeaksToBuild.broadcast ();
+	for (auto& t : peak_thread_pool) {
+		t->join ();
 	}
 }
 
@@ -116,18 +142,15 @@ SourceFactory::setup_peakfile (boost::shared_ptr<Source> s, bool async)
 	boost::shared_ptr<AudioSource> as (boost::dynamic_pointer_cast<AudioSource> (s));
 
 	if (as) {
-
 		// immediately set 'peakfile-path' for empty and NoPeakFile sources
-		if (async && !as->empty() && !(as->flags() & Source::NoPeakFile)) {
-
+		if (async && !as->empty () && !(as->flags () & Source::NoPeakFile)) {
 			Glib::Threads::Mutex::Lock lm (peak_building_lock);
 			files_with_peaks.push_back (boost::weak_ptr<AudioSource> (as));
 			PeaksToBuild.broadcast ();
 
 		} else {
-
 			if (as->setup_peakfile ()) {
-				error << string_compose("SourceFactory: could not set up peakfile for %1", as->name()) << endmsg;
+				error << string_compose ("SourceFactory: could not set up peakfile for %1", as->name ()) << endmsg;
 				return -1;
 			}
 		}
@@ -139,7 +162,7 @@ SourceFactory::setup_peakfile (boost::shared_ptr<Source> s, bool async)
 boost::shared_ptr<Source>
 SourceFactory::createSilent (Session& s, const XMLNode& node, samplecnt_t nframes, float sr)
 {
-	Source* src = new SilentFileSource (s, node, nframes, sr);
+	Source*                   src = new SilentFileSource (s, node, nframes, sr);
 	boost::shared_ptr<Source> ret (src);
 	BOOST_MARK_SOURCE (ret);
 	// no analysis data - the file is non-existent
@@ -150,19 +173,17 @@ SourceFactory::createSilent (Session& s, const XMLNode& node, samplecnt_t nframe
 boost::shared_ptr<Source>
 SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 {
-	DataType type = DataType::AUDIO;
-	XMLProperty const * prop = node.property("type");
+	DataType           type = DataType::AUDIO;
+	XMLProperty const* prop = node.property ("type");
 
 	if (prop) {
-		type = DataType (prop->value());
+		type = DataType (prop->value ());
 	}
 
 	if (type == DataType::AUDIO) {
-
 		/* it could be nested */
 
 		if (node.property ("playlist") != 0) {
-
 			try {
 				boost::shared_ptr<AudioPlaylistSource> ap (new AudioPlaylistSource (s, node));
 
@@ -180,9 +201,8 @@ SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 			}
 
 		} else {
-
 			try {
-				Source* src = new SndFileSource (s, node);
+				Source*                   src = new SndFileSource (s, node);
 				boost::shared_ptr<Source> ret (src);
 				BOOST_MARK_SOURCE (ret);
 				if (setup_peakfile (ret, defer_peaks)) {
@@ -191,11 +211,12 @@ SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 				ret->check_for_analysis_data_on_disk ();
 				SourceCreated (ret);
 				return ret;
-			} catch (failed_constructor& err) { }
+			} catch (failed_constructor& err) {
+			}
 
 #ifdef HAVE_COREAUDIO
 			try {
-				Source* src = new CoreAudioSource (s, node);
+				Source*                   src = new CoreAudioSource (s, node);
 				boost::shared_ptr<Source> ret (src);
 				BOOST_MARK_SOURCE (ret);
 
@@ -206,7 +227,8 @@ SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 				ret->check_for_analysis_data_on_disk ();
 				SourceCreated (ret);
 				return ret;
-			} catch (...) { }
+			} catch (...) {
+			}
 #endif
 			/* this is allowed to throw */
 			throw failed_constructor ();
@@ -215,8 +237,6 @@ SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 	} else if (type == DataType::MIDI) {
 		try {
 			boost::shared_ptr<SMFSource> src (new SMFSource (s, node));
-			Source::Lock lock(src->mutex());
-			src->load_model (lock, true);
 			BOOST_MARK_SOURCE (src);
 			src->check_for_analysis_data_on_disk ();
 			SourceCreated (src);
@@ -230,12 +250,11 @@ SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 
 boost::shared_ptr<Source>
 SourceFactory::createExternal (DataType type, Session& s, const string& path,
-			       int chn, Source::Flag flags, bool announce, bool defer_peaks)
+                               int chn, Source::Flag flags, bool announce, bool defer_peaks)
 {
 	if (type == DataType::AUDIO) {
-
 		try {
-			Source* src = new SndFileSource (s, path, chn, flags);
+			Source*                   src = new SndFileSource (s, path, chn, flags);
 			boost::shared_ptr<Source> ret (src);
 			BOOST_MARK_SOURCE (ret);
 			if (setup_peakfile (ret, defer_peaks)) {
@@ -246,11 +265,12 @@ SourceFactory::createExternal (DataType type, Session& s, const string& path,
 				SourceCreated (ret);
 			}
 			return ret;
-		} catch (failed_constructor& err) { }
+		} catch (failed_constructor& err) {
+		}
 
 #ifdef HAVE_COREAUDIO
 		try {
-			Source* src = new CoreAudioSource (s, path, chn, flags);
+			Source*                   src = new CoreAudioSource (s, path, chn, flags);
 			boost::shared_ptr<Source> ret (src);
 			BOOST_MARK_SOURCE (ret);
 			if (setup_peakfile (ret, defer_peaks)) {
@@ -261,34 +281,35 @@ SourceFactory::createExternal (DataType type, Session& s, const string& path,
 				SourceCreated (ret);
 			}
 			return ret;
-		} catch (...) { }
+		} catch (...) {
+		}
 #endif
 
 		/* only create mp3s for audition: no announce, no peaks */
 		if (!announce && (!AudioFileSource::get_build_peakfiles () || defer_peaks)) {
 			try {
-				Source* src = new Mp3FileSource (s, path, chn, flags);
+				Source*                   src = new Mp3FileSource (s, path, chn, flags);
 				boost::shared_ptr<Source> ret (src);
 				BOOST_MARK_SOURCE (ret);
 				return ret;
 
-			} catch (failed_constructor& err) { }
+			} catch (failed_constructor& err) {
+			}
 
 			try {
-				Source* src = new FFMPEGFileSource (s, path, chn, flags);
+				Source*                   src = new FFMPEGFileSource (s, path, chn, flags);
 				boost::shared_ptr<Source> ret (src);
 				BOOST_MARK_SOURCE (ret);
 				return ret;
 
-			} catch (failed_constructor& err) { }
+			} catch (failed_constructor& err) {
+			}
 		}
 
 	} else if (type == DataType::MIDI) {
-
 		try {
 			boost::shared_ptr<SMFSource> src (new SMFSource (s, path));
-			Source::Lock lock(src->mutex());
-			src->load_model (lock, true);
+			Source::WriterLock           lock (src->mutex ());
 			BOOST_MARK_SOURCE (src);
 
 			if (announce) {
@@ -298,7 +319,6 @@ SourceFactory::createExternal (DataType type, Session& s, const string& path,
 			return src;
 		} catch (...) {
 		}
-
 	}
 
 	throw failed_constructor ();
@@ -306,16 +326,16 @@ SourceFactory::createExternal (DataType type, Session& s, const string& path,
 
 boost::shared_ptr<Source>
 SourceFactory::createWritable (DataType type, Session& s, const std::string& path,
-			       samplecnt_t rate, bool announce, bool defer_peaks)
+                               samplecnt_t rate, bool announce, bool defer_peaks)
 {
 	/* this might throw failed_constructor(), which is OK */
 
 	if (type == DataType::AUDIO) {
-		Source* src = new SndFileSource (s, path, string(),
-						 s.config.get_native_file_data_format(),
-						 s.config.get_native_file_header_format(),
-						 rate,
-		                                 SndFileSource::default_writable_flags);
+		Source*                   src = new SndFileSource (s, path, string (),
+                                                 s.config.get_native_file_data_format (),
+                                                 s.config.get_native_file_header_format (),
+                                                 rate,
+                                                 SndFileSource::default_writable_flags);
 		boost::shared_ptr<Source> ret (src);
 		BOOST_MARK_SOURCE (ret);
 
@@ -331,14 +351,10 @@ SourceFactory::createWritable (DataType type, Session& s, const std::string& pat
 		return ret;
 
 	} else if (type == DataType::MIDI) {
-                // XXX writable flags should belong to MidiSource too
+		// XXX writable flags should belong to MidiSource too
 		try {
 			boost::shared_ptr<SMFSource> src (new SMFSource (s, path, SndFileSource::default_writable_flags));
-
 			assert (src->writable ());
-
-			Source::Lock lock(src->mutex());
-			src->load_model (lock, true);
 			BOOST_MARK_SOURCE (src);
 
 			// no analysis data - this is a new file
@@ -389,21 +405,19 @@ SourceFactory::createForRecovery (DataType type, Session& s, const std::string&
 
 boost::shared_ptr<Source>
 SourceFactory::createFromPlaylist (DataType type, Session& s, boost::shared_ptr<Playlist> p, const PBD::ID& orig, const std::string& name,
-				   uint32_t chn, sampleoffset_t start, samplecnt_t len, bool copy, bool defer_peaks)
+                                   uint32_t chn, timepos_t start, timepos_t const& len, bool copy, bool defer_peaks)
 {
 	if (type == DataType::AUDIO) {
 		try {
-
-			boost::shared_ptr<AudioPlaylist> ap = boost::dynamic_pointer_cast<AudioPlaylist>(p);
+			boost::shared_ptr<AudioPlaylist> ap = boost::dynamic_pointer_cast<AudioPlaylist> (p);
 
 			if (ap) {
-
 				if (copy) {
 					ap.reset (new AudioPlaylist (ap, start, len, name, true));
-					start = 0;
+					start = timecnt_t::zero (Temporal::AudioTime);
 				}
 
-				Source* src = new AudioPlaylistSource (s, orig, name, ap, chn, start, len, Source::Flag (0));
+				Source*                   src = new AudioPlaylistSource (s, orig, name, ap, chn, start, len, Source::Flag (0));
 				boost::shared_ptr<Source> ret (src);
 
 				if (setup_peakfile (ret, defer_peaks)) {
@@ -421,30 +435,7 @@ SourceFactory::createFromPlaylist (DataType type, Session& s, boost::shared_ptr<
 		}
 
 	} else if (type == DataType::MIDI) {
-
-		try {
-
-			boost::shared_ptr<MidiPlaylist> ap = boost::dynamic_pointer_cast<MidiPlaylist>(p);
-
-			if (ap) {
-
-				if (copy) {
-					ap.reset (new MidiPlaylist (ap, start, len, name, true));
-					start = 0;
-				}
-
-				Source* src = new MidiPlaylistSource (s, orig, name, ap, chn, start, len, Source::Flag (0));
-				boost::shared_ptr<Source> ret (src);
-
-				SourceCreated (ret);
-				return ret;
-			}
-		}
-
-		catch (failed_constructor& err) {
-			/* relax - return at function scope */
-		}
-
+		/* fail - not implemented, and probably too difficult to do */
 	}
 
 	throw failed_constructor ();
