@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2020 Robin Gareus <robin@gareus.org>
+ * Copyright (C) 2019-2023 Robin Gareus <robin@gareus.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,12 +56,14 @@ using namespace Presonus;
 VST3Plugin::VST3Plugin (AudioEngine& engine, Session& session, VST3PI* plug)
 	: Plugin (engine, session)
 	, _plug (plug)
+	, _parameter_queue (128 + plug->parameter_count ())
 {
 	init ();
 }
 
 VST3Plugin::VST3Plugin (const VST3Plugin& other)
 	: Plugin (other)
+	, _parameter_queue (128 + other.parameter_count ())
 {
 	boost::shared_ptr<VST3PluginInfo> nfo = boost::dynamic_pointer_cast<VST3PluginInfo> (other.get_info ());
 	_plug = new VST3PI (nfo->m, nfo->unique_id);
@@ -121,6 +123,9 @@ VST3Plugin::parameter_change_handler (VST3PI::ParameterChange t, uint32_t param,
 			Plugin::EndTouch (param);
 			break;
 		case VST3PI::ValueChange:
+			_parameter_queue.write_one (PV (param, value));
+			/* fallthrough */
+		case VST3PI::ParamValueChanged:
 			/* emit ParameterChangedExternally, mark preset dirty */
 			Plugin::parameter_changed_externally (param, value);
 			break;
@@ -163,7 +168,14 @@ VST3Plugin::default_value (uint32_t port)
 void
 VST3Plugin::set_parameter (uint32_t port, float val, sampleoffset_t when)
 {
-	_plug->set_parameter (port, val, when);
+	if (!_plug->active () || AudioEngine::instance()->in_process_thread()) {
+		/* directly use VST3PI::_input_param_changes */
+		_plug->set_parameter (port, val, when);
+	} else {
+		assert (when == 0);
+		_plug->set_parameter (port, val, when, false);
+		_parameter_queue.write_one (PV (port, val));
+	}
 	Plugin::set_parameter (port, val, when);
 }
 
@@ -266,7 +278,54 @@ VST3Plugin::describe_io_port (ARDOUR::DataType dt, bool input, uint32_t id) cons
 PluginOutputConfiguration
 VST3Plugin::possible_output () const
 {
-	return Plugin::possible_output (); // TODO
+	auto const& bi (_plug->bus_info_out ());
+	if (bi.size() < 2) {
+		return Plugin::possible_output ();
+	}
+#if 0
+	PluginOutputConfiguration oc;
+	int32_t sum = 0;
+	for (auto const& n : bi) {
+		sum += n.second.n_chn;
+		oc.insert (sum);
+	}
+	return oc;
+#else
+	/* first main out, + individual stereo main outs, +all main outs, + individual aux outs */
+
+	auto i         = bi.begin ();
+	int32_t sum    = i->second.n_chn;
+	bool seen_aux  = i->second.type == Vst::kAux;
+	bool seen_mono = sum == 1;
+
+	PluginOutputConfiguration oc;
+	oc.insert (sum);
+
+	for (++i; i != bi.end (); ++i) {
+		if (seen_aux || seen_mono) {
+			sum += i->second.n_chn;
+			oc.insert (sum);
+		}
+		else if (i->second.type == Vst::kAux) {
+			oc.insert (sum);
+			seen_aux = true;
+			sum += i->second.n_chn;
+			oc.insert (sum);
+		} else {
+			sum += i->second.n_chn;
+			if (i->second.n_chn == 1) {
+				seen_mono = true;
+				oc.insert (sum);
+			} else if (!seen_mono) {
+				oc.insert (sum);
+			}
+		}
+	}
+	if (!seen_aux && seen_mono) {
+		oc.insert (sum);
+	}
+	return oc;
+#endif
 }
 
 /* ****************************************************************************
@@ -554,9 +613,18 @@ VST3Plugin::set_state (const XMLNode& node, int version)
 			continue;
 		}
 
+		/* This is not required, PluginInsert::set_state calls
+		 * set_control_ids() which already calls VST3Plugin::set_parameter.
+		 *
+		 * However there /may/ not be controllables for all parameters. Doing
+		 * this here also prevents an additional pass to synchronize the controller
+		 * via VST3PI::load_state -> VST3PI::update_shadow_data -> addParameterData
+		 */
+#if 1
 		if (!_plug->try_set_parameter_by_id (param_id, value)) {
 			warning << string_compose (_("VST3<%1>: Invalid Vst::ParamID in VST3Plugin::set_state"), name ()) << endmsg;
 		}
+#endif
 	}
 
 	XMLNode* chunk;
@@ -622,6 +690,11 @@ VST3Plugin::connect_and_run (BufferSet&  bufs,
                              ChanMapping const& in_map, ChanMapping const& out_map,
                              pframes_t n_samples, samplecnt_t offset)
 {
+	Glib::Threads::Mutex::Lock tm (_plug->process_lock (), Glib::Threads::TRY_LOCK);
+	if (!tm.locked ()) {
+		return 0;
+	}
+
 	DEBUG_TRACE (DEBUG::VST3Process, string_compose ("%1 run %2 offset %3\n", name (), n_samples, offset));
 	Plugin::connect_and_run (bufs, start, end, speed, in_map, out_map, n_samples, offset);
 
@@ -639,7 +712,7 @@ VST3Plugin::connect_and_run (BufferSet&  bufs,
 
 	{
 		TempoMap::SharedPtr tmap (TempoMap::use());
-		const TempoMetric&  metric (tmap->metric_at (start));
+		const TempoMetric&  metric (tmap->metric_at (timepos_t (start)));
 		const BBT_Time&     bbt (metric.bbt_at (timepos_t (start)));
 
 		context.tempo              = metric.tempo().quarter_notes_per_minute ();
@@ -717,6 +790,12 @@ VST3Plugin::connect_and_run (BufferSet&  bufs,
 		_connected_outputs[i] = valid;
 	}
 
+	/* apply parameter changes */
+	PV pv;
+	while (_parameter_queue.read (&pv, 1)) {
+		_plug->set_parameter (pv.port, pv.val, 0);
+	}
+
 	in_index = 0;
 	for (int32_t i = 0; i < (int32_t)_plug->n_midi_inputs (); ++i) {
 		bool     valid = false;
@@ -775,6 +854,8 @@ VST3Plugin::load_preset (PresetRecord r)
 		return false;
 	}
 
+	Glib::Threads::Mutex::Lock lx (_plug->process_lock ());
+
 	if (tmp[0] == "VST3-P") {
 		int program = PBD::atoi (tmp[2]);
 		assert (!r.user);
@@ -798,6 +879,8 @@ VST3Plugin::load_preset (PresetRecord r)
 		}
 	}
 
+	lx.release ();
+
 	if (ok) {
 		Plugin::load_preset (r);
 	}
@@ -1002,6 +1085,8 @@ VST3PluginInfo::get_presets (bool user_only) const
 		p.push_back (Plugin::PresetRecord (uri, preset_name, is_user));
 	}
 
+	std::sort (p.begin (), p.end ());
+
 	return p;
 }
 
@@ -1180,6 +1265,8 @@ VST3PI::VST3PI (boost::shared_ptr<ARDOUR::VST3PluginModule> m, std::string uniqu
 	}
 
 	int32 n_params = _controller->getParameterCount ();
+	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3 parameter count: %1\n", n_params));
+
 	for (int32 i = 0; i < n_params; ++i) {
 		Vst::ParameterInfo pi;
 		if (_controller->getParameterInfo (i, pi) != kResultTrue) {
@@ -1228,6 +1315,12 @@ VST3PI::VST3PI (boost::shared_ptr<ARDOUR::VST3PluginModule> m, std::string uniqu
 		_update_ctrl.push_back (false);
 	}
 
+	if (_n_midi_inputs > 0 || _n_midi_outputs > 0) {
+		n_params += 128;
+	} else if (n_params == 0) {
+		n_params = 16; /* arbitrary baseline, grows as needed */
+	}
+
 	_input_param_changes.set_n_params (n_params);
 	_output_param_changes.set_n_params (n_params);
 
@@ -1377,6 +1470,12 @@ VST3PI::restartComponent (int32 flags)
 	DEBUG_TRACE (DEBUG::VST3Callbacks, string_compose ("VST3PI::restartComponent %1%2\n", std::hex, flags));
 
 	if (flags & Vst::kReloadComponent) {
+		Glib::Threads::Mutex::Lock pl (_process_lock, Glib::Threads::NOT_LOCK);
+		if (!AudioEngine::instance()->in_process_thread()) {
+			pl.acquire ();
+		} else {
+			assert (0); // a plugin should not call this while processing
+		}
 		/* according to the spec, "The host has to unload completely
 		 * the plug-in (controller/processor) and reload it."
 		 *
@@ -1389,12 +1488,30 @@ VST3PI::restartComponent (int32 flags)
 		activate ();
 	}
 	if (flags & Vst::kParamValuesChanged) {
+		Glib::Threads::Mutex::Lock pl (_process_lock, Glib::Threads::NOT_LOCK);
+		if (!AudioEngine::instance()->in_process_thread()) {
+			pl.acquire ();
+		}
 		update_shadow_data ();
 	}
 	if (flags & Vst::kLatencyChanged) {
-		/* need to re-activate the plugin as per spec */
-		deactivate ();
-		activate ();
+		/* https://forums.steinberg.net/t/reporting-latency-change/201601
+		 * mentions that the host plugin should be deactivated before querying
+		 * latency. However the official spec does not require this.
+		 *
+		 * However other implementations do not call setActive(false/true) when 
+		 * the latency changes, and Ardour does not require it either, latency
+		 * changes are automatically picked up.
+		 */
+		Glib::Threads::Mutex::Lock pl (_process_lock, Glib::Threads::NOT_LOCK);
+		if (!AudioEngine::instance()->in_process_thread()) {
+			/* Some plugins (e.g BlendEQ) call this from the process,
+			 * IPlugProcessor::ProcessBuffers. In that case taking the
+			 * _process_lock would deadlock.
+			 */
+			pl.acquire ();
+		}
+		_plugin_latency.reset ();
 	}
 	if (flags & Vst::kIoChanged) {
 		warning << "VST3: Vst::kIoChanged (not implemented)" << endmsg;
@@ -1434,9 +1551,9 @@ VST3PI::performEdit (Vst::ParamID id, Vst::ParamValue v)
 		float value               = v;
 		_shadow_data[idx->second] = value;
 		_update_ctrl[idx->second] = true;
-		set_parameter_internal (id, value, 0, true);
+		/* set_parameter_internal() is called via OnParameterChange */
 		value = _controller->normalizedParamToPlain (id, value);
-		OnParameterChange (ValueChange, idx->second, v); /* EMIT SIGNAL */
+		OnParameterChange (ValueChange, idx->second, value); /* EMIT SIGNAL */
 	}
 	return kResultOk;
 }
@@ -1600,15 +1717,6 @@ VST3PI::count_channels (Vst::MediaType media, Vst::BusDirection dir, Vst::BusTyp
 	for (int32 i = 0; i < n_busses; ++i) {
 		Vst::BusInfo bus;
 		if (_component->getBusInfo (media, dir, i, bus) == kResultTrue && bus.busType == type) {
-#if 1
-			if ((type == Vst::kMain && i != 0) || (type == Vst::kAux && i != 1)) {
-				/* For now allow we only support one main bus, and one aux-bus.
-				 * Also an aux-bus by itself is currently N/A.
-				 */
-				continue;
-			}
-#endif
-
 			std::string bus_name     = tchar_to_utf8 (bus.name);
 			bool        is_sidechain = (type == Vst::kAux) && (dir == Vst::kInput);
 
@@ -1621,7 +1729,7 @@ VST3PI::count_channels (Vst::MediaType media, Vst::BusDirection dir, Vst::BusTyp
 				return std::min<int32> (1, bus.channelCount);
 #else
 				/* Some plugin leave it at zero, even though they accept events */
-				_io_name[media][dir].push_back (Plugin::IOPortDescription (bus_name, is_sidechain));
+				_io_name[media][dir].push_back (Plugin::IOPortDescription (bus_name, is_sidechain, "", 0, i));
 				return 1;
 #endif
 			} else {
@@ -1632,9 +1740,15 @@ VST3PI::count_channels (Vst::MediaType media, Vst::BusDirection dir, Vst::BusTyp
 					} else {
 						channel_name = bus_name;
 					}
-					_io_name[media][dir].push_back (Plugin::IOPortDescription (channel_name, is_sidechain, bus_name, j));
+					_io_name[media][dir].push_back (Plugin::IOPortDescription (channel_name, is_sidechain, bus_name, j, i));
 				}
 				n_channels += bus.channelCount;
+
+				if (dir == Vst::kInput) {
+					_bus_info_in.insert (std::make_pair(i, AudioBusInfo (type, bus.channelCount)));
+				} else {
+					_bus_info_out.insert (std::make_pair(i, AudioBusInfo (type, bus.channelCount)));
+				}
 			}
 		}
 	}
@@ -1716,15 +1830,15 @@ VST3PI::print_parameter (Vst::ParamID id, Vst::ParamValue value) const
 }
 
 uint32_t
-VST3PI::n_audio_inputs () const
+VST3PI::n_audio_inputs (bool with_aux) const
 {
-	return _n_inputs + _n_aux_inputs;
+	return _n_inputs + (with_aux ? _n_aux_inputs : 0);
 }
 
 uint32_t
-VST3PI::n_audio_outputs () const
+VST3PI::n_audio_outputs (bool with_aux) const
 {
-	return _n_outputs + _n_aux_outputs;
+	return _n_outputs + (with_aux ? _n_aux_outputs : 0);
 }
 
 uint32_t
@@ -1762,14 +1876,18 @@ VST3PI::try_set_parameter_by_id (Vst::ParamID id, float value)
 	if (idx == _ctrl_id_index.end ()) {
 		return false;
 	}
-	set_parameter (idx->second, value, 0);
+	set_parameter (idx->second, value, 0, true /* OK, called from set_state */);
 	return true;
 }
 
 void
-VST3PI::set_parameter (uint32_t p, float value, int32 sample_off)
+VST3PI::set_parameter (uint32_t p, float value, int32 sample_off, bool to_list)
 {
-	set_parameter_internal (index_to_id (p), value, sample_off, false);
+	if (to_list) {
+		set_parameter_internal (index_to_id (p), value, sample_off, false);
+	} else {
+		value = _controller->plainParamToNormalized (index_to_id (p), value);
+	}
 	_shadow_data[p] = value;
 	_update_ctrl[p] = true;
 }
@@ -1802,6 +1920,7 @@ VST3PI::set_program (int pgm, int32 sample_off)
 #endif
 	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::set_program pgm: %1 val: %2 (norm: %3)\n", pgm, value, _controller->plainParamToNormalized (id, pgm)));
 
+	/* must not be called concurrently with processing */
 	int32 index;
 	_input_param_changes.addParameterData (id, index)->addPoint (sample_off, value, index);
 	_controller->setParamNormalized (id, value);
@@ -1847,6 +1966,7 @@ VST3PI::update_shadow_data ()
 			_input_param_changes.addParameterData (i->second, index)->addPoint (0, v, index);
 #endif
 			_shadow_data[i->first] = v;
+			OnParameterChange (ParamValueChanged, i->first, v); /* EMIT SIGNAL */
 		}
 	}
 }
@@ -1877,6 +1997,7 @@ VST3PI::update_contoller_param ()
 void
 VST3PI::set_parameter_by_id (Vst::ParamID id, float value, int32 sample_off)
 {
+	/* called in rt-thread from evoral_to_vst3 */
 	set_parameter_internal (id, value, sample_off, true);
 	std::map<Vst::ParamID, uint32_t>::const_iterator idx = _ctrl_id_index.find (id);
 	if (idx != _ctrl_id_index.end ()) {
@@ -1892,6 +2013,7 @@ VST3PI::set_parameter_internal (Vst::ParamID id, float& value, int32 sample_off,
 	if (!normalized) {
 		value = _controller->plainParamToNormalized (id, value);
 	}
+	/* must not be called concurrently with processing */
 	_input_param_changes.addParameterData (id, index)->addPoint (sample_off, value, index);
 }
 
@@ -1978,6 +2100,14 @@ VST3PI::enable_io (std::vector<bool> const& ins, std::vector<bool> const& outs)
 		return;
 	}
 
+	/* some plugins, notably JUCE based ones, require the plugin to be
+	 * inactive to change bus arrangements.
+	 */
+	bool was_active = _is_processing;
+	if (!deactivate ()) {
+		DEBUG_TRACE (DEBUG::VST3Config, "VST3PI::enable_io failed to deactivate plugin\n");
+	}
+
 	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: ins = %1 == %3 outs = %2 == %4\n", ins.size (), outs.size (), n_audio_inputs (), n_audio_outputs ()));
 
 	_enabled_audio_in  = ins;
@@ -1989,115 +2119,82 @@ VST3PI::enable_io (std::vector<bool> const& ins, std::vector<bool> const& outs)
 	assert (_n_bus_in == _component->getBusCount (Vst::kAudio, Vst::kInput));
 	assert (_n_bus_out == _component->getBusCount (Vst::kAudio, Vst::kOutput));
 
-	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: n_bus_in = %1 n_bus_in = %2\n", _n_bus_in, _n_bus_out));
+	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: n_bus_in = %1 n_bus_out = %2\n", _n_bus_in, _n_bus_out));
 
 	typedef std::vector<Vst::SpeakerArrangement> VSTSpeakerArrangements;
 	VSTSpeakerArrangements sa_in;
 	VSTSpeakerArrangements sa_out;
 
-	bool                    enable = false;
-	Vst::SpeakerArrangement sa     = 0;
+	size_t cnt  = 0;
 
-	for (int i = 0; i < _n_inputs; ++i) {
-		if (ins[i]) {
-			enable = true;
-		}
-		sa |= (uint64_t)1 << i;
-	}
-	if (_n_inputs > 0) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kInput, 0, %1)\n", enable));
-		_component->activateBus (Vst::kAudio, Vst::kInput, 0, enable);
-		sa_in.push_back (sa);
-	}
-
-	enable = false;
-	sa     = 0;
-	for (int i = 0; i < _n_aux_inputs; ++i) {
-		if (ins[i + _n_inputs]) {
-			enable = true;
-		}
-		sa |= (uint64_t)1 << i;
-	}
-	if (_n_aux_inputs > 0) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kInput, 1, %1)\n", enable));
-		_component->activateBus (Vst::kAudio, Vst::kInput, 1, enable);
-		sa_in.push_back (sa);
-	}
-
-	/* disable remaining input busses and set their speaker-count to zero */
 	while (sa_in.size () < (VSTSpeakerArrangements::size_type) _n_bus_in) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kInput, %1, false)\n", sa_in.size ()));
-		_component->activateBus (Vst::kAudio, Vst::kInput, sa_in.size (), false);
-		sa_in.push_back (0);
-	}
-
-	enable = false;
-	sa     = 0;
-	for (int i = 0; i < _n_outputs; ++i) {
-		if (outs[i]) {
-			enable = true;
+		bool enable                = false;
+		Vst::SpeakerArrangement sa = 0;
+		for (int i = 0; i < _bus_info_in[sa_in.size ()].n_chn; ++i) {
+			if (ins[cnt++]) {
+				sa |= (uint64_t)1 << i;
+				enable = true;
+			}
 		}
-		sa |= (uint64_t)1 << i;
-	}
-
-	if (_n_outputs > 0) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kOutput, 0, %1)\n", enable));
-		_component->activateBus (Vst::kAudio, Vst::kOutput, 0, enable);
-		sa_out.push_back (sa);
-	}
-
-	enable = false;
-	sa     = 0;
-	for (int i = 0; i < _n_aux_outputs; ++i) {
-		if (outs[i + _n_outputs]) {
-			enable = true;
+		/* special case for Left only == Mono */
+		if (sa == 1 /*Vst::SpeakerArr::kSpeakerL */) {
+			sa = Vst::SpeakerArr::kMono; /* 1 << 19 */
 		}
-		sa |= (uint64_t)1 << i;
-	}
-	if (_n_aux_outputs > 0) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kOutput, 1, %1)\n", enable));
-		_component->activateBus (Vst::kAudio, Vst::kOutput, 1, enable);
-		sa_out.push_back (sa);
+
+		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kInput, %1, %2, %3%4)\n", sa_in.size (), enable, std::hex, sa));
+		_component->activateBus (Vst::kAudio, Vst::kInput, sa_in.size (), enable);
+		sa_in.push_back (sa);
 	}
 
+	cnt = 0;
 	while (sa_out.size () < (VSTSpeakerArrangements::size_type) _n_bus_out) {
-		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kOutput, %1, false)\n", sa_out.size ()));
-		_component->activateBus (Vst::kAudio, Vst::kOutput, sa_out.size (), false);
-		sa_out.push_back (0);
-	}
-
-	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: setBusArrangements ins = %1 outs = %2\n", sa_in.size (), sa_out.size ()));
-	_processor->setBusArrangements (sa_in.size () > 0 ? &sa_in[0] : NULL, sa_in.size (),
-	                                sa_out.size () > 0 ? &sa_out[0] : NULL, sa_out.size ());
-
-#if 0
-	for (int32 i = 0; i < _n_bus_in; ++i) {
-		Vst::SpeakerArrangement arr;
-		if (_processor->getBusArrangement (Vst::kInput, i, arr) == kResultOk) {
-			int cc = Vst::SpeakerArr::getChannelCount (arr);
-			std::cerr << "VST3: Input BusArrangements: " << i << " chan: " << cc << " bits: " << arr << "\n";
+		bool enable = false;
+		Vst::SpeakerArrangement sa = 0;
+		for (int i = 0; i < _bus_info_out[sa_out.size ()].n_chn; ++i) {
+			if (outs[cnt++]) {
+				sa |= (uint64_t)1 << i;
+				enable = true;
+			}
 		}
+		/* special case for Left only == Mono */
+		if (sa == 1 /*Vst::SpeakerArr::kSpeakerL */) {
+			sa = Vst::SpeakerArr::kMono; /* 1 << 19 */
+		}
+		DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: activateBus (kAudio, kOutput, %1, %2, %3%4)\n", sa_out.size (), enable, std::hex, sa));
+		_component->activateBus (Vst::kAudio, Vst::kOutput, sa_out.size (), enable);
+		sa_out.push_back (sa);
 	}
-	for (int32 i = 0; i < _n_bus_out; ++i) {
-		Vst::SpeakerArrangement arr;
-		if (_processor->getBusArrangement (Vst::kOutput, i, arr) == kResultOk) {
-			int cc = Vst::SpeakerArr::getChannelCount (arr);
-			std::cerr << "VST3: Output BusArrangements: " << i << " chan: " << cc << " bits: " << arr << "\n";
+
+	Vst::SpeakerArrangement null_arrangement = {};
+#ifndef NDEBUG
+	tresult rv =
+#endif
+	_processor->setBusArrangements (sa_in.size () > 0 ? &sa_in[0] : &null_arrangement, sa_in.size (),
+	                                sa_out.size () > 0 ? &sa_out[0] : &null_arrangement, sa_out.size ());
+
+#ifndef NDEBUG
+	DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3PI::enable_io: setBusArrangements ins = %1 outs = %2 | rv = %3\n", sa_in.size (), sa_out.size (), rv));
+
+	if (DEBUG_ENABLED (DEBUG::VST3Config)) {
+		for (int32 i = 0; i < _n_bus_in; ++i) {
+			Vst::SpeakerArrangement arr;
+			if (_processor->getBusArrangement (Vst::kInput, i, arr) == kResultOk) {
+				int cc = Vst::SpeakerArr::getChannelCount (arr);
+				DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3: Input BusArrangements: %1 chan: %2 bits: %3%4\n", i, cc, std::hex, arr));
+			}
+		}
+		for (int32 i = 0; i < _n_bus_out; ++i) {
+			Vst::SpeakerArrangement arr;
+			if (_processor->getBusArrangement (Vst::kOutput, i, arr) == kResultOk) {
+				int cc = Vst::SpeakerArr::getChannelCount (arr);
+				DEBUG_TRACE (DEBUG::VST3Config, string_compose ("VST3: Output BusArrangements: %1 chan: %2 bits: %3%4\n", i, cc, std::hex, arr));
+			}
 		}
 	}
 #endif
-}
-
-static int32
-used_bus_count (int auxes, int inputs)
-{
-	if (auxes > 0 && inputs > 0) {
-		return 2;
+	if (was_active) {
+		activate ();
 	}
-	if (auxes == 0 && inputs == 0) {
-		return 0;
-	}
-	return 1;
 }
 
 void
@@ -2110,8 +2207,8 @@ VST3PI::process (float** ins, float** outs, uint32_t n_samples)
 	data.numSamples         = n_samples;
 	data.processMode        = AudioEngine::instance ()->freewheeling () ? Vst::kOffline : Vst::kRealtime;
 	data.symbolicSampleSize = Vst::kSample32;
-	data.numInputs          = used_bus_count (_n_aux_inputs, _n_inputs); // _n_bus_in;
-	data.numOutputs         = used_bus_count (_n_aux_outputs, _n_outputs); // _n_bus_out;
+	data.numInputs          = _n_bus_in;
+	data.numOutputs         = _n_bus_out;
 	data.inputs             = inputs;
 	data.outputs            = outputs;
 
@@ -2122,48 +2219,24 @@ VST3PI::process (float** ins, float** outs, uint32_t n_samples)
 	data.inputParameterChanges  = &_input_param_changes;
 	data.outputParameterChanges = &_output_param_changes;
 
-	int used_ins = 0;
-	int used_outs = 0;
+	uint32_t used_ins = 0;
+	uint32_t used_outs = 0;
 
-	if (_n_bus_in > 0) {
-		inputs[0].silenceFlags     = 0;
-		inputs[0].numChannels      = _n_inputs;
-		inputs[0].channelBuffers32 = ins;
-		++used_ins;
-	}
-
-	if (_n_bus_in > 1 && _n_aux_inputs > 0) {
-		inputs[1].silenceFlags     = 0;
-		inputs[1].numChannels      = _n_aux_inputs;
-		inputs[1].channelBuffers32 = &ins[_n_inputs];
-		++used_ins;
-	}
-
-	if (_n_bus_out > 0) {
-		outputs[0].silenceFlags     = 0;
-		outputs[0].numChannels      = _n_outputs;
-		outputs[0].channelBuffers32 = outs;
-		++used_outs;
-	}
-
-	if (_n_bus_out > 1 && _n_aux_outputs > 0) {
-		outputs[1].silenceFlags     = 0;
-		outputs[1].numChannels      = _n_outputs;
-		outputs[1].channelBuffers32 = &outs[_n_outputs];
-		++used_outs;
-	}
-
-	for (int i = used_ins; i < _n_bus_in; ++i) {
+	for (int i = 0; i < _n_bus_in; ++i) {
 		inputs[i].silenceFlags     = 0;
-		inputs[i].numChannels      = 0;
-		inputs[i].channelBuffers32 = 0;
+		inputs[i].numChannels      = _bus_info_in[i].n_chn;
+		inputs[i].channelBuffers32 = &ins[used_ins];
+		used_ins += _bus_info_in[i].n_chn;
 	}
 
-	for (int i = used_outs; i < _n_bus_out; ++i) {
+	for (int i = 0; i < _n_bus_out; ++i) {
 		outputs[i].silenceFlags     = 0;
-		outputs[i].numChannels      = 0;
-		outputs[i].channelBuffers32 = 0;
+		outputs[i].numChannels      = _bus_info_out[i].n_chn;
+		outputs[i].channelBuffers32 = &outs[used_outs];
+		used_outs += _bus_info_out[i].n_chn;
 	}
+	assert (used_ins == n_audio_inputs ());
+	assert (used_outs == n_audio_outputs ());
 
 	/* and go */
 	if (_processor->process (data) != kResultOk) {
