@@ -21,9 +21,6 @@
 #include <sys/mman.h>
 #include <sys/time.h>
 
-#include <mach/thread_policy.h>
-#include <mach/thread_act.h>
-
 #undef nil
 
 #include <glibmm.h>
@@ -34,6 +31,8 @@
 #include "pbd/error.h"
 #include "pbd/file_utils.h"
 #include "pbd/pthread_utils.h"
+
+#include "ardour/debug.h"
 #include "ardour/filesystem_paths.h"
 #include "ardour/port_manager.h"
 #include "pbd/i18n.h"
@@ -100,7 +99,7 @@ CoreAudioBackend::CoreAudioBackend (AudioEngine& e, AudioBackendInfo& info)
 	, _last_process_start (0)
 	, _input_audio_device("")
 	, _output_audio_device("")
-	, _midi_driver_option(get_standard_device_name(DeviceNone))
+	, _midi_driver_option(_("CoreMidi"))
 	, _samplerate (48000)
 	, _samples_per_period (1024)
 	, _n_inputs (0)
@@ -833,9 +832,44 @@ void *
 CoreAudioBackend::coreaudio_process_thread (void *arg)
 {
 	ThreadData* td = reinterpret_cast<ThreadData*> (arg);
+
+	if (pbd_mach_set_realtime_policy (pthread_self (), td->period_ns, false)) {
+		DEBUG_TRACE (PBD::DEBUG::BackendThreads, "AudioEngine: process thread failed to set mach realtime policy.\n");
+	}
+
+#if MAC_OS_X_VERSION_MAX_ALLOWED >= 110000
+	if (td->_joined_workgroup) {
+		/* have WG */
+		int res = os_workgroup_join (td->_workgroup, &td->_join_token);
+		switch (res) {
+			case 0:
+				DEBUG_TRACE (PBD::DEBUG::BackendThreads, "AudioEngine: process thread joined AUHAL workgroup.");
+				break;
+			case EALREADY:
+				DEBUG_TRACE (PBD::DEBUG::BackendThreads, "AudioEngine: process thread is already in a workgroup.");
+				td->_joined_workgroup = false;
+				break;
+			case EINVAL:
+				DEBUG_TRACE (PBD::DEBUG::BackendThreads, "AudioEngine: invalid workgroup for process thread.");
+				td->_joined_workgroup = false;
+				break;
+			default:
+				td->_joined_workgroup = false;
+				DEBUG_TRACE (PBD::DEBUG::BackendThreads, "AudioEngine: process thread failed to join AUHAL workgroup.");
+				break;
+		}
+	}
+#endif
+
 	boost::function<void ()> f = td->f;
-	delete td;
 	f ();
+
+#if MAC_OS_X_VERSION_MAX_ALLOWED >= 110000
+	if (td->_joined_workgroup) {
+		os_workgroup_leave (td->_workgroup, &td->_join_token);
+	}
+#endif
+	delete td;
 	return 0;
 }
 
@@ -843,7 +877,15 @@ int
 CoreAudioBackend::create_process_thread (boost::function<void()> func)
 {
 	pthread_t   thread_id;
-	ThreadData* td = new ThreadData (this, func, PBD_RT_STACKSIZE_PROC);
+	ThreadData* td = new ThreadData (this, func, PBD_RT_STACKSIZE_PROC, 1e9 * _samples_per_period / _samplerate);
+
+#if MAC_OS_X_VERSION_MAX_ALLOWED >= 110000
+	if (_pcmio->workgroup (td->_workgroup)) {
+		td->_joined_workgroup = true;
+	} else {
+		td->_joined_workgroup = false;
+	}
+#endif
 
 	if (pbd_realtime_pthread_create (PBD_SCHED_FIFO, PBD_RT_PRI_PROC, PBD_RT_STACKSIZE_PROC,
 	                              &thread_id, coreaudio_process_thread, td)) {
@@ -854,10 +896,6 @@ CoreAudioBackend::create_process_thread (boost::function<void()> func)
 		PBD::warning << _("AudioEngine: process thread failed to acquire realtime permissions.") << endmsg;
 	}
 
-	if (pbd_mach_set_realtime_policy (thread_id, 1e9 * _samples_per_period / _samplerate, false)) {
-		PBD::warning << _("AudioEngine: process thread failed to set mach realtime policy.") << endmsg;
-	}
-
 	_threads.push_back (thread_id);
 	return 0;
 }
@@ -1179,7 +1217,7 @@ CoreAudioBackend::set_latency_range (PortEngine::PortHandle port_handle, bool fo
 {
 	boost::shared_ptr<BackendPort> port = boost::dynamic_pointer_cast<BackendPort> (port_handle);
 	if (!valid_port (port)) {
-		PBD::warning << _("BackendPort::set_latency_range (): invalid port.") << endmsg;
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "BackendPort::set_latency_range (): invalid port.");
 		return;
 	}
 	port->set_latency_range (latency_range, for_playback);
@@ -1191,7 +1229,7 @@ CoreAudioBackend::get_latency_range (PortEngine::PortHandle port_handle, bool fo
 	boost::shared_ptr<BackendPort> port = boost::dynamic_pointer_cast<BackendPort> (port_handle);
 	LatencyRange r;
 	if (!valid_port (port)) {
-		PBD::warning << _("BackendPort::get_latency_range (): invalid port.") << endmsg;
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "BackendPort::get_latency_range (): invalid port.");
 		r.min = 0;
 		r.max = 0;
 		return r;
@@ -1218,8 +1256,6 @@ CoreAudioBackend::get_buffer (PortEngine::PortHandle port_handle, pframes_t nfra
 {
 	boost::shared_ptr<BackendPort> port = boost::dynamic_pointer_cast<BackendPort> (port_handle);
 	assert (port);
-	assert (valid_port (port));
-	if (!port || !valid_port (port)) return NULL; // XXX remove me
 	return port->get_buffer (nframes);
 }
 
