@@ -38,6 +38,7 @@
 #include "pbd/compose.h"
 #include "pbd/pthread_utils.h"
 
+#include "ardour/debug.h"
 #include "ardour/port_manager.h"
 
 #include "pbd/i18n.h"
@@ -871,7 +872,8 @@ DummyAudioBackend::set_latency_range (PortEngine::PortHandle port_handle, bool f
 {
 	BackendPortPtr port = boost::dynamic_pointer_cast<BackendPort> (port_handle);
 	if (!valid_port (port)) {
-		PBD::error << _("DummyPort::set_latency_range (): invalid port.") << endmsg;
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "DummyPort::set_latency_range (): invalid port.");
+		return;
 	}
 	port->set_latency_range (latency_range, for_playback);
 }
@@ -882,7 +884,7 @@ DummyAudioBackend::get_latency_range (PortEngine::PortHandle port_handle, bool f
 	LatencyRange r;
 	BackendPortPtr port = boost::dynamic_pointer_cast<BackendPort> (port_handle);
 	if (!valid_port (port)) {
-		PBD::error << _("DummyPort::get_latency_range (): invalid port.") << endmsg;
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "DummyPort::get_latency_range (): invalid port.");
 		r.min = 0;
 		r.max = 0;
 		return r;
@@ -1387,7 +1389,7 @@ void DummyAudioPort::midi_to_wavetable (DummyMidiBuffer const * const src, size_
 		// somewhat arbitrary mapping for quick visual feedback
 		float v = -.5f;
 		if ((*it)->size() == 3) {
-			const unsigned char *d = (*it)->const_data();
+			const unsigned char *d = (*it)->data();
 			if ((d[0] & 0xf0) == 0x90) { // note on
 				v = .25f + d[2] / 512.f;
 			}
@@ -1890,9 +1892,9 @@ DummyMidiEvent::DummyMidiEvent (const DummyMidiEvent& other)
 	, _timestamp (other.timestamp ())
 	, _data (0)
 {
-	if (other.size () && other.const_data ()) {
+	if (other.size () && other.data ()) {
 		_data = (uint8_t*) malloc (other.size ());
-		memcpy (_data, other.const_data (), other.size ());
+		memcpy (_data, other.data (), other.size ());
 	}
 };
 
