@@ -80,7 +80,7 @@ PortAudioBackend::PortAudioBackend (AudioEngine& e, AudioBackendInfo& info)
 	, _max_deviation_us(0)
 	, _input_audio_device("")
 	, _output_audio_device("")
-	, _midi_driver_option(get_standard_device_name(DeviceNone))
+	, _midi_driver_option(winmme_driver_name)
 	, _samplerate (48000)
 	, _samples_per_period (1024)
 	, _n_inputs (0)
@@ -1407,6 +1407,7 @@ PortAudioBackend::set_latency_range (PortEngine::PortHandle port_handle, bool fo
 	boost::shared_ptr<BackendPort> port = boost::dynamic_pointer_cast<BackendPort>(port_handle);
 	if (!valid_port (port)) {
 		DEBUG_PORTS("BackendPort::set_latency_range (): invalid port.\n");
+		return;
 	}
 	port->set_latency_range (latency_range, for_playback);
 }
@@ -1446,8 +1447,6 @@ PortAudioBackend::get_buffer (PortEngine::PortHandle port_handle, pframes_t nfra
 {
 	boost::shared_ptr<BackendPort> port = boost::dynamic_pointer_cast<BackendPort>(port_handle);
 	assert (port);
-	assert (valid_port (port));
-	if (!port || !valid_port (port)) return NULL; // XXX remove me
 	return port->get_buffer (nframes);
 }
 
