@@ -70,7 +70,7 @@ PulseAudioBackend::~PulseAudioBackend ()
 	clear_ports ();
 }
 
-/* Pulseaudio */
+/* PulseAudio */
 void
 PulseAudioBackend::close_pulse (bool unlock)
 {
@@ -211,19 +211,10 @@ int
 PulseAudioBackend::init_pulse ()
 {
 	pa_sample_spec ss;
-	pa_buffer_attr ba;
-
 	ss.channels = N_CHANNELS;
 	ss.rate     = _samplerate;
 	ss.format   = PA_SAMPLE_FLOAT32LE;
 
-	/* https://freedesktop.org/software/pulseaudio/doxygen/structpa__buffer__attr.html */
-	ba.minreq    = _samples_per_period * N_CHANNELS * sizeof (float);
-	ba.maxlength = 2 * ba.minreq;
-	ba.prebuf    = (uint32_t)-1;
-	ba.tlength   = (uint32_t)-1;
-	ba.fragsize  = 0; // capture only
-
 	if (!pa_sample_spec_valid (&ss)) {
 		PBD::error << _("PulseAudioBackend: Default sample spec not valid") << endmsg;
 		return AudioDeviceInvalidError;
@@ -294,22 +285,26 @@ PulseAudioBackend::init_pulse ()
 	pa_stream_set_underflow_callback (p_stream, PulseAudioBackend::stream_xrun_cb, this);
 	pa_stream_set_overflow_callback (p_stream, PulseAudioBackend::stream_xrun_cb, this);
 
+	/* PulseAudio buffer strategy: Be explicit for small latency and avoid using PA auto tuning.
+	 * The user specified a buffer size (_samples_per_period).
+	 * Specify the PA buffer to be twice as big so it can use double buffering (maxlength).
+	 * Aim for keeping the buffer full (tlength).
+	 * Fill up the buffer before starting playback (prebuf).
+	 * Immediately ask for more data when there is room for the buffer size (minreq because PA_STREAM_EARLY_REQUESTS).
+	 */
+	pa_buffer_attr ba;
+	/* https://freedesktop.org/software/pulseaudio/doxygen/structpa__buffer__attr.html */
+	ba.minreq    = _samples_per_period * N_CHANNELS * sizeof (float);
+	ba.maxlength = 2 * ba.minreq;
+	ba.tlength   = ba.maxlength;
+	ba.prebuf    = ba.tlength;
+	ba.fragsize  = 0; // capture only
+
 	/* https://freedesktop.org/software/pulseaudio/doxygen/def_8h.html#a6966d809483170bc6d2e6c16188850fc */
 	pa_stream_flags_t sf = (pa_stream_flags_t) (
-			  (int)PA_STREAM_START_CORKED
-#if 0 /* may happen during freewheel export */
-			| (int)PA_STREAM_FAIL_ON_SUSPEND
-#endif
-			| (int)PA_STREAM_NO_REMAP_CHANNELS
+			  (int)PA_STREAM_NO_REMAP_CHANNELS
 			| (int)PA_STREAM_NO_REMIX_CHANNELS
-			| (int)PA_STREAM_EARLY_REQUESTS
-
-			/*
-			| (int)PA_STREAM_DONT_MOVE
-			| (int)PA_STREAM_ADJUST_LATENCY
-			| (int)PA_STREAM_AUTO_TIMING_UPDATE
-			| (int)PA_STREAM_INTERPOLATE_TIMING
-			*/
+			| (int)PA_STREAM_EARLY_REQUESTS  // request more data as soon as minreq is reached
 			);
 
 	if (pa_stream_connect_playback (p_stream, NULL, &ba, sf, NULL, NULL) < 0) {
@@ -334,7 +329,7 @@ PulseAudioBackend::init_pulse ()
 std::string
 PulseAudioBackend::name () const
 {
-	return X_("Pulseaudio");
+	return X_("PulseAudio");
 }
 
 bool
@@ -847,7 +842,7 @@ PulseAudioBackend::port_factory (std::string const & name, ARDOUR::DataType type
 			port = new PulseMidiPort (*this, name, flags);
 			break;
 		default:
-			PBD::error << string_compose (_("%1::register_port: Invalid Data Type."), _instance_name) << endmsg;
+			PBD::error << string_compose (_("%1::port_factory: Invalid Data Type."), _instance_name) << endmsg;
 			return 0;
 	}
 
@@ -991,16 +986,6 @@ PulseAudioBackend::main_process_thread ()
 	manager.registration_callback ();
 	manager.graph_order_callback ();
 
-	/* begin streaming */
-	if (!cork_pulse (false)) {
-		PBD::error << _("PulseAudioBackend::main_process_thread initial uncork failed.") << endmsg;
-		_active = false;
-		if (_run) {
-			engine.halted_callback ("PulseAudio: cannot uncork stream");
-		}
-		return 0;
-	}
-
 	_dsp_load_calc.reset ();
 	stream_latency_update_cb (p_stream, this);
 
@@ -1151,7 +1136,7 @@ static bool already_configured ();
 static bool available ();
 
 static ARDOUR::AudioBackendInfo _descriptor = {
-	_("Pulseaudio"),
+	_("PulseAudio"),
 	instantiate,
 	deinstantiate,
 	backend_factory,
