@@ -22,6 +22,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+//#define CANVAS_PROFILE
+
 /** @file  canvas/canvas.cc
  *  @brief Implementation of the main canvas classes.
  */
@@ -124,6 +126,10 @@ Canvas::zoomed ()
 void
 Canvas::render (Rect const & area, Cairo::RefPtr<Cairo::Context> const & context) const
 {
+#ifdef CANVAS_PROFILE
+	const int64_t start = g_get_monotonic_time ();
+#endif
+
 	PreRender (); // emit signal
 
 	_last_render_start_timestamp = g_get_monotonic_time();
@@ -168,6 +174,12 @@ Canvas::render (Rect const & area, Cairo::RefPtr<Cairo::Context> const & context
 #endif
 	}
 
+#ifdef CANVAS_PROFILE
+	const int64_t end = g_get_monotonic_time ();
+	const int64_t elapsed = end - start;
+	std::cout << "GtkCanvas::render " << area << " " << (elapsed / 1000.f) << " ms\n";
+#endif
+
 }
 
 void
@@ -543,12 +555,12 @@ GtkCanvas::GtkCanvas ()
 }
 
 void
-GtkCanvas::use_nsglview ()
+GtkCanvas::use_nsglview (bool retina)
 {
 	assert (!_nsglview);
 	assert (!get_realized());
 #ifdef ARDOUR_CANVAS_NSVIEW_TAG // patched gdkquartz.h
-	_nsglview = Gtkmm2ext::nsglview_create (this);
+	_nsglview = Gtkmm2ext::nsglview_create (this, retina);
 #endif
 }
 
@@ -572,8 +584,8 @@ GtkCanvas::pick_current_item (int state)
 	pick_current_item (Duple (x, y), state);
 }
 
-/** Given @param point (a position in window coordinates)
- *  and mouse state @param state, check to see if _current_item
+/** Given @p point (a position in window coordinates)
+ *  and mouse state @p state, check to see if _current_item
  *  (which will be used to deliver events) should change.
  */
 void
@@ -656,7 +668,7 @@ GtkCanvas::pick_current_item (Duple const & point, int state)
 }
 
 /** Deliver a series of enter & leave events based on the pointer position being at window
- * coordinate @param point, and pointer @param state (modifier keys, etc)
+ * coordinate @p point, and pointer @p state (modifier keys, etc)
  */
 void
 GtkCanvas::deliver_enter_leave (Duple const & point, int state)
@@ -679,7 +691,7 @@ GtkCanvas::deliver_enter_leave (Duple const & point, int state)
 	enter_event.state = state;
 
 	/* Events delivered to canvas items are expected to be in canvas
-	 * coordinates but @param point is in window coordinates.
+	 * coordinates but @p point is in window coordinates.
 	 */
 
 	Duple c = window_to_canvas (point);
