@@ -26,6 +26,7 @@
 #include "canvas/canvas.h"
 #include "canvas/debug.h"
 #include "canvas/item.h"
+#include "canvas/root_group.h"
 #include "canvas/scroll_group.h"
 
 using namespace std;
@@ -41,9 +42,16 @@ Item::Item (Canvas* canvas)
 	, _parent (0)
 	, _scroll_parent (0)
 	, _visible (true)
-	, _bounding_box_dirty (true)
+	, _pack_options (PackOptions (0))
+	, _layout_sensitive (false)
 	, _lut (0)
+	, _resize_queued (false)
+	, _requested_width (-1)
+	, _requested_height (-1)
 	, _ignore_events (false)
+	, _scroll_translation (true)
+	, _bounding_box_dirty (true)
+	, change_blocked (0)
 {
 	DEBUG_TRACE (DEBUG::CanvasItems, string_compose ("new canvas item %1\n", this));
 }
@@ -55,9 +63,16 @@ Item::Item (Item* parent)
 	, _parent (parent)
 	, _scroll_parent (0)
 	, _visible (true)
-	, _bounding_box_dirty (true)
+	, _pack_options (PackOptions (0))
+	, _layout_sensitive (false)
 	, _lut (0)
+	, _resize_queued (false)
+	, _requested_width (-1)
+	, _requested_height (-1)
 	, _ignore_events (false)
+	, _scroll_translation (true)
+	, _bounding_box_dirty (true)
+	, change_blocked (0)
 {
 	DEBUG_TRACE (DEBUG::CanvasItems, string_compose ("new canvas item %1\n", this));
 
@@ -76,9 +91,16 @@ Item::Item (Item* parent, Duple const& p)
 	, _scroll_parent (0)
 	, _position (p)
 	, _visible (true)
-	, _bounding_box_dirty (true)
+	, _pack_options (PackOptions (0))
+	, _layout_sensitive (false)
 	, _lut (0)
+	, _resize_queued (false)
+	, _requested_width (-1.)
+	, _requested_height(-1.)
 	, _ignore_events (false)
+	, _scroll_translation (true)
+	, _bounding_box_dirty (true)
+	, change_blocked (0)
 {
 	DEBUG_TRACE (DEBUG::CanvasItems, string_compose ("new canvas item %1\n", this));
 
@@ -278,13 +300,24 @@ Item::set_position (Duple p)
 	if (visible()) {
 		_canvas->item_moved (this, pre_change_parent_bounding_box);
 
-
 		if (_parent) {
-			_parent->child_changed ();
+			_parent->child_changed (true);
 		}
 	}
 }
 
+void
+Item::layout()
+{
+	for (list<Item*>::iterator i = _items.begin(); i != _items.end(); ++i) {
+		if ((*i)->resize_queued()) {
+			(*i)->layout ();
+		}
+	}
+
+	_resize_queued = false;
+}
+
 void
 Item::set_x_position (Coord x)
 {
@@ -378,7 +411,7 @@ Item::propagate_show_hide ()
 	/* bounding box may have changed while we were hidden */
 
 	if (_parent) {
-		_parent->child_changed ();
+		_parent->child_changed (true);
 	}
 
 	_canvas->item_shown_or_hidden (this);
@@ -407,6 +440,7 @@ Item::unparent ()
 {
 	_parent = 0;
 	_scroll_parent = 0;
+	_layout_sensitive = false;
 }
 
 void
@@ -428,6 +462,9 @@ Item::reparent (Item* new_parent, bool already_added)
 	_canvas = _parent->canvas ();
 
 	find_scroll_parent ();
+	if (!_layout_sensitive) {
+		set_layout_sensitive (_parent->layout_sensitive());
+	}
 
 	if (!already_added) {
 		_parent->add (this);
@@ -566,33 +603,118 @@ Item::is_descendant_of (const Item& candidate) const
 }
 
 void
-Item::grab_focus ()
+Item::size_allocate (Rect const & r)
 {
-	/* XXX */
+	begin_change ();
+	_size_allocate (r);
+	set_bbox_dirty ();
+	end_change ();
 }
 
 void
-Item::size_allocate (Rect const & r)
+Item::_size_allocate (Rect const & r)
 {
-	_allocation = r;
+	if (_layout_sensitive) {
+		/* this definitely affects the item */
+		_position = Duple (r.x0, r.y0);
+		/* this may have no effect on the item */
+		_allocation = r;
+	}
+
+	size_allocate_children (r);
+}
+
+void
+Item::size_allocate_children (Rect const & r)
+{
+	/* this does nothing by default. Containers like Box or
+	 * ConstraintPacker can override it to do "smart" layout based on this
+	 * Item's allocation.
+	 */
+
+	/* parent was told "you get width x height @ x,y""
+	 *
+	 * x must be 0 and y must be 0 in parent-relatve coordinates
+	 */
+
+	Rect parent_relative = r.translate (-_position);
+
+	if (_items.size() == 1 && _items.front()->layout_sensitive()) {
+		_items.front()->size_allocate (parent_relative);
+	}
+}
+
+void
+Item::size_request (double& w, double& h) const
+{
+	Rect r (bounding_box());
+
+	w = _requested_width < 0 ? r.width()  : _requested_width;
+	h = _requested_width < 0 ? r.height() : _requested_height;
+}
+
+void
+Item::set_size_request (double w, double h)
+{
+	/* allow reset to zero or require that both are positive */
+
+	begin_change ();
+	_requested_width = w;
+	_requested_height = h;
+	set_bbox_dirty ();
+	end_change ();
+}
+
+void
+Item::set_size_request_to_display_given_text (const std::vector<std::string>& strings, gint hpadding, gint vpadding)
+{
+	Glib::RefPtr<Pango::Context> context = _canvas->get_pango_context();
+	Glib::RefPtr<Pango::Layout> layout = Pango::Layout::create (context);
+
+	int width, height;
+	int width_max = 0;
+	int height_max = 0;
+
+	vector<string> copy;
+	const vector<string>* to_use;
+	vector<string>::const_iterator i;
+
+	for (i = strings.begin(); i != strings.end(); ++i) {
+		if ((*i).find_first_of ("gy") != string::npos) {
+			/* contains a descender */
+			break;
+		}
+	}
+
+	if (i == strings.end()) {
+		/* make a copy of the strings then add one that has a descender */
+		copy = strings;
+		copy.push_back ("g");
+		to_use = &copy;
+	} else {
+		to_use = &strings;
+	}
+
+	for (vector<string>::const_iterator i = to_use->begin(); i != to_use->end(); ++i) {
+		layout->set_text (*i);
+		layout->get_pixel_size (width, height);
+		width_max = max (width_max,width);
+		height_max = max (height_max, height);
+	}
+
+	set_size_request (width_max + hpadding, height_max + vpadding);
 }
 
 /** @return Bounding box in this item's coordinates */
 ArdourCanvas::Rect
-Item::bounding_box (bool for_own_purposes) const
+Item::bounding_box () const
 {
-	if (_bounding_box_dirty) {
+	if (bbox_dirty()) {
 		compute_bounding_box ();
 		assert (!_bounding_box_dirty);
 		add_child_bounding_boxes ();
 	}
 
-	if (!for_own_purposes) {
-		if (_allocation) {
-			return _allocation;
-		}
-	}
-
 	return _bounding_box;
 }
 
@@ -623,24 +745,31 @@ void
 Item::redraw () const
 {
 	if (visible() && _bounding_box && _canvas) {
-		_canvas->request_redraw (item_to_window (_bounding_box));
+		_canvas->request_redraw (item_to_window (_bounding_box, false));
 	}
+
 }
 
 void
 Item::begin_change ()
 {
-	_pre_change_bounding_box = bounding_box ();
+	if (!change_blocked) {
+		_pre_change_bounding_box = bounding_box ();
+	}
 }
 
 void
 Item::end_change ()
 {
+	if (change_blocked) {
+		return;
+	}
+
 	if (visible()) {
 		_canvas->item_changed (this, _pre_change_bounding_box);
 
 		if (_parent) {
-			_parent->child_changed ();
+			_parent->child_changed (_pre_change_bounding_box != _bounding_box);
 		}
 	}
 }
@@ -725,12 +854,14 @@ Item::covers (Duple const & point) const
 {
 	Duple p = window_to_item (point);
 
-	if (_bounding_box_dirty) {
-		compute_bounding_box ();
+	if (bbox_dirty()) {
+		(void) bounding_box ();
 	}
 
 	Rect r = bounding_box();
 
+	/* bounding box uses item coordinates, with _position as the origin */
+
 	if (!r) {
 		return false;
 	}
@@ -740,6 +871,8 @@ Item::covers (Duple const & point) const
 
 /* nesting/grouping API */
 
+#define CANVAS_DEBUG 1
+
 void
 Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context) const
 {
@@ -751,10 +884,10 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 	std::vector<Item*> items = _lut->get (area);
 
 #ifdef CANVAS_DEBUG
-	if (DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
-		cerr << string_compose ("%1%7 %2 @ %7 render %5 @ %6 %3 items out of %4\n",
-					_canvas->render_indent(), (name.empty() ? string ("[unnamed]") : name), items.size(), _items.size(), area, _position, this,
-					whatami());
+	if (_canvas->debug_render() || DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
+		cerr << string_compose (">>>> %1%8 %2 @ %7 render %5 @ %6 %3 items out of %4\n",
+		                        _canvas->render_indent(), (name.empty() ? string ("[unnamed]") : name), items.size(), _items.size(), area, _position, 0 /* this */,
+		                        whatami());
 	}
 #endif
 
@@ -764,8 +897,8 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 
 		if (!(*i)->visible ()) {
 #ifdef CANVAS_DEBUG
-			if (DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
-				cerr << _canvas->render_indent() << "Item " << (*i)->whatami() << " [" << (*i)->name << "] invisible - skipped\n";
+			if (_canvas->debug_render() || DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
+				cerr << _canvas->render_indent() << "Item " << (*i)->whoami() << " invisible - skipped\n";
 			}
 #endif
 			continue;
@@ -775,8 +908,8 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 
 		if (!item_bbox) {
 #ifdef CANVAS_DEBUG
-			if (DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
-				cerr << _canvas->render_indent() << "Item " << (*i)->whatami() << " [" << (*i)->name << "] empty - skipped\n";
+			if (_canvas->debug_render() || DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
+				cerr << _canvas->render_indent() << "Item " << (*i)->whoami() << " empty - skipped\n";
 			}
 #endif
 			continue;
@@ -789,15 +922,13 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 			Rect draw = d;
 			if (draw.width() && draw.height()) {
 #ifdef CANVAS_DEBUG
-				if (DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
+				if (_canvas->debug_render() || DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
 					if (dynamic_cast<Container*>(*i) == 0) {
 						cerr << _canvas->render_indent() << "render "
 						     << ' '
 						     << (*i)
 						     << ' '
-						     << (*i)->whatami()
-						     << ' '
-						     << (*i)->name
+						     << (*i)->whoami()
 						     << " item "
 						     << item_bbox
 						     << " window = "
@@ -818,9 +949,8 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 		} else {
 
 #ifdef CANVAS_DEBUG
-			if (DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
-				cerr << string_compose ("%1skip render of %2 %3, no intersection between %4 and %5\n", _canvas->render_indent(), (*i)->whatami(),
-							(*i)->name, item, area);
+			if (_canvas->debug_render() || DEBUG_ENABLED(PBD::DEBUG::CanvasRender)) {
+				cerr << string_compose ("%1skip render of %2, no intersection between %3 and %4\n", _canvas->render_indent(), (*i)->whoami(), item, area);
 			}
 #endif
 
@@ -829,6 +959,7 @@ Item::render_children (Rect const & area, Cairo::RefPtr<Cairo::Context> context)
 
 	--render_depth;
 }
+#undef CANVAS_DEBUG
 
 void
 Item::prepare_for_render_children (Rect const & area) const
@@ -891,11 +1022,11 @@ Item::add_child_bounding_boxes (bool include_hidden) const
 			continue;
 		}
 
-		Rect group_bbox = (*i)->item_to_parent (item_bbox);
+		Rect child_bbox = (*i)->item_to_parent (item_bbox);
 		if (have_one) {
-			bbox = bbox.extend (group_bbox);
+			bbox = bbox.extend (child_bbox);
 		} else {
-			bbox = group_bbox;
+			bbox = child_bbox;
 			have_one = true;
 		}
 	}
@@ -907,6 +1038,20 @@ Item::add_child_bounding_boxes (bool include_hidden) const
 	}
 }
 
+void
+Item::queue_resize()
+{
+	_resize_queued = true;
+
+	if (_parent) {
+		_parent->queue_resize ();
+	}
+
+	if (this == _canvas->root()) {
+		_canvas->queue_resize ();
+	}
+}
+
 void
 Item::add (Item* i)
 {
@@ -915,7 +1060,7 @@ Item::add (Item* i)
 	_items.push_back (i);
 	i->reparent (this, true);
 	invalidate_lut ();
-	_bounding_box_dirty = true;
+	set_bbox_dirty ();
 }
 
 void
@@ -926,7 +1071,7 @@ Item::add_front (Item* i)
 	_items.push_front (i);
 	i->reparent (this, true);
 	invalidate_lut ();
-	_bounding_box_dirty = true;
+	set_bbox_dirty();
 }
 
 void
@@ -950,9 +1095,10 @@ Item::remove (Item* i)
 	}
 
 	i->unparent ();
+	i->set_layout_sensitive (false);
 	_items.remove (i);
 	invalidate_lut ();
-	_bounding_box_dirty = true;
+	set_bbox_dirty ();
 
 	end_change ();
 }
@@ -965,8 +1111,7 @@ Item::clear (bool with_delete)
 	clear_items (with_delete);
 
 	invalidate_lut ();
-	_bounding_box_dirty = true;
-
+	set_bbox_dirty ();
 	end_change ();
 }
 
@@ -1061,13 +1206,16 @@ Item::invalidate_lut () const
 }
 
 void
-Item::child_changed ()
+Item::child_changed (bool bbox_changed)
 {
 	invalidate_lut ();
-	_bounding_box_dirty = true;
 
-	if (_parent) {
-		_parent->child_changed ();
+	if (bbox_changed) {
+		set_bbox_dirty ();
+	}
+
+	if (!change_blocked && _parent) {
+		_parent->child_changed (bbox_changed);
 	}
 }
 
@@ -1129,14 +1277,8 @@ Item::dump (ostream& o) const
 {
 	ArdourCanvas::Rect bb = bounding_box();
 
-	o << _canvas->indent() << whatami() << ' ' << this << " self-Visible ? " << self_visible() << " visible ? " << visible();
-	o << " @ " << position();
-
-#ifdef CANVAS_DEBUG
-	if (!name.empty()) {
-		o << ' ' << name;
-	}
-#endif
+	o << _canvas->indent() << whoami() << ' ' << this << " self-Visible ? " << self_visible() << " visible ? " << visible() << " layout " << layout_sensitive()
+	  << " @ " << position() << " +/- " << scroll_offset();
 
 	if (bb) {
 		o << endl << _canvas->indent() << "\tbbox: " << bb;
@@ -1185,3 +1327,63 @@ ArdourCanvas::operator<< (ostream& o, const Item& i)
 	return o;
 }
 
+void
+Item::set_layout_sensitive (bool yn)
+{
+	_layout_sensitive = yn;
+
+	for (list<Item*>::const_iterator i = _items.begin(); i != _items.end(); ++i) {
+		if (!(*i)->layout_sensitive()) {
+			(*i)->set_layout_sensitive (yn);
+		}
+	}
+}
+
+void
+Item::set_bbox_clean () const
+{
+	_bounding_box_dirty = false;
+}
+
+void
+Item::set_bbox_dirty () const
+{
+	_bounding_box_dirty = true;
+	Item* i = _parent;
+	while (i) {
+		i->set_bbox_dirty ();
+		i = i->parent ();
+	}
+}
+
+void
+Item::set_pack_options (PackOptions po)
+{
+	/* must be called before adding/packing Item in a Container */
+	_pack_options = po;
+}
+
+void
+Item::disable_scroll_translation ()
+{
+	_scroll_translation = false;
+}
+
+void
+Item::block_change_notifications ()
+{
+	if (!change_blocked) {
+		begin_change ();
+	}
+	change_blocked++;
+}
+
+void
+Item::unblock_change_notifications ()
+{
+	if (change_blocked) {
+		if (--change_blocked == 0) {
+			end_change ();
+		}
+	}
+}
