@@ -20,8 +20,11 @@
 
 #include <iostream>
 #include <cairomm/context.h>
+
 #include "pbd/compose.h"
 
+#include "gtkmm2ext/utils.h"
+
 #include "canvas/canvas.h"
 #include "canvas/rectangle.h"
 #include "canvas/debug.h"
@@ -29,9 +32,25 @@
 using namespace std;
 using namespace ArdourCanvas;
 
+/* Rectangle notes
+ *
+ * A Rectangle is defined by an ArdourCanvas::Rect which encloses every pixel
+ * that the Rectangle might draw. If the Rect is (0, 0, 10, 10) then a filled
+ * version of the Rectangle will paint every pixel up to and including those
+ * edges.
+ *
+ * If there is a border to the Rectangle, it will be drawn *INSIDE* the
+ * boundary given by the Rect. The border will include (at minimum) the outer
+ * pixel edge(s) of the Rectangle.
+ *
+ * This makes ArdourCanvas::Rectangle follow the semantics implied by CSS's
+ * box-sizing: border-box, rather than box-sizing: content-box
+ */
+
 Rectangle::Rectangle (Canvas* c)
 	: Item (c)
 	, _outline_what ((What) (LEFT | RIGHT | TOP | BOTTOM))
+	, _corner_radius (0.0)
 {
 }
 
@@ -39,12 +58,14 @@ Rectangle::Rectangle (Canvas* c, Rect const & rect)
 	: Item (c)
 	, _rect (rect)
 	, _outline_what ((What) (LEFT | RIGHT | TOP | BOTTOM))
+	, _corner_radius (0.0)
 {
 }
 
 Rectangle::Rectangle (Item* parent)
 	: Item (parent)
 	, _outline_what ((What) (LEFT | RIGHT | TOP | BOTTOM))
+	, _corner_radius (0.0)
 {
 }
 
@@ -52,25 +73,30 @@ Rectangle::Rectangle (Item* parent, Rect const & rect)
 	: Item (parent)
 	, _rect (rect)
 	, _outline_what ((What) (LEFT | RIGHT | TOP | BOTTOM))
+	, _corner_radius (0.0)
 {
 }
 
 void
 Rectangle::render (Rect const & area, Cairo::RefPtr<Cairo::Context> context) const
 {
-	/* In general, a Rectangle will have a _position of (0,0) within its
-	   parent, and its extent is actually defined by _rect. But in the
-	   unusual case that _position is set to something other than (0,0),
-	   we should take that into account when rendering.
+	/* Note that item_to_window() already takes _position into account (as
+	   part of item_to_canvas()
 	*/
 
-	Rect self (item_to_window (_rect.translate (_position), false));
+	Rect self (item_to_window (_rect));
 	const Rect draw = self.intersection (area);
 
 	if (!draw) {
 		return;
 	}
 
+	if (_corner_radius) {
+		context->save ();
+		Gtkmm2ext::rounded_rectangle (context, self.x0, self.y0, self.width(), self.height(), _corner_radius);
+		context->clip ();
+	}
+
 	if (_fill && !_transparent) {
 		if (_stops.empty()) {
 			setup_fill_context (context);
@@ -78,7 +104,11 @@ Rectangle::render (Rect const & area, Cairo::RefPtr<Cairo::Context> context) con
 			setup_gradient_context (context, self, Duple (draw.x0, draw.y0));
 		}
 
-		context->rectangle (draw.x0, draw.y0, draw.width(), draw.height());
+		if (_corner_radius) {
+			Gtkmm2ext::rounded_rectangle (context, draw.x0, draw.y0, draw.width(), draw.height(), _corner_radius);
+		} else {
+			context->rectangle (draw.x0, draw.y0, draw.width(), draw.height());
+		}
 		context->fill ();
 	}
 
@@ -86,27 +116,16 @@ Rectangle::render (Rect const & area, Cairo::RefPtr<Cairo::Context> context) con
 
 		setup_outline_context (context);
 
-		/* the goal here is that if the border is 1 pixel
-		 * thick, it will precisely align with the corner
-		 * coordinates of the rectangle. So if the rectangle
-		 * has a left edge at 0 and a right edge at 10, then
-		 * the left edge must span 0..1, the right edge
-		 * must span 10..11 because the first and final pixels
-		 * to be colored are actually "at" 0.5 and 10.5 (midway
-		 * between the integer coordinates).
-		 *
-		 * See the Cairo FAQ on single pixel lines for more
-		 * detail.
-		 */
+		const double shift = _outline_width * 0.5;
+		self = self.translate (Duple (shift, shift));
 
-		if (fmod (_outline_width, 2.0)  != 0.0) {
-			const double shift = _outline_width * 0.5;
-			self = self.translate (Duple (shift, shift));
-		}
+		if (_outline_what == ALL) {
 
-		if (_outline_what == What (LEFT|RIGHT|BOTTOM|TOP)) {
-
-			context->rectangle (self.x0, self.y0, self.width(), self.height());
+			if (_corner_radius) {
+				Gtkmm2ext::rounded_rectangle (context, self.x0, self.y0, self.width() - _outline_width, self.height() - _outline_width, _corner_radius);
+			} else {
+				context->rectangle (self.x0, self.y0, self.width() - _outline_width, self.height() - _outline_width);
+			}
 
 		} else {
 
@@ -133,44 +152,30 @@ Rectangle::render (Rect const & area, Cairo::RefPtr<Cairo::Context> context) con
 
 		context->stroke ();
 	}
+
+	if (_corner_radius) {
+		context->restore ();
+	}
+
+	render_children (area, context);
+}
+
+void
+Rectangle::size_request (double& w, double& h) const
+{
+	w = _rect.width();
+	h = _rect.height();
 }
 
 void
 Rectangle::compute_bounding_box () const
 {
 	if (!_rect.empty()) {
-		Rect r = _rect.fix ();
-
-		/* if the outline is 1 pixel, then the actual
-		   bounding box is 0.5 pixels outside the stated
-		   corners of the rectangle.
-
-		   if the outline is 2 pixels, then the actual
-		   bounding box is 1.0 pixels outside the stated
-		   corners of the rectangle (so that the middle
-		   of the 2 pixel wide border passes through
-		   the corners, alternatively described as 1 row
-		   of pixels outside of the corners, and 1 row
-		   inside).
-
-		   if the outline is 3 pixels, then the actual
-		   bounding box is 1.5 outside the stated corners
-		   of the rectangle (so that the middle row of
-		   pixels of the border passes through the corners).
-
-		   if the outline is 4 pixels, then the actual bounding
-		   box is 2.0 pixels outside the stated corners
-		   of the rectangle, so that the border consists
-		   of 2 pixels outside the corners and 2 pixels inside.
-
-		   hence ... the bounding box is width * 0.5 larger
-		   than the rectangle itself.
-		*/
-
-		_bounding_box = r.expand (1.0 + _outline_width * 0.5);
+		// _bounding_box = _rect.fix().expand (1.0 + _outline_width * 0.5);
+		_bounding_box = _rect.fix().expand (_outline_width * 0.5);
 	}
 
-	_bounding_box_dirty = false;
+	set_bbox_clean ();
 }
 
 void
@@ -186,7 +191,7 @@ Rectangle::set (Rect const & r)
 
 		_rect = r;
 
-		_bounding_box_dirty = true;
+		set_bbox_dirty ();
 		end_change ();
 	}
 }
@@ -199,7 +204,7 @@ Rectangle::set_x0 (Coord x0)
 
 		_rect.x0 = x0;
 
-		_bounding_box_dirty = true;
+		set_bbox_dirty ();
 		end_change ();
 	}
 }
@@ -212,7 +217,7 @@ Rectangle::set_y0 (Coord y0)
 
 		_rect.y0 = y0;
 
-		_bounding_box_dirty = true;
+		set_bbox_dirty ();
 		end_change();
 	}
 }
@@ -225,7 +230,7 @@ Rectangle::set_x1 (Coord x1)
 
 		_rect.x1 = x1;
 
-		_bounding_box_dirty = true;
+		set_bbox_dirty ();
 		end_change ();
 	}
 }
@@ -238,7 +243,7 @@ Rectangle::set_y1 (Coord y1)
 
 		_rect.y1 = y1;
 
-		_bounding_box_dirty = true;
+		set_bbox_dirty ();
 		end_change ();
 	}
 }
@@ -275,3 +280,36 @@ Rectangle::vertical_fraction (double y) const
 
         return 1.0 - ((i.y - bbox.y0) / bbox.height());
 }
+
+void
+Rectangle::_size_allocate (Rect const & r)
+{
+	Item::_size_allocate (r);
+
+	if (_layout_sensitive) {
+		/* Set _position use the upper left of the Rect, and then set
+		   the _rect member with values that use _position as the
+		   origin.
+		*/
+		Rect r2 (0, 0, r.x1 - r.x0, r.y1 - r.y0);
+		set (r2);
+	}
+}
+
+void
+Rectangle::set_corner_radius (double r)
+{
+	/* note: this does not change the bounding box */
+
+	begin_change ();
+	_corner_radius = r;
+	end_change ();
+}
+
+void
+Rectangle::dump (std::ostream & o) const
+{
+	Item::dump (o);
+
+	o << _canvas->indent() << " outline: w " << outline_width() << " color " << outline_color() << " what 0x" << std::hex << _outline_what << std::dec << endl;
+}
