@@ -33,7 +33,7 @@
 #define isnan_local std::isnan
 #endif
 
-#define GUARD_POINT_DELTA(foo) (foo.time_domain () == Temporal::AudioTime ? Temporal::timecnt_t (64) : Temporal::timecnt_t (Beats (0, 1)))
+#define GUARD_POINT_DELTA(foo) ((foo).time_domain () == Temporal::AudioTime ? Temporal::timecnt_t (64) : Temporal::timecnt_t (Beats (0, 1)))
 
 #include <cassert>
 #include <cmath>
@@ -381,6 +381,14 @@ ControlList::thin (double thinning_factor)
 		return;
 	}
 
+	/* compat. In the past the actual (internal) value was used
+	 * to compute the area. For gain the range is 0..2 (exp).
+	 * Since we cannot change automation-thinning-factor
+	 * in user's existing config, we simply re-normalize
+	 * the thinning factor.
+	 */
+	thinning_factor *= .7071;
+
 	assert (is_sorted ());
 
 	bool changed = false;
@@ -407,9 +415,13 @@ ControlList::thin (double thinning_factor)
 				const double pw  = prev->when.samples ();
 				const double cw  = cur->when.samples ();
 
-				double area = fabs ((ppw * (prev->value - cur->value)) +
-				                    (pw * (cur->value - prevprev->value)) +
-				                    (cw * (prevprev->value - prev->value)));
+				const float ppv = _desc.to_interface (prevprev->value);
+				const float cv  = _desc.to_interface (cur->value);
+				const float pv  = _desc.to_interface (prev->value);
+
+				double area = fabs ((ppw * (pv - cv)) +
+				                    (pw * (cv - ppv)) +
+				                    (cw * (ppv - pv)));
 
 				if (area < thinning_factor) {
 					iterator tmp = pprev;
@@ -420,6 +432,7 @@ ControlList::thin (double thinning_factor)
 					 */
 
 					pprev = i;
+					prev  = cur;
 					_events.erase (tmp);
 					changed = true;
 					continue;
@@ -595,6 +608,7 @@ ControlList::add_guard_point (timepos_t const& time, timecnt_t const& offset)
 	 */
 	if (_in_write_pass && new_write_pass) {
 		WritePassStarted (); /* EMIT SIGNAL w/WriteLock */
+		did_write_during_pass = true;
 		new_write_pass = false;
 	}
 
@@ -814,7 +828,6 @@ ControlList::add (timepos_t const& time, double value, bool with_guards, bool wi
 
 			if (with_guards) {
 				add_guard_point (insert_position, timecnt_t (_time_domain));
-				did_write_during_pass = true;
 			} else {
 				/* not adding a guard, but we need to set iterator appropriately */
 				const ControlEvent cp (when, 0.0);
@@ -1932,8 +1945,8 @@ ControlList::paste (const ControlList& alist, timepos_t const& time)
 
 	/* when pasting a range of automation, first add guard points so the automation data before and after this range is retained */
 	const ControlEvent* last = alist.back ();
-	add_guard_point (time, -GUARD_POINT_DELTA (time));
-	add_guard_point (time + last->when, GUARD_POINT_DELTA (time));
+	add_guard_point (time, -GUARD_POINT_DELTA (*this));
+	add_guard_point (time + last->when, GUARD_POINT_DELTA (*this));
 
 	{
 		Glib::Threads::RWLock::WriterLock lm (_lock);
@@ -2184,8 +2197,8 @@ ControlList::dump (ostream& o)
 {
 	/* NOT LOCKED ... for debugging only */
 
-	for (EventList::iterator x = _events.begin (); x != _events.end (); ++x) {
-		o << (*x)->value << " @ " << (*x)->when << endl;
+	for (auto const & e : _events) {
+		o << e->value << " @ " << e->when << endl;
 	}
 }
 
