@@ -96,13 +96,13 @@ CairoWidget::set_canvas_widget ()
 }
 
 void
-CairoWidget::use_nsglview ()
+CairoWidget::use_nsglview (bool retina)
 {
 	assert (!_nsglview);
 	assert (!_canvas_widget);
 	assert (!get_realized());
 #ifdef ARDOUR_CANVAS_NSVIEW_TAG // patched gdkquartz.h
-	_nsglview = Gtkmm2ext::nsglview_create (this);
+	_nsglview = Gtkmm2ext::nsglview_create (this, retina);
 #endif
 }
 
