@@ -96,10 +96,9 @@ UI::UI (string application_name, string thread_name, int *argc, char ***argv)
 	}
 
 	/* the GUI event loop runs in the main thread of the app,
-	   which is assumed to have called this.
-	*/
-
-	run_loop_thread = Threads::Thread::self();
+	 * which is assumed to have called this.
+	 */
+	_run_loop_thread = PBD::Thread::self ();
 
 	/* store "this" as the UI-for-thread of this thread, same argument
 	   as for previous line.
@@ -144,9 +143,9 @@ UI::~UI ()
 }
 
 bool
-UI::caller_is_ui_thread ()
+UI::caller_is_ui_thread () const
 {
-	return Threads::Thread::self() == run_loop_thread;
+	return caller_is_self ();
 }
 
 int
@@ -390,13 +389,16 @@ UI::set_tip (Widget *w, const gchar *tip, const gchar *hlp)
 	}
 
 	if (action) {
-		Bindings* bindings = (Bindings*) w->get_data ("ardour-bindings");
-		if (!bindings) {
-			Gtk::Window* win = (Gtk::Window*) w->get_toplevel();
-			if (win) {
-				bindings = (Bindings*) win->get_data ("ardour-bindings");
+		/* get_bindings_from_widget_hierarchy */
+		Widget* ww = w;
+		Bindings* bindings = NULL;
+		do {
+			bindings = (Bindings*) ww->get_data ("ardour-bindings");
+			if (bindings) {
+				break;
 			}
-		}
+			ww = ww->get_parent ();
+		} while (ww);
 
 		if (!bindings) {
 			bindings = global_bindings;
