@@ -202,15 +202,16 @@ void
 WindowProxy::drop_window ()
 {
 	if (_window) {
+		unmap_connection.disconnect ();
 		_window->hide ();
 		delete_connection.disconnect ();
 		configure_connection.disconnect ();
 		map_connection.disconnect ();
-		unmap_connection.disconnect ();
 		delete _window;
 		_window = 0;
 		delete vistracker;
 		vistracker = 0;
+		_visible = false;
 	}
 }
 
@@ -227,8 +228,6 @@ WindowProxy::setup ()
 {
 	assert (_window);
 
-	assert (_window);
-
 	delete_connection.disconnect ();
 	configure_connection.disconnect ();
 	map_connection.disconnect ();
@@ -408,3 +407,26 @@ WindowProxy::set_state_mask (StateMask sm)
 {
 	_state_mask = sm;
 }
+
+void
+WindowProxy::set_transient_for (Gtk::Window& win)
+{
+	/* on macOS set_transient() calls _gdk_quartz_window_attach_to_parent()
+	 * which attaches the windows as child window to the parent. As side-effect
+	 * the child becomes the same window-level as the parent.
+	 *
+	 * This makes it hard to re-order siblings of the parent without explicit call to
+	 * re-order those (gdk_window_restack gdk_window_quartz_restack_toplevel).
+	 *
+	 * macOS has a rich concept of z-axis stacking per application, explict transient parents
+	 * are not required.
+	 *
+	 * https://developer.apple.com/documentation/appkit/nswindow/1419152-addchildwindow?language=objc
+	 * https://developer.apple.com/documentation/appkit/nswindowlevel?language=objc
+	 */
+#ifndef __APPLE__
+	if (_window) {
+		_window->set_transient_for (win);
+	}
+#endif
+}
