@@ -21,7 +21,7 @@
 #include "pbd/command.h"
 #include "pbd/xml++.h"
 
-XMLNode &Command::get_state()
+XMLNode &Command::get_state() const
 {
 	XMLNode *node = new XMLNode ("Command");
 	node->add_content("WARNING: Somebody forgot to subclass Command.");
