@@ -309,7 +309,7 @@ CC121::button_press_handler (MIDI::Parser &, MIDI::EventTwoBytes* tb)
 		if (_current_stripable) {
 			boost::shared_ptr<AutomationControl> gain = _current_stripable->gain_control ();
 			if (gain) {
-			  samplepos_t now = session->engine().sample_time();
+				timepos_t now (session->engine().sample_time());
 			  gain->start_touch (now);
 			}
 		}
@@ -352,15 +352,15 @@ CC121::button_release_handler (MIDI::Parser &, MIDI::EventTwoBytes* tb)
 
 	switch (id) {
 	case FaderTouch:
-	  fader_is_touched = false;
-	  if (_current_stripable) {
-	    boost::shared_ptr<AutomationControl> gain = _current_stripable->gain_control ();
-	    if (gain) {
-	      samplepos_t now = session->engine().sample_time();
-	      gain->stop_touch (now);
-	    }
-	  }
-	  break;
+		fader_is_touched = false;
+		if (_current_stripable) {
+			boost::shared_ptr<AutomationControl> gain = _current_stripable->gain_control ();
+			if (gain) {
+				timepos_t now (session->engine().sample_time());
+				gain->stop_touch (now);
+			}
+		}
+		break;
 	default:
 		break;
 	}
@@ -656,6 +656,8 @@ CC121::map_recenable_state ()
 			onoff = blink_state;
 		}
 		break;
+	default:
+		return; /* stupid compilers */
 	}
 
 	if (onoff != rec_enable_state) {
@@ -696,7 +698,7 @@ CC121::connect_session_signals()
 bool
 CC121::midi_input_handler (Glib::IOCondition ioc, boost::shared_ptr<ARDOUR::AsyncMIDIPort> port)
 {
-	DEBUG_TRACE (DEBUG::CC121, string_compose ("something happend on  %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
+	DEBUG_TRACE (DEBUG::CC121, string_compose ("something happened on  %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
 
 	if (ioc & ~IO_IN) {
 		return false;
@@ -715,7 +717,7 @@ CC121::midi_input_handler (Glib::IOCondition ioc, boost::shared_ptr<ARDOUR::Asyn
 
 
 XMLNode&
-CC121::get_state ()
+CC121::get_state () const
 {
 	XMLNode& node (ControlProtocol::get_state());
 
