@@ -78,7 +78,7 @@ FaderPort8::setup_actions ()
 #ifdef FP8_MUTESOLO_UNDO
 	BindMethod (BtnSoloClear, button_solo_clear);
 #else
-	BindAction (BtnSoloClear, "Main", "cancel-solo");
+	BindMethod (BtnSoloClear, cancel_all_solo);
 #endif
 	BindMethod (BtnMuteClear, button_mute_clear);
 
@@ -309,7 +309,7 @@ FaderPort8::button_varispeed (bool ffw)
 		// stop key-repeat
 		dynamic_cast<FP8RepeatButton*>(&b_ffw)->stop_repeat();
 		dynamic_cast<FP8RepeatButton*>(&b_rew)->stop_repeat();
-		session->request_locate (0, MustStop);
+		session->request_locate (0, false, MustStop);
 		return;
 	}
 
@@ -345,7 +345,7 @@ FaderPort8::button_solo_clear ()
 			if (!ac) {
 				continue;
 			}
-			ac->start_touch (ac->session().transport_sample());
+			ac->start_touch (timepos_t (ac->session().transport_sample()));
 			cl->push_back (ac);
 		}
 		if (!cl->empty()) {
@@ -370,7 +370,7 @@ FaderPort8::button_mute_clear ()
 				continue;
 			}
 			cl->push_back (ac);
-			ac->start_touch (ac->session().transport_sample());
+			ac->start_touch (timepos_t (ac->session().transport_sample()));
 		}
 		if (!cl->empty()) {
 			session->set_controls (cl, 1.0, PBD::Controllable::NoGroup);
@@ -410,7 +410,7 @@ FaderPort8::handle_encoder_pan (int steps)
 			ac = s->pan_azimuth_control ();
 		}
 		if (ac) {
-			ac->start_touch (ac->session().transport_sample());
+			ac->start_touch (timepos_t (ac->session().transport_sample()));
 			if (steps == 0) {
 				ac->set_value (ac->normal(), PBD::Controllable::UseGroup);
 			} else {
@@ -434,7 +434,7 @@ FaderPort8::handle_encoder_link (int steps)
 	}
 
 	double v = ac->internal_to_interface (ac->get_value(), true);
-	ac->start_touch (ac->session().transport_sample());
+	ac->start_touch (timepos_t (ac->session().transport_sample()));
 
 	if (steps == 0) {
 		ac->set_value (ac->normal(), PBD::Controllable::UseGroup);
@@ -548,13 +548,13 @@ FaderPort8::button_encoder ()
 			{
 				/* master || monitor level -- reset to 0dB */
 				boost::shared_ptr<AutomationControl> ac;
-				if (session->monitor_active() && !_ctrls.button (FP8Controls::BtnMaster).is_pressed ()) {
+				if (session->monitor_out() && !_ctrls.button (FP8Controls::BtnMaster).is_pressed ()) {
 					ac = session->monitor_out()->gain_control ();
 				} else if (session->master_out()) {
 					ac = session->master_out()->gain_control ();
 				}
 				if (ac) {
-					ac->start_touch (ac->session().transport_sample());
+					ac->start_touch (timepos_t (ac->session().transport_sample()));
 					ac->set_value (ac->normal(), PBD::Controllable::NoGroup);
 				}
 			}
@@ -571,7 +571,7 @@ FaderPort8::button_encoder ()
 				 * the current position and we're not rolling.
 				 */
 				samplepos_t where = session->audible_sample();
-				if (session->transport_stopped_or_stopping() && session->locations()->mark_at (where, session->sample_rate() / 100.0)) {
+				if (session->transport_stopped_or_stopping() && session->locations()->mark_at (timepos_t (where), timecnt_t (session->sample_rate() / 100.0))) {
 					return;
 				}
 
@@ -628,7 +628,7 @@ FaderPort8::encoder_navigate (bool neg, int steps)
 			{
 				/* master || monitor level */
 				boost::shared_ptr<AutomationControl> ac;
-				if (session->monitor_active() && !_ctrls.button (FP8Controls::BtnMaster).is_pressed ()) {
+				if (session->monitor_out() && !_ctrls.button (FP8Controls::BtnMaster).is_pressed ()) {
 					ac = session->monitor_out()->gain_control ();
 				} else if (session->master_out()) {
 					ac = session->master_out()->gain_control ();
@@ -636,7 +636,7 @@ FaderPort8::encoder_navigate (bool neg, int steps)
 				if (ac) {
 					double v = ac->internal_to_interface (ac->get_value());
 					v = std::max (0.0, std::min (1.0, v + steps * (neg ? -.01 : .01)));
-					ac->start_touch (ac->session().transport_sample());
+					ac->start_touch (timepos_t (ac->session().transport_sample()));
 					ac->set_value (ac->interface_to_internal(v), PBD::Controllable::NoGroup);
 				}
 			}
