@@ -356,10 +356,11 @@ FP8Strip::midi_touch (bool t)
 	if (!ac) {
 		return false;
 	}
+	timepos_t now (ac->session().transport_sample());
 	if (t) {
-		ac->start_touch (ac->session().transport_sample());
+		ac->start_touch (now);
 	} else {
-		ac->stop_touch (ac->session().transport_sample());
+		ac->stop_touch (now);
 	}
 	return true;
 }
@@ -375,7 +376,7 @@ FP8Strip::midi_fader (float val)
 	if (!ac) {
 		return false;
 	}
-	ac->start_touch (ac->session().transport_sample());
+	ac->start_touch (timepos_t (ac->session().transport_sample()));
 	ac->set_value (ac->interface_to_internal (val), group_mode ());
 	return true;
 }
@@ -400,7 +401,7 @@ FP8Strip::set_mute (bool on)
 	if (!_mute_ctrl) {
 		return;
 	}
-	_mute_ctrl->start_touch (_mute_ctrl->session().transport_sample());
+	_mute_ctrl->start_touch (timepos_t (_mute_ctrl->session().transport_sample()));
 	_mute_ctrl->set_value (on ? 1.0 : 0.0, group_mode ());
 }
 
@@ -410,7 +411,7 @@ FP8Strip::set_solo (bool on)
 	if (!_solo_ctrl) {
 		return;
 	}
-	_solo_ctrl->start_touch (_solo_ctrl->session().transport_sample());
+	_solo_ctrl->start_touch (timepos_t (_solo_ctrl->session().transport_sample()));
 	PBD::Controllable::GroupControlDisposition gcd = group_mode ();
 	Session& s = const_cast<Session&> (_solo_ctrl->session());
 	s.set_control (_solo_ctrl, on ? 1.0 : 0.0, gcd);
@@ -433,7 +434,7 @@ FP8Strip::set_select ()
 		assert (!_x_select_ctrl);
 		_select_plugin_functor ();
 	} else if (_x_select_ctrl) {
-		_x_select_ctrl->start_touch (_x_select_ctrl->session().transport_sample());
+		_x_select_ctrl->start_touch (timepos_t (_x_select_ctrl->session().transport_sample()));
 		const bool on = !select_button ().is_active();
 		_x_select_ctrl->set_value (on ? 1.0 : 0.0, group_mode ());
 	}
