@@ -560,7 +560,7 @@ TranzportControlProtocol::show_bbt (samplepos_t where)
 {
 	if ((where != last_where) || lcd_isdamaged(1,9,8)) {
 		char buf[16];
-		Timecode::BBT_Time bbt;
+		Temporal::BBT_Time bbt;
 		session->tempo_map().bbt_time (where, bbt);
 		sprintf (buf, "%03" PRIu32 "|%02" PRIu32 "|%04" PRIu32, bbt.bars,bbt.beats,bbt.ticks);
 		last_bars = bbt.bars;
@@ -1921,7 +1921,7 @@ TranzportControlProtocol::print_noretry (int row, int col, const char *text)
 }
 
 XMLNode&
-TranzportControlProtocol::get_state ()
+TranzportControlProtocol::get_state () const
 {
 	return ControlProtocol::get_state();
 }
