@@ -50,7 +50,9 @@
 #include "ardour/async_midi_port.h"
 #include "ardour/audioengine.h"
 #include "ardour/auditioner.h"
-#include "ardour/filesystem_paths.h"
+#include "ardour/directory_names.h"
+#include "ardour/filename_extensions.h"
+#include "ardour/search_paths.h"
 #include "ardour/session.h"
 #include "ardour/midi_ui.h"
 #include "ardour/plugin_insert.h"
@@ -180,32 +182,6 @@ GenericMidiControlProtocol::bundles ()
 	return b;
 }
 
-
-static const char * const midimap_env_variable_name = "ARDOUR_MIDIMAPS_PATH";
-static const char* const midi_map_dir_name = "midi_maps";
-static const char* const midi_map_suffix = ".map";
-
-Searchpath
-system_midi_map_search_path ()
-{
-	bool midimap_path_defined = false;
-	std::string spath_env (Glib::getenv (midimap_env_variable_name, midimap_path_defined));
-
-	if (midimap_path_defined) {
-		return spath_env;
-	}
-
-	Searchpath spath (ardour_data_search_path());
-	spath.add_subdirectory_to_paths(midi_map_dir_name);
-	return spath;
-}
-
-static std::string
-user_midi_map_directory ()
-{
-	return Glib::build_filename (user_config_directory(), midi_map_dir_name);
-}
-
 static bool
 midi_map_filter (const string &str, void* /*arg*/)
 {
@@ -682,14 +658,6 @@ GenericMidiControlProtocol::set_state (const XMLNode& node, int version)
 		_feedback_interval = 10000;
 	}
 
-	if (!node.get_property ("threshold", _threshold)) {
-		_threshold = 10;
-	}
-
-	if (!node.get_property ("motorized", _motorised)) {
-		_motorised = false;
-	}
-
 	boost::shared_ptr<Controllable> c;
 
 	{
@@ -715,6 +683,15 @@ GenericMidiControlProtocol::set_state (const XMLNode& node, int version)
 		}
 	}
 
+	/* Restore any custom settings which may have been overwritten by load_bindings */
+	if (!node.get_property ("threshold", _threshold)) {
+		_threshold = 10;
+	}
+
+	if (!node.get_property ("motorized", _motorised)) {
+		_motorised = false;
+	}
+
 	/* Load up specific bindings from the
 	 * <Controls><MidiControllable>...</MidiControllable><Controls> section
 	 */
@@ -1141,7 +1118,18 @@ GenericMidiControlProtocol::lookup_controllable (const string & str) const
 
 		switch (type) {
 		case Named:
-			s = session->route_by_name (name);
+
+			name = rest[0];
+
+			if (name == "Master" || name == X_("master")) {
+				s = session->master_out();
+			} else if (name == X_("control") || name == X_("listen") || name == X_("monitor") || name == "Monitor") {
+				s = session->monitor_out();
+			} else if (name == X_("auditioner")) {
+				s = session->the_auditioner();
+			} else {
+				s = session->route_by_name (name);
+			}
 			break;
 		default:
 			s = session->get_remote_nth_stripable (id, PresentationInfo::Bus);
