@@ -369,7 +369,7 @@ public:
 	int get_amount_of_tracks();
 
 	int set_active(bool yn);
-	XMLNode &get_state();
+	XMLNode& get_state() const;
 	int set_state(const XMLNode &node, int version);
 
 	PBD::Signal0<void> ConnectionChange;
@@ -411,6 +411,8 @@ public:
 	void send_bank_switch(bool up);
 	int send_bank_base () const { return _send_bank_base; }
 
+	CONTROL_PROTOCOL_THREADS_NEED_TEMPO_MAP_DECL();
+
 private:
 	bool in_use;
 	TrackMode _track_mode;
@@ -631,7 +633,6 @@ private:
 
 	boost::shared_ptr<ARDOUR::Stripable> master;
 
-	PBD::ScopedConnection port_reg_connection;
 	void port_registration_handler();
 
 	enum ConnectionState { InputConnected = 0x1, OutputConnected = 0x2 };
