@@ -111,8 +111,14 @@ MackieControlProtocol::left_press (Button &)
 
 	DEBUG_TRACE (DEBUG::MackieControl, string_compose ("bank left with current initial = %1 nstrips = %2 tracks/busses = %3\n",
 							   _current_initial_bank, strip_cnt, sorted.size()));
+
 	if (_current_initial_bank > 0) {
-		(void) switch_banks ((_current_initial_bank - 1) / strip_cnt * strip_cnt);
+		uint32_t initial = (_current_initial_bank - 1) / strip_cnt * strip_cnt;
+		while (initial >= sorted.size())
+		{
+			initial -= strip_cnt;
+		}
+		(void) switch_banks (initial);
 	} else {
 		(void) switch_banks (0);
 	}
@@ -383,6 +389,19 @@ MackieControlProtocol::undo_release (Button&)
 	return none;
 }
 
+LedState
+MackieControlProtocol::redo_press (Button &)
+{
+	redo ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::redo_release (Button &)
+{
+	return off;
+}
+
 LedState
 MackieControlProtocol::drop_press (Button &)
 {
@@ -419,6 +438,19 @@ MackieControlProtocol::save_release (Button &)
 	return none;
 }
 
+LedState
+MackieControlProtocol::open_press (Button &)
+{
+	access_action ("Main/Open");
+	return on;
+}
+
+LedState
+MackieControlProtocol::open_release (Button &)
+{
+	return off;
+}
+
 LedState
 MackieControlProtocol::timecode_beats_press (Button &)
 {
@@ -485,7 +517,7 @@ MackieControlProtocol::marker_release (Button &)
 
 	samplepos_t where = session->audible_sample();
 
-	if (session->transport_stopped_or_stopping() && session->locations()->mark_at (where, session->sample_rate() / 100.0)) {
+	if (session->transport_stopped_or_stopping() && session->locations()->mark_at (timepos_t (where), timecnt_t (session->sample_rate() / 100.0))) {
 		return off;
 	}
 
@@ -495,6 +527,58 @@ MackieControlProtocol::marker_release (Button &)
 	return off;
 }
 
+LedState
+MackieControlProtocol::prev_marker_press (Button &)
+{
+	prev_marker ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::prev_marker_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::next_marker_press (Button &)
+{
+	next_marker ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::next_marker_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::flip_window_press (Button &)
+{
+	access_action("Common/toggle-editor-and-mixer");
+	return on;
+}
+
+LedState
+MackieControlProtocol::flip_window_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::master_press (Button &)
+{
+	_master_surface->toggle_master_monitor ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::master_release (Button &)
+{
+	return off;
+}
+
 /////////////////////////////////////
 // Transport Buttons
 /////////////////////////////////////
@@ -865,10 +949,8 @@ MackieControlProtocol::master_fader_touch_press (Mackie::Button &)
 
 		Fader* master_fader = _master_surface->master_fader();
 
-		boost::shared_ptr<AutomationControl> ac = master_fader->control ();
-
 		master_fader->set_in_use (true);
-		master_fader->start_touch (transport_sample());
+		master_fader->start_touch (timepos_t (transport_sample()));
 	}
 	return none;
 }
@@ -881,7 +963,8 @@ MackieControlProtocol::master_fader_touch_release (Mackie::Button &)
 		Fader* master_fader = _master_surface->master_fader();
 
 		master_fader->set_in_use (false);
-		master_fader->stop_touch (transport_sample());
+		master_fader->stop_touch (timepos_t (transport_sample()));
+
 	}
 	return none;
 }
@@ -1000,6 +1083,9 @@ MackieControlProtocol::audioinstruments_press (Mackie::Button& b)
 Mackie::LedState
 MackieControlProtocol::audioinstruments_release (Mackie::Button& b)
 {
+#ifndef MIXBUS
+	set_view_mode (AudioInstr);
+#endif
 	return none;
 
 }
@@ -1033,7 +1119,7 @@ MackieControlProtocol::outputs_press (Mackie::Button&)
 Mackie::LedState
 MackieControlProtocol::outputs_release (Mackie::Button&)
 {
-	set_view_mode (Hidden);
+	set_view_mode (Outputs);
 	return none;
 }
 Mackie::LedState
@@ -1126,11 +1212,11 @@ MackieControlProtocol::click_press (Mackie::Button&)
 {
 	if (main_modifier_state() & MODIFIER_SHIFT) {
 		access_action ("Editor/set-punch-from-edit-range");
-		return off;
+		return none;
 	} else {
 		bool state = !Config->get_clicking();
 		Config->set_clicking (state);
-		return state;
+		return none;
 	}
 }
 Mackie::LedState
@@ -1149,3 +1235,137 @@ MackieControlProtocol::view_release (Mackie::Button&)
 {
 	return none;
 }
+
+/////////////////////////////////////
+// QCon Pro G2 Buttons
+/////////////////////////////////////
+
+LedState
+MackieControlProtocol::prog2_undo_press (Button &)
+{
+	if(main_modifier_state () & MODIFIER_SHIFT) {
+		access_action ("Common/menu-show-preferences");
+		return on;
+	}
+	undo ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_undo_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::prog2_clear_solo_press (Button &)
+{
+	if (main_modifier_state() & MODIFIER_SHIFT) {
+
+		StripableList sl;
+		session->get_stripables (sl);
+		for (StripableList::const_iterator i = sl.begin(); i != sl.end(); ++i)
+		{
+			boost::shared_ptr<MuteControl> mc = (*i)->mute_control();
+			if (!mc->muted() && (!(*i)->is_master()) && (!(*i)->is_monitor()))
+			{
+				mc->set_value(1.0, Controllable::UseGroup);
+			}
+		}
+
+		return none;   
+	}
+	cancel_all_solo ();
+	return none;
+}
+
+LedState
+MackieControlProtocol::prog2_clear_solo_release (Button &)
+{
+	return none;
+}
+
+LedState
+MackieControlProtocol::prog2_save_press (Button &)
+{
+	if (main_modifier_state() & MODIFIER_SHIFT)
+	{
+		access_action("Main/SaveAs");
+		return on;
+	}
+	save_state ();
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_save_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::prog2_vst_press (Button &)
+{
+	access_action("Mixer/select-all-processors");
+	access_action("Mixer/toggle-processors");
+
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_vst_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::prog2_left_press (Button &)
+{
+	access_action("Mixer/select-prev-stripable");
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_left_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::prog2_right_press (Button &)
+{
+	access_action("Mixer/select-next-stripable");
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_right_release (Button &)
+{
+	return off;
+}
+
+LedState
+MackieControlProtocol::prog2_marker_press (Button &)
+{
+	if (main_modifier_state() & MODIFIER_SHIFT) {
+		access_action ("Common/remove-location-from-playhead");
+		return on;
+	}
+
+	samplepos_t where = session->audible_sample();
+	if (session->transport_stopped_or_stopping() && session->locations()->mark_at (timepos_t (where), timecnt_t (session->sample_rate() / 100.0))) {
+		return on;
+	}
+
+	string markername;
+	session->locations()->next_available_name (markername,"mark");
+	add_marker (markername);
+
+	return on;
+}
+
+LedState
+MackieControlProtocol::prog2_marker_release (Button &)
+{
+	return off;
+}
