@@ -715,6 +715,7 @@ Strip::format_parameter_for_display(
 	case GainAutomation:
 	case BusSendLevel:
 	case TrimAutomation:
+	case InsertReturnLevel:
 		// we can't use value_as_string() that'll suffix "dB" and also use "-inf" w/o space :(
 		if (val == 0.0) {
 			formatted_parameter_display = " -inf ";
@@ -1054,7 +1055,7 @@ Strip::display (uint32_t lcd_number, uint32_t line_number, const std::string& li
 		retval << ' ';	// add the left pad space
 	}
 
-	// ascii data to display. @param line is UTF-8
+	// ascii data to display. `line` is UTF-8
 	string ascii = Glib::convert_with_fallback (line, "UTF-8", "ISO-8859-1", "_");
 	string::size_type len = ascii.length();
 	if (len > max_char_count) {
