@@ -94,7 +94,7 @@ public:
 	MidiByteArray display (uint32_t lcd_number, uint32_t line_number, const std::string&);
 	MidiByteArray blank_display (uint32_t lcd_number, uint32_t line_number);
 	
-	static std::string format_paramater_for_display(
+	static std::string format_parameter_for_display(
 		ARDOUR::ParameterDescriptor const& desc, 
 		float val, 
 		boost::shared_ptr<ARDOUR::Stripable> stripable_for_non_mixbus_azimuth_automation, 
