@@ -193,11 +193,14 @@ public:
 
 	void master_monitor_may_have_changed ();
 
-	XMLNode& get_state ();
+	XMLNode& get_state () const;
 	int set_state (const XMLNode&, int version);
 
 	bool get_qcon_flag() { return is_qcon; }
 
+	void toggle_master_monitor ();
+	bool master_stripable_is_master_monitor ();
+
   private:
 	MackieControlProtocol& _mcp;
 	SurfacePort*           _port;
