@@ -25,8 +25,6 @@
 
 #include "pbd/compose.h"
 #include "pbd/error.h"
-#include "pbd/i18n.h"
-#include "pbd/abstract_ui.cc" // instantiate template
 
 #include "ardour/async_midi_port.h"
 #include "ardour/audioengine.h"
@@ -44,6 +42,8 @@
 
 #include "canvas.h"
 
+#include "pbd/abstract_ui.cc" // instantiate template, includes i18n
+
 using namespace ARDOUR;
 using namespace PBD;
 using namespace ArdourSurface;
@@ -163,7 +163,7 @@ Maschine2::set_active (bool yn)
 }
 
 XMLNode&
-Maschine2::get_state()
+Maschine2::get_state() const
 {
 	XMLNode& node (ControlProtocol::get_state());
 	return node;
@@ -224,12 +224,12 @@ Maschine2::start ()
 		case Mikro:
 			_hw = new Maschine2Mikro ();
 			_ctrl = new M2MapMikro ();
-			info << _("Maschine2 Mikro control surface intialized");
+			info << _("Maschine2 Mikro control surface initialized");
 			break;
 		case Maschine:
 			_hw = new Maschine2Mk2 ();
 			_ctrl = new M2MapMk2 ();
-			info << _("Maschine2 control surface intialized");
+			info << _("Maschine2 control surface initialized");
 			break;
 		case Studio:
 			error << _("Maschine2 Studio is not yet supported");
