@@ -48,6 +48,7 @@
 
 #include "pbd/i18n.h"
 
+
 class OSCControllable;
 class OSCRouteObserver;
 class OSCGlobalObserver;
@@ -57,6 +58,7 @@ class OSCCueObserver;
 namespace ARDOUR {
 class Session;
 class Route;
+class ZeroConf;
 }
 
 /* this is mostly a placeholder because I suspect that at some
@@ -190,6 +192,7 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 		 * [13] - Send well known feedback (for /select/command
 		 * [14] - use OSC 1.0 only (#reply -> /reply)
 		 * [15] - report 8x8 trigger grid status
+		 * [16] - report mixer scene status
 		 *
 		 * Strip_type bits:
 		 * [0] - Audio Tracks
@@ -268,6 +271,8 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 	int trigger_bank_state (lo_address addr);
 	int trigger_grid_state (lo_address addr, bool zero_it = false);
 
+	int mixer_scene_state (lo_address addr, bool zero_it = false);
+
   protected:
         void thread_init ();
 	void do_request (OSCUIRequest*);
@@ -303,6 +308,8 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 	bool global_init;
 	boost::shared_ptr<ARDOUR::Stripable> _select;	// which stripable out of /surface/stripables is gui selected
 
+	ARDOUR::ZeroConf* _zeroconf;
+
 	void register_callbacks ();
 
 	void route_added (ARDOUR::RouteList&);
@@ -493,6 +500,9 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 	PATH_CALLBACK1(trigger_cue_row,i,);
 	PATH_CALLBACK1(trigger_stop_all,i,);  //0 = "stop at end of bar"  1 = "stop now"
 
+	PATH_CALLBACK1(store_mixer_scene,i,);
+	PATH_CALLBACK1(apply_mixer_scene,i,);
+
 	PATH_CALLBACK1(set_transport_speed,f,);
 	PATH_CALLBACK1(add_marker_name,s,&);
 	PATH_CALLBACK1(access_action,s,&);
