@@ -47,13 +47,13 @@ row_interval_string (const Push2::RowInterval row_interval, const bool inkey)
 {
 	switch (row_interval) {
 	case Push2::Third:
-		return _("3rd \u2191");
+		return _(u8"3rd \u2191");
 	case Push2::Fourth:
-		return _("4th \u2191");
+		return _(u8"4th \u2191");
 	case Push2::Fifth:
-		return _("5th \u2191");
+		return _(u8"5th \u2191");
 	case Push2::Sequential:
-		return inkey ? _("Octave \u2191") : _("Sequential \u2191");
+		return inkey ? _(u8"Octave \u2191") : _(u8"Sequential \u2191");
 	}
 
 	return "";
@@ -62,7 +62,7 @@ row_interval_string (const Push2::RowInterval row_interval, const bool inkey)
 static const char*
 column_interval_string (const bool inkey)
 {
-	return inkey ? _("Scale \u2192") : _("Semitone \u2192");
+	return inkey ? _(u8"Scale \u2192") : _(u8"Semitone \u2192");
 }
 
 ScaleLayout::ScaleLayout (Push2& p, Session & s, std::string const & name)
@@ -179,19 +179,19 @@ ScaleLayout::ScaleLayout (Push2& p, Session & s, std::string const & name)
 			t->set (S_("Note|F"));
 			break;
 		case 2:
-			t->set (S_("Note|B\u266D/A\u266F"));
+			t->set (S_(u8"Note|B\u266D/A\u266F"));
 			break;
 		case 3:
-			t->set (S_("Note|E\u266D/D\u266F"));
+			t->set (S_(u8"Note|E\u266D/D\u266F"));
 			break;
 		case 4:
-			t->set (S_("Note|A\u266D/G\u266F"));
+			t->set (S_(u8"Note|A\u266D/G\u266F"));
 			break;
 		case 5:
-			t->set (S_("Note|D\u266D/C\u266F"));
+			t->set (S_(u8"Note|D\u266D/C\u266F"));
 			break;
 		case 6:
-			t->set (S_("Note|G\u266D/F\u266F"));
+			t->set (S_(u8"Note|G\u266D/F\u266F"));
 			break;
 		}
 
