@@ -20,6 +20,7 @@
 #include <cmath>
 #include "ardour/lmath.h"
 
+#include "pbd/assert.h"
 #include "pbd/cpus.h"
 #include "pbd/pthread_utils.h"
 
@@ -31,8 +32,8 @@
 namespace ArdourWaveView {
 
 WaveViewProperties::WaveViewProperties (boost::shared_ptr<ARDOUR::AudioRegion> region)
-    : region_start (region->start ())
-    , region_end (region->start () + region->length ())
+    : region_start (region->start_sample ())
+    , region_end (region->start_sample () + region->length_samples ())
     , channel (0)
     , height (64)
     , samples_per_pixel (0)
@@ -208,8 +209,7 @@ WaveViewCache::get_cache_group (boost::shared_ptr<ARDOUR::AudioSource> source)
 	boost::shared_ptr<WaveViewCacheGroup> new_group (new WaveViewCacheGroup (*this));
 
 	bool inserted = cache_group_map.insert (std::make_pair (source, new_group)).second;
-
-	assert (inserted);
+	x_assert (inserted, inserted);
 
 	return new_group;
 }
@@ -405,7 +405,7 @@ WaveViewDrawingThread::start ()
 {
 	assert (!_thread);
 
-	_thread = Glib::Threads::Thread::create (sigc::ptr_fun (&WaveViewThreads::thread_proc));
+	_thread = PBD::Thread::create (&WaveViewThreads::thread_proc);
 }
 
 void
